var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';

import { Alert, Button, Col, ControlLabel, Glyphicon, Grid, Row, Table, Well } from 'react-bootstrap';

import Spinner from './helpers/Spinner';
import server from './helpers/Server';
import MessageIcons from './helpers/MessageIcons';
import ModalAgesServiceSelector from './modules/ModalAgesServiceSelector';
import ReactSelector from './modules/ReactSelector';
import User from "./classes/User";

/**
 * This class renders a liturgical service or book using a json
 * metadata file created from the HTML in a user selected service
 * or book from the AGES Initiatives website.
 * This class provides a UI for the user to
 * 1. Select a service or book from the AGES website.  It reads the json index and the index for sacraments.
 * 2. Indicate one, two, or three languages (versions) and fallbacks.
 * 3. Calls the web service to get the json metadata file.
 * 4. Uses the json metadata file to render an HTML table.
 */
var AgesViewer = (_temp = _class = function (_React$Component) {
  _inherits(AgesViewer, _React$Component);

  function AgesViewer(props) {
    _classCallCheck(this, AgesViewer);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    _this.state = _this.setTheState(props, _this.state);

    _this.disableFetchButton = _this.disableFetchButton.bind(_this);
    _this.fetchAgesIndex = _this.fetchAgesIndex.bind(_this);
    _this.fetchData = _this.fetchData.bind(_this);
    _this.getAgesTableInfo = _this.getAgesTableInfo.bind(_this);
    _this.getAgesTableRow = _this.getAgesTableRow.bind(_this);
    _this.getFetchingAgesTableRow = _this.getFetchingAgesTableRow.bind(_this);
    _this.getPdfButton = _this.getPdfButton.bind(_this);
    _this.checkPdfStatus = _this.checkPdfStatus.bind(_this);
    _this.getSelectedService = _this.getSelectedService.bind(_this);
    _this.getServiceSelectorPanel = _this.getServiceSelectorPanel.bind(_this);
    _this.handleFetchAgesIndexCallback = _this.handleFetchAgesIndexCallback.bind(_this);
    _this.handleFetchCallback = _this.handleFetchCallback.bind(_this);
    _this.handleFirstLibraryFallbackSelection = _this.handleFirstLibraryFallbackSelection.bind(_this);
    _this.handleFirstLibrarySelection = _this.handleFirstLibrarySelection.bind(_this);
    _this.handlePdfStatusCallback = _this.handlePdfStatusCallback.bind(_this);
    _this.handleSecondLibraryFallbackSelection = _this.handleSecondLibraryFallbackSelection.bind(_this);
    _this.handleSecondLibrarySelection = _this.handleSecondLibrarySelection.bind(_this);
    _this.handleServiceSelection = _this.handleServiceSelection.bind(_this);
    _this.handleServiceSelectionClose = _this.handleServiceSelectionClose.bind(_this);
    _this.handleThirdLibraryFallbackSelection = _this.handleThirdLibraryFallbackSelection.bind(_this);
    _this.handleThirdLibrarySelection = _this.handleThirdLibrarySelection.bind(_this);
    _this.handleTimeout = _this.handleTimeout.bind(_this);
    _this.renderHtml = _this.renderHtml.bind(_this);
    _this.setTable = _this.setTable.bind(_this);
    _this.showServiceSelector = _this.showServiceSelector.bind(_this);
    return _this;
  }

  // if we did not receive table values as a prop, fetch them


  AgesViewer.prototype.render = function render() {
    return React.createElement(
      'div',
      { className: 'App App-ParaColTextEditor' },
      React.createElement(
        Well,
        null,
        React.createElement(
          Grid,
          { className: 'App-Grid' },
          React.createElement(
            Row,
            { className: 'App-Selection-Row' },
            React.createElement(
              Col,
              { xs: 12, md: 12 },
              React.createElement(
                'h3',
                null,
                this.state.labels.thisClass.panelTitle
              ),
              React.createElement(
                ControlLabel,
                null,
                this.state.labels.thisClass.msg1
              )
            )
          ),
          React.createElement(
            Row,
            { className: 'App-Selection-Row' },
            React.createElement(
              Col,
              { xs: 12, md: 12 },
              this.getServiceSelectorPanel()
            )
          ),
          React.createElement(
            Row,
            { className: 'App-Selection-Row' },
            React.createElement(
              Col,
              { xs: 12 },
              this.getSelectedService()
            )
          ),
          React.createElement(
            Row,
            { className: 'App-Selection-Row' },
            React.createElement(
              Col,
              { xs: 4, md: 4 },
              React.createElement(
                ControlLabel,
                null,
                this.state.labels.thisClass.selectFirstLibrary
              )
            ),
            React.createElement(
              Col,
              { xs: 8, md: 8 },
              React.createElement(ReactSelector, {
                initialValue: this.state.selectedFirstLibrary,
                resources: this.state.session.userInfo.domains.reader,
                changeHandler: this.handleFirstLibrarySelection,
                multiSelect: false
              })
            )
          ),
          React.createElement(
            Row,
            { className: 'App-Selection-Row' },
            React.createElement(
              Col,
              { xs: 4, md: 4 },
              React.createElement(
                ControlLabel,
                null,
                this.state.labels.thisClass.selectFirstLibraryFallback
              )
            ),
            React.createElement(
              Col,
              { xs: 8, md: 8 },
              React.createElement(ReactSelector, {
                initialValue: this.state.selectedFirstLibraryFallback,
                resources: this.state.fallbackArray,
                changeHandler: this.handleFirstLibraryFallbackSelection,
                multiSelect: false
              })
            )
          ),
          this.state.selectedFirstLibrary && React.createElement(
            'div',
            null,
            React.createElement(
              Row,
              { className: 'App-Selection-Row' },
              React.createElement(
                Col,
                { xs: 4, md: 4 },
                React.createElement(
                  ControlLabel,
                  null,
                  this.state.labels.thisClass.selectSecondLibrary
                )
              ),
              React.createElement(
                Col,
                { xs: 8, md: 8 },
                React.createElement(ReactSelector, {
                  initialValue: this.state.selectedSecondLibrary,
                  resources: this.state.session.userInfo.domains.reader,
                  changeHandler: this.handleSecondLibrarySelection,
                  multiSelect: false
                })
              )
            ),
            React.createElement(
              Row,
              { className: 'App-Selection-Row' },
              React.createElement(
                Col,
                { xs: 4, md: 4 },
                React.createElement(
                  ControlLabel,
                  null,
                  this.state.labels.thisClass.selectSecondLibraryFallback
                )
              ),
              React.createElement(
                Col,
                { xs: 8, md: 8 },
                React.createElement(ReactSelector, {
                  initialValue: this.state.selectedSecondLibraryFallback,
                  resources: this.state.fallbackArray,
                  changeHandler: this.handleSecondLibraryFallbackSelection,
                  multiSelect: false
                })
              )
            )
          ),
          this.state.selectedSecondLibrary && React.createElement(
            'div',
            null,
            React.createElement(
              Row,
              { className: 'App-Selection-Row' },
              React.createElement(
                Col,
                { xs: 4, md: 4 },
                React.createElement(
                  ControlLabel,
                  null,
                  this.state.labels.thisClass.selectThirdLibrary
                )
              ),
              React.createElement(
                Col,
                { xs: 8, md: 8 },
                React.createElement(ReactSelector, {
                  initialValue: this.state.selectedThirdLibrary,
                  resources: this.state.session.userInfo.domains.reader,
                  changeHandler: this.handleThirdLibrarySelection,
                  multiSelect: false
                })
              )
            ),
            React.createElement(
              Row,
              { className: 'App-Selection-Row' },
              React.createElement(
                Col,
                { xs: 4, md: 4 },
                React.createElement(
                  ControlLabel,
                  null,
                  this.state.labels.thisClass.selectThirdLibraryFallback
                )
              ),
              React.createElement(
                Col,
                { xs: 8, md: 8 },
                React.createElement(ReactSelector, {
                  initialValue: this.state.selectedThirdLibraryFallback,
                  resources: this.state.fallbackArray,
                  changeHandler: this.handleThirdLibraryFallbackSelection,
                  multiSelect: false
                })
              )
            )
          ),
          React.createElement(
            Row,
            { className: 'App-Selection-Row' },
            React.createElement(
              Col,
              { xs: 12, md: 12 },
              React.createElement(
                Button,
                {
                  bsStyle: 'primary',
                  onClick: this.fetchData,
                  disabled: this.disableFetchButton()
                },
                this.state.labels.thisClass.fetch
              )
            )
          ),
          this.state.dataFetched && this.getAgesTableRow(),
          this.state.fetchingData && this.getFetchingAgesTableRow()
        )
      )
    );
  };

  return AgesViewer;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {
    _this2.fetchAgesIndex();
  };

  this.componentWillReceiveProps = function (nextProps) {
    _this2.state = _this2.setTheState(nextProps, _this2.state);
  };

  this.setTheState = function (props, currentState) {
    var url = undefined;
    if (currentState && currentState.url) {
      url = currentState.url;
    }
    var pdfId = undefined;
    if (currentState && currentState.pdfId) {
      pdfId = currentState.pdfId;
    }
    var pdfFilename = undefined;
    if (currentState && currentState.pdfFilename) {
      pdfFilename = currentState.pdfFilename;
    }
    var serviceType = undefined;
    if (currentState && currentState.serviceType) {
      serviceType = currentState.serviceType;
    }
    var serviceDate = undefined;
    if (currentState && currentState.serviceDate) {
      serviceDate = currentState.serviceDate;
    }
    var serviceDow = undefined;
    if (currentState && currentState.serviceDow) {
      serviceDow = currentState.serviceDow;
    }
    var selectedService = undefined;
    if (currentState && currentState.selectedService) {
      selectedService = currentState.selectedService;
    }
    var agesIndexValues = [];
    var agesIndexFetched = false;
    if (currentState && currentState.agesIndexFetched) {
      agesIndexValues = currentState.agesIndexValues;
      agesIndexFetched = true;
    }
    var selectedFirstLibrary = "gr_gr_cog";
    if (currentState && currentState.selectedFirstLibrary) {
      selectedFirstLibrary = currentState.selectedFirstLibrary;
    }
    var selectedFirstLibraryFallback = "gr_gr_ages";
    if (currentState && currentState.selectedFirstLibraryFallback) {
      selectedFirstLibraryFallback = currentState.selectedFirstLibraryFallback;
    }
    var selectedSecondLibrary = "en_us_dedes";
    if (currentState && currentState.selectedSecondLibrary) {
      selectedSecondLibrary = currentState.selectedSecondLibrary;
    }
    var selectedSecondLibraryFallback = "en_us_ages";
    if (currentState && currentState.selectedSecondLibraryFallback) {
      selectedSecondLibraryFallback = currentState.selectedSecondLibraryFallback;
    }
    var selectedThirdLibrary = "";
    if (currentState && currentState.selectedThirdLibrary) {
      selectedThirdLibrary = currentState.selectedThirdLibrary;
    }
    var selectedThirdLibraryFallback = "";
    if (currentState && currentState.selectedThirdLibraryFallback) {
      selectedThirdLibraryFallback = currentState.selectedThirdLibraryFallback;
    }

    var userInfo = {};
    if (props.session && props.session.userInfo) {
      userInfo = new User(props.session.userInfo.username, props.session.userInfo.password, props.session.userInfo.domain, props.session.userInfo.email, props.session.userInfo.firstname, props.session.userInfo.lastname, props.session.userInfo.title, props.session.userInfo.authenticated, props.session.userInfo.domains);
    }

    return {
      labels: {
        thisClass: props.session.labels[props.session.labelTopics.AgesViewer],
        buttons: props.session.labels[props.session.labelTopics.button],
        messages: props.session.labels[props.session.labelTopics.messages],
        liturgicalAcronyms: props.session.labels[props.session.labelTopics.liturgicalAcronyms]
      },
      session: {
        userInfo: userInfo
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: props.session.labels[props.session.labelTopics.messages].initial,
      selectedFirstLibrary: selectedFirstLibrary,
      selectedFirstLibraryFallback: selectedFirstLibraryFallback,
      selectedSecondLibrary: selectedSecondLibrary,
      selectedSecondLibraryFallback: selectedSecondLibraryFallback,
      selectedThirdLibrary: selectedThirdLibrary,
      selectedThirdLibraryFallback: selectedThirdLibraryFallback,
      showModalEditor: false,
      selectedId: "",
      selectedTopicKey: "",
      renderedTable: undefined,
      showModalServiceSelector: false,
      url: url,
      pdfId: pdfId,
      pdfFilename: pdfFilename,
      generationStatusMessage: "",
      serviceDate: serviceDate,
      serviceDow: serviceDow,
      serviceType: serviceType,
      selectedService: selectedService,
      agesIndexFetched: agesIndexFetched,
      agesIndexValues: agesIndexValues,
      fetchingData: false,
      fallbackArray: [{ value: "en_us_ages", label: "AGES English translations" }, { value: "gr_gr_ages", label: "AGES Greek" }, { value: "none", label: "No Fallback" }]
    };
  };

  this.disableFetchButton = function () {
    return !_this2.state.url;
  };

  this.fetchAgesIndex = function () {
    if (_this2.props.agesIndexValues) {
      _this2.setState({
        agesIndexFetched: true,
        agesIndexValues: _this2.props.agesIndexValues
      });
    } else {
      _this2.setState({
        message: _this2.state.labels.messages.retrieving
      }, server.getAgesIndex(_this2.props.session.restServer, _this2.state.session.userInfo.username, _this2.state.session.userInfo.password, _this2.handleFetchAgesIndexCallback));
    }
  };

  this.handleFetchAgesIndexCallback = function (restCallResult) {
    if (restCallResult && restCallResult.code == "200" && restCallResult.data && restCallResult.data.values) {
      var values = restCallResult.data.values[0];
      _this2.setState({
        agesIndexFetched: true,
        agesIndexValues: values.tableData
      });
    } else {
      console.log(JSON.stringify(restCallResult));
      _this2.setState({
        agesIndexFetched: true
      });
    }
  };

  this.checkPdfStatus = function () {
    _this2.setState({
      fetchingPdf: true,
      showPdfButton: false
    }, server.restGetGenerationStatus(_this2.props.session.restServer, _this2.state.session.userInfo.username, _this2.state.session.userInfo.password, _this2.state.pdfId, _this2.handlePdfStatusCallback));
  };

  this.handlePdfStatusCallback = function (result) {
    var statusMessage = _this2.state.labels.messages.couldNotGenerate;
    var showPdfButton = false;
    if (result.code === 200) {
      var _statusMessage = "";
      showPdfButton = true;
    }
    _this2.setState({
      fetchingPdf: false,
      showPdfButton: showPdfButton,
      generationStatusMessage: statusMessage
    });
  };

  this.fetchData = function () {
    var parms = "u=" + encodeURIComponent(_this2.state.url) + "&l=" + encodeURIComponent(_this2.state.selectedFirstLibrary) + "&c=" + encodeURIComponent(_this2.state.selectedSecondLibrary) + "&r=" + encodeURIComponent(_this2.state.selectedThirdLibrary) + "&lf=" + encodeURIComponent(_this2.state.selectedFirstLibraryFallback) + "&cf=" + encodeURIComponent(_this2.state.selectedSecondLibraryFallback) + "&rf=" + encodeURIComponent(_this2.state.selectedThirdLibraryFallback);

    _this2.setState({
      message: _this2.state.labels.messages.retrieving,
      fetchingData: true,
      dataFetched: false,
      showPdfButton: false
    }, server.getAgesReadOnlyTemplate(_this2.props.session.restServer, _this2.state.session.userInfo.username, _this2.state.session.userInfo.password, parms, _this2.handleFetchCallback));
  };

  this.handleTimeout = function () {
    _this2.setState({ showPdfButton: true });
  };

  this.handleFetchCallback = function (restCallResult) {
    if (restCallResult && restCallResult.code == "200" && restCallResult.data && restCallResult.data.values) {
      var data = restCallResult.data.values[0];
      var values = data.values;
      var topicKeys = data.topicKeys;
      var topElement = data.topElement.children[0].children[0]; // tbody
      var pdfId = data.pdfId;
      var pdfFilename = data.pdfFilename;
      _this2.setState({
        dataFetched: true,
        fetchingData: false,
        values: values,
        topicKeys: topicKeys,
        topElement: topElement,
        pdfId: pdfId,
        pdfFilename: pdfFilename
      }, _this2.setTable);
    } else {
      alert("An error occurred while trying to create a template out of the html file you selected.");
      if (restCallResult && restCallResult.data && restCallResult.data.status) {
        console.log(JSON.stringify(restCallResult, null, 3));
      }
      _this2.setState({
        dataFetched: false,
        fetchingData: false,
        values: null,
        topicKeys: null,
        topElement: null,
        pdfId: null,
        pdfFilename: null
      });
    }
  };

  this.handleFirstLibrarySelection = function (selection) {
    if (selection == null) {
      _this2.setState({
        selectedFirstLibrary: "",
        selectedFirstLibraryFallback: "",
        selectedSecondLibrary: "",
        selectedSecondLibraryFallback: "",
        selectedThirdLibrary: "",
        selectedThirdLibraryFallback: ""
      });
    } else {
      var selectedFirstLibraryFallback = "en_us_ages";
      if (_this2.state.selectedFirstLibraryFallback.length > 0) {
        selectedFirstLibraryFallback = _this2.state.selectedFirstLibraryFallback;
      } else {
        if (selection["value"].startsWith("gr")) {
          selectedFirstLibraryFallback = "gr_gr_ages";
        } else if (selection["value"].startsWith("en")) {
          selectedFirstLibraryFallback = "en_us_ages";
        }
      }
      _this2.setState({
        selectedFirstLibrary: selection["value"],
        selectedFirstLibraryFallback: selectedFirstLibraryFallback
      });
    }
  };

  this.handleServiceSelectionClose = function () {
    _this2.setState({
      showModalServiceSelector: false
    });
  };

  this.handleFirstLibraryFallbackSelection = function (selection) {
    if (selection == null) {
      _this2.setState({
        selectedFirstLibrary: "",
        selectedFirstLibraryFallback: "",
        selectedSecondLibrary: "",
        selectedSecondLibraryFallback: "",
        selectedThirdLibrary: "",
        selectedThirdLibraryFallback: ""
      });
    } else {
      _this2.setState({
        selectedFirstLibraryFallback: selection["value"]
      });
    }
  };

  this.handleSecondLibrarySelection = function (selection) {
    if (selection == null) {
      _this2.setState({
        selectedSecondLibrary: "",
        selectedSecondLibraryFallback: "",
        selectedThirdLibrary: "",
        selectedThirdLibraryFallback: ""
      });
    } else {
      var selectedSecondLibraryFallback = "en_us_ages";
      if (selection["value"].startsWith("gr")) {
        selectedSecondLibraryFallback = "gr_gr_ages";
      } else if (selection["value"].startsWith("en")) {
        selectedSecondLibraryFallback = "en_us_ages";
      } else if (_this2.state.selectedSecondLibraryFallback.length > 0) {
        selectedSecondLibraryFallback = _this2.state.selectedSecondLibraryFallback;
      }
      _this2.setState({
        selectedSecondLibrary: selection["value"],
        selectedSecondLibraryFallback: selectedSecondLibraryFallback,
        selectedThirdLibrary: "",
        selectedThirdLibraryFallback: ""
      });
    }
  };

  this.handleSecondLibraryFallbackSelection = function (selection) {
    if (selection == null) {
      _this2.setState({
        selectedSecondLibrary: "",
        selectedSecondLibraryFallback: ""
      });
    } else {
      _this2.setState({
        selectedSecondLibraryFallback: selection["value"]
      });
    }
  };

  this.handleThirdLibrarySelection = function (selection) {
    if (selection == null) {
      _this2.setState({
        selectedThirdLibrary: "",
        selectedThirdLibraryFallback: ""
      });
    } else {
      var selectedThirdLibraryFallback = "en_us_ages";
      if (_this2.state.selectedThirdLibraryFallback.length > 0) {
        selectedThirdLibraryFallback = _this2.state.selectedThirdLibraryFallback;
      } else {
        if (selection["value"].startsWith("gr")) {
          selectedThirdLibraryFallback = "gr_gr_ages";
        } else if (selection["value"].startsWith("en")) {
          selectedThirdLibraryFallback = "en_us_ages";
        }
      }
      _this2.setState({
        selectedThirdLibrary: selection["value"],
        selectedThirdLibraryFallback: selectedThirdLibraryFallback
      });
    }
  };

  this.handleThirdLibraryFallbackSelection = function (selection) {
    if (selection == null) {
      _this2.setState({
        selectedThirdLibrary: "",
        selectedThirdLibraryFallback: ""
      });
    } else {
      _this2.setState({
        selectedThirdLibraryFallback: selection["value"]
      });
    }
  };

  this.setTable = function () {
    _this2.setState({
      renderedTable: _this2.renderHtml(_this2.state.topElement)
    }, _this2.checkPdfStatus);
  };

  this.renderHtml = function (element) {
    var props = {};
    var children = [];
    var value = "";

    if (element.key) {
      props["key"] = element.key;
    }
    if (element.className) {
      props["className"] = element.className + " ages-table-element";
    } else {
      if (element.tag === "table" || element.tag === "tbody" || element.tag === "tr") {
        props["className"] = "ages";
      }
    }
    if (element.dataKey) {
      props["data-key"] = element.dataKey;
      value = _this2.state.values[element.dataKey];
      children.push(value);
    }
    if (element.topicKey) {
      props["data-topicKey"] = element.topicKey;
    }

    if (element.children) {
      for (var i = 0; i < element.children.length; i++) {
        children.push(_this2.renderHtml(element.children[i]));
      }
    }
    if (element.dataKey && value && value.trim().length === 0) {
      return React.createElement('span', { className: 'app-no-show' });
    } else {
      return React.createElement(element.tag, props, children);
    }
  };

  this.showServiceSelector = function () {
    _this2.setState({
      showModalServiceSelector: true
    });
  };

  this.handleServiceSelection = function (url, serviceType, serviceDate, serviceDow) {
    var selectedService = serviceType;
    if (_this2.state.labels.liturgicalAcronyms[serviceType]) {
      selectedService = _this2.state.labels.liturgicalAcronyms[serviceType];
    }
    if (serviceDate != "any") {
      selectedService = selectedService + " " + serviceDate;
    }
    if (serviceDow != "any") {
      selectedService = selectedService + " " + serviceDow;
    }
    _this2.setState({
      showModalServiceSelector: false,
      url: url,
      serviceDate: serviceDate,
      serviceDow: serviceDow,
      serviceType: serviceType,
      selectedService: selectedService
    });
  };

  this.getServiceSelectorPanel = function () {
    if (_this2.state.showModalServiceSelector) {
      return React.createElement(ModalAgesServiceSelector, {
        session: _this2.props.session,
        callBack: _this2.handleServiceSelection,
        onClose: _this2.handleServiceSelectionClose,
        values: _this2.state.agesIndexValues
      });
    } else {
      if (_this2.state.agesIndexFetched) {
        return React.createElement(
          Button,
          {
            bsStyle: 'primary',
            onClick: _this2.showServiceSelector
          },
          _this2.state.labels.thisClass.select
        );
      } else {
        return React.createElement(Spinner, { message: _this2.state.labels.messages.retrieving });
      }
    }
  };

  this.getAgesTableInfo = function () {
    if (_this2.state.dataFetched) {
      if (_this2.state.selectedFirstLibrary) {
        return React.createElement(
          'div',
          null,
          React.createElement(
            Alert,
            { bsStyle: 'info' },
            React.createElement(
              'p',
              null,
              React.createElement(Glyphicon, { glyph: 'hand-right' }),
              _this2.state.labels.thisClass.msg2,
              _this2.state.url
            )
          )
        );
      } else {
        return React.createElement(
          'div',
          null,
          React.createElement(
            Alert,
            { bsStyle: 'info' },
            React.createElement(
              'p',
              null,
              React.createElement(Glyphicon, { glyph: 'hand-right' }),
              _this2.state.labels.thisClass.msg2,
              _this2.state.url
            )
          ),
          React.createElement(
            Alert,
            { bsStyle: 'info' },
            React.createElement(
              'p',
              null,
              React.createElement(Glyphicon, { glyph: 'hand-right' }),
              _this2.state.labels.thisClass.agesGreek,
              _this2.state.labels.thisClass.agesEnglish,
              _this2.state.labels.thisClass.msg1
            )
          )
        );
      }
    } else {
      return React.createElement('div', null);
    }
  };

  this.getFetchingAgesTableRow = function () {
    return React.createElement(Spinner, { message: _this2.state.labels.messages.retrieving });
  };

  this.getAgesTableRow = function () {
    return React.createElement(
      'div',
      null,
      React.createElement(
        Row,
        { className: 'App-Info-Row' },
        React.createElement(
          Col,
          { xs: 12, md: 12 },
          _this2.getAgesTableInfo()
        )
      ),
      _this2.getPdfButton(),
      React.createElement(
        Row,
        { className: 'App App-Ages-Table-Row' },
        React.createElement(
          Col,
          { xs: 12, md: 12 },
          _this2.state.dataFetched && React.createElement(
            'div',
            { className: 'ages-content' },
            React.createElement(
              Table,
              { responsive: true },
              _this2.state.renderedTable
            )
          )
        )
      )
    );
  };

  this.getPdfButton = function () {
    if (_this2.state.dataFetched && _this2.state.showPdfButton) {
      var url = "data/" + _this2.state.pdfId;
      return React.createElement(
        Row,
        { className: 'App-Download-Row' },
        React.createElement(
          Col,
          { className: 'App-Download-Col', xs: 6, md: 6 },
          React.createElement(
            'a',
            { href: url + ".pdf", target: "_blank" },
            _this2.state.labels.buttons.downloadAsPdf
          )
        ),
        React.createElement(
          Col,
          { className: 'App-Download-Col', xs: 6, md: 6 },
          React.createElement(
            'a',
            { href: url + ".tex", target: "_blank" },
            _this2.state.labels.buttons.downloadAsTex
          )
        )
      );
    } else {
      if (_this2.state.dataFetched) {
        return React.createElement(Spinner, { message: _this2.state.labels.messages.preparingPdf });
      } else {
        return React.createElement(
          'span',
          null,
          _this2.state.generationStatusMessage
        );
      }
    }
  };

  this.getSelectedService = function () {
    if (_this2.state.selectedService) {
      return React.createElement(
        'div',
        null,
        React.createElement(
          ControlLabel,
          null,
          _this2.state.labels.thisClass.selected
        ),
        React.createElement(
          'span',
          null,
          _this2.state.selectedService
        )
      );
    }
  };
}, _temp);


process.env.NODE_ENV !== "production" ? AgesViewer.propTypes = {
  session: PropTypes.object.isRequired,
  agesIndexValues: PropTypes.array
} : void 0;

AgesViewer.defaultProps = {};

export default AgesViewer;