var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import FontAwesome from 'react-fontawesome';
import DeleteButton from './helpers/DeleteButton';
import RichEditor from './modules/RichEditor';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import 'react-draft-wysiwyg/dist/react-draft-wysiwyg.css';
import { get, has } from 'lodash';
import { Accordion, Button, Col, ControlLabel, Glyphicon, Grid, FormControl, FormGroup, HelpBlock, Panel, Row, Tab, Tabs, Well } from 'react-bootstrap';
import GenericModalNewEntryForm from './modules/GenericModalNewEntryForm';
import Server from './helpers/Server';
import Spinner from './helpers/Spinner';
import MessageIcons from './helpers/MessageIcons';
import ResourceSelector from './modules/ReactSelector';
import EditableSelector from './modules/EditableSelector';
import FormattedTextNote from './FormattedTextNote';
import IdManager from './helpers/IdManager';
import BibleRefSelector from './helpers/BibleRefSelector';
import OntologyRefSelector from './helpers/OntologyRefSelector';
import WorkflowForm from './helpers/WorkflowForm';

import CompareDocs from './modules/CompareDocs';
import axios from "axios/index";
import UiSchemas from "./classes/UiSchemas";
import * as Labels from "../es/Labels";

/**
 * Note: The form properties need to be remapped in the server:
 * biblicalScope needs to be renamed biblicalHeading
 * biblicalLemma needs to be renamed biblicalSubHeading
 * liturgicalScope needs to be renamed liturgicalHeading
 * liturgicalLemma needs to be renamed liturgicalSubHeadingA
 * In the code below, some renaming of the client-side properties has occurred.
 * So, selectedLiturgicalHeadingId =~ form.liturgicalGreekId
 *     selectedLiturgicalSubHeadingId =~ form.liturgicalTranslationId
 *
 *     The bottom line is that there is some changes to be make both client and server side.
 */

var TextNoteEditor = (_temp = _class = function (_React$Component) {
  _inherits(TextNoteEditor, _React$Component);

  function TextNoteEditor(props) {
    _classCallCheck(this, TextNoteEditor);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var created = false;
    if (props.form && props.form.noteType) {
      created = true;
    }
    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;
    var thisClassLabels = labels[labelTopics.TextNoteEditor];
    var messages = labels[labelTopics.messages];
    var initialMessage = messages.initial;

    var textIdParts = IdManager.getParts(props.textId);
    var editorId = "tinymce-" + new Date().getTime();
    var tags = [];
    var selectedTag = "";
    var selectedBiblicalIdParts = [{ key: "domain", label: "*" }, { key: "topic", label: "" }, { key: "key", label: "" }];

    var selectedType = "";
    var selectedTypeLabel = "";
    var selectedBiblicalGreekId = "";
    var selectedBiblicalLibrary = "";
    var selectedBiblicalBook = "";
    var selectedBiblicalChapter = "";
    var selectedBiblicalVerse = "";
    var citeBible = "";
    var selectedBiblicalTranslationId = "";
    var selectedLiturgicalSubHeadingId = "";
    var selectedLiturgicalHeadingId = "";

    var selectedRow = "";

    if (props.form) {
      selectedTypeLabel = props.form.noteType;
      if (props.form.tags) {
        selectedTag = props.form.tags[0];
        var j = props.form.tags.length;
        for (var i = 0; i < j; i++) {
          tags.push({ value: props.form.tags[i], label: props.form.tags[i] });
        }
      }
      if (props.form.biblicalGreekId) {
        var biblicalIdParts = IdManager.getParts(props.form.biblicalGreekId);
        selectedBiblicalIdParts = [{ key: "domain", label: "*" }, { key: "topic", label: biblicalIdParts.topic }, { key: "key", label: biblicalIdParts.key }];
        selectedBiblicalGreekId = props.form.biblicalGreekId;
        selectedBiblicalLibrary = biblicalIdParts.library;
        selectedBiblicalBook = biblicalIdParts.book;
        selectedBiblicalChapter = biblicalIdParts.chapter;
        selectedBiblicalVerse = biblicalIdParts.verse;
        var citeBook = biblicalIdParts.book;
        var citeChapter = biblicalIdParts.chapter.substring(1, biblicalIdParts.chapter.length);
        try {
          citeChapter = parseInt(citeChapter);
        } catch (err) {
          citeChapter = biblicalIdParts.chapter;
        }
        var citeVerse = 0;
        try {
          citeVerse = parseInt(biblicalIdParts.verse);
        } catch (err) {
          citeVerse = biblicalIdParts.verse;
        }
        citeBible = citeBook + " " + citeChapter + ":" + citeVerse;
      }
      if (props.form.biblicalTranslationId) {
        selectedBiblicalTranslationId = props.form.biblicalTranslationId;
      }
      if (props.form.liturgicalGreekId) {
        selectedLiturgicalHeadingId = props.form.liturgicalGreekId;
      } else {
        selectedLiturgicalHeadingId = props.textId;
      }
      if (props.form.liturgicalTranslationId) {
        selectedLiturgicalSubHeadingId = props.form.liturgicalTranslationId;
      } else {
        selectedLiturgicalSubHeadingId = "gr_gr_cog~" + textIdParts.topic + "~" + textIdParts.key;
      }
      if (props.form.noteType) {
        selectedType = props.form.noteType;
        selectedTypeLabel = _this.getLabel(props.form.noteType);
      }
      if (props.form.followsNoteId) {
        selectedRow = props.form.followsNoteId;
      }
    }
    var notesList = [];
    if (props.notesList && props.form) {
      notesList = props.notesList;
    }
    notesList = notesList.filter(function (el) {
      return el.id !== props.form.id;
    });

    var bibliographyDropdown = [];
    if (props.session && props.session.dropdowns) {
      bibliographyDropdown = props.session.dropdowns.schemaEditorDropdown.filter(function (row) {
        return row.value.startsWith("BibEntry");
      });
    }

    _this.state = {
      labels: {
        thisClass: thisClassLabels,
        buttons: labels[labelTopics.button],
        messages: messages,
        resultsTableLabels: labels[labelTopics.resultsTable],
        search: labels[labelTopics.search]
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: initialMessage,
      bibliographyDropdown: bibliographyDropdown,
      notesList: notesList,
      textIdParts: textIdParts,
      form: props.form,
      created: created,
      editor: null,
      editorId: editorId,
      note: "",
      scopeBiblical: "",
      scopeLiturgical: textIdParts.key,
      lemmaBiblical: "",
      lemmaLiturgical: "",
      title: "",
      liturgicalText: props.liturgicalText,
      liturgicalLibraries: undefined,
      biblicalLibraries: undefined,
      selectedNoteLibrary: props.session.userInfo.domain,
      selectedType: selectedType,
      selectedTypeLabel: selectedTypeLabel,
      bibleRef: "",
      selectedBiblicalGreekId: selectedBiblicalGreekId,
      selectedBiblicalIdParts: selectedBiblicalIdParts,
      selectedBiblicalLibrary: selectedBiblicalLibrary,
      selectedBiblicalBook: selectedBiblicalBook,
      selectedBiblicalChapter: selectedBiblicalChapter,
      selectedBiblicalVerse: selectedBiblicalVerse,
      citeBible: citeBible,
      selectedBiblicalTranslationId: selectedBiblicalTranslationId,
      selectedLiturgicalSubHeadingId: selectedLiturgicalSubHeadingId,
      selectedLiturgicalHeadingId: selectedLiturgicalHeadingId,
      greekBibleId: "",
      selectedLiturgicalIdParts: [{ key: "domain", label: "*" }, { key: "topic", label: textIdParts.topic }, { key: "key", label: textIdParts.key }],
      showBibleView: props.form && props.form.biblicalGreekId ? true : false,
      ontologyRefType: "",
      ontologyRefEntityId: "",
      ontologyRefEntityName: "",
      showOntologyView: false,
      workflow: {
        visibility: "PERSONAL",
        status: "EDITING",
        assignedTo: props.session.userInfo.username,
        statusIcon: "edit",
        visibilityIcon: "lock"
      },
      buttonSubmitDisabled: true,
      selectedTag: selectedTag,
      tags: tags,
      formIsValid: true,
      suggestions: [{
        text: 'No abbreviations or Suggestions entries available.',
        value: 'ignore',
        url: 'cite'
      }],
      predecessorNote: "",
      options: {
        sizePerPage: 30,
        sizePerPageList: [5, 15, 30],
        onSizePerPageList: _this.onSizePerPageList,
        hideSizePerPage: true,
        paginationShowsTotal: true
      },
      selectRow: {
        mode: 'checkbox' // or radio
        , hideSelectColumn: false,
        clickToSelect: false,
        onSelect: _this.handlePredecessorChange,
        className: "App-row-select",
        selected: [selectedRow]
      },
      filter: { type: 'RegexFilter', delay: 100 }
    };

    _this.createMarkup = _this.createMarkup.bind(_this);
    _this.fetchBibleText = _this.fetchBibleText.bind(_this);
    _this.fetchSuggestions = _this.fetchSuggestions.bind(_this);
    _this.getBibleRefRow = _this.getBibleRefRow.bind(_this);
    _this.getBiblicalGreekLibraryRow = _this.getBiblicalGreekLibraryRow.bind(_this);
    _this.getBiblicalLemmaRow = _this.getBiblicalLemmaRow.bind(_this);
    _this.getBiblicalScopeRow = _this.getBiblicalScopeRow.bind(_this);
    _this.getBiblicalTranslationLibraryRow = _this.getBiblicalTranslationLibraryRow.bind(_this);
    _this.getButtonRow = _this.getButtonRow.bind(_this);
    _this.getEditor = _this.getEditor.bind(_this);
    _this.getFormattedHeaderRow = _this.getFormattedHeaderRow.bind(_this);
    _this.getFormattedView = _this.getFormattedView.bind(_this);
    _this.getModalNewBiblioForm = _this.getModalNewBiblioForm.bind(_this);
    _this.getSettingsWell = _this.getSettingsWell.bind(_this);
    _this.getIdsWell = _this.getIdsWell.bind(_this);
    _this.getNoteOrderingRow = _this.getNoteOrderingRow.bind(_this);
    _this.getOrderWell = _this.getOrderWell.bind(_this);
    _this.getLabel = _this.getLabel.bind(_this);
    _this.getLiturgicalHeadingLibraryRow = _this.getLiturgicalHeadingLibraryRow.bind(_this);
    _this.getLiturgicalLemmaRow = _this.getLiturgicalLemmaRow.bind(_this);
    _this.getLiturgicalScopeRow = _this.getLiturgicalScopeRow.bind(_this);
    _this.getLiturgicalSubHeadingLibraryRow = _this.getLiturgicalSubHeadingLibraryRow.bind(_this);
    _this.getLiturgicalView = _this.getLiturgicalView.bind(_this);
    _this.getNoteIdRow = _this.getNoteIdRow.bind(_this);
    _this.getNoteLibraryRow = _this.getNoteLibraryRow.bind(_this);
    _this.getNoteTypeRow = _this.getNoteTypeRow.bind(_this);
    _this.getOntologyLabel = _this.getOntologyLabel.bind(_this);
    _this.getOntologyRefRow = _this.getOntologyRefRow.bind(_this);
    _this.getRevisionsPanel = _this.getRevisionsPanel.bind(_this);
    _this.getTabs = _this.getTabs.bind(_this);
    _this.getTagsRow = _this.getTagsRow.bind(_this);
    _this.getTimestamp = _this.getTimestamp.bind(_this);
    _this.getTitleRow = _this.getTitleRow.bind(_this);
    _this.getWorkflowPanel = _this.getWorkflowPanel.bind(_this);
    _this.handleAddButtonClick = _this.handleAddButtonClick.bind(_this);
    _this.handleBibleRefChange = _this.handleBibleRefChange.bind(_this);
    _this.handleBiblicalGreekLibraryChange = _this.handleBiblicalGreekLibraryChange.bind(_this);
    _this.handleBiblicalIdSelection = _this.handleBiblicalIdSelection.bind(_this);
    _this.handleBiblicalLemmaChange = _this.handleBiblicalLemmaChange.bind(_this);
    _this.handleBiblicalScopeChange = _this.handleBiblicalScopeChange.bind(_this);
    _this.handleBiblicalTranslationLibraryChange = _this.handleBiblicalTranslationLibraryChange.bind(_this);
    _this.handleCloseModalAddBiblio = _this.handleCloseModalAddBiblio.bind(_this);
    _this.handleDeleteCallback = _this.handleDeleteCallback.bind(_this);
    _this.handleEditableListCallback = _this.handleEditableListCallback.bind(_this);
    _this.handleEditorChange = _this.handleEditorChange.bind(_this);
    _this.handleFetchBibleTextCallback = _this.handleFetchBibleTextCallback.bind(_this);
    _this.handleFetchSuggestionsCallback = _this.handleFetchSuggestionsCallback.bind(_this);
    _this.handleLibrariesCallback = _this.handleLibrariesCallback.bind(_this);
    _this.handleLiturgicalHeadingLibraryChange = _this.handleLiturgicalHeadingLibraryChange.bind(_this);
    _this.handleLiturgicalIdSelection = _this.handleLiturgicalIdSelection.bind(_this);
    _this.handleLiturgicalLemmaChange = _this.handleLiturgicalLemmaChange.bind(_this);
    _this.handleLiturgicalScopeChange = _this.handleLiturgicalScopeChange.bind(_this);
    _this.handleLiturgicalSubHeadingLibraryChange = _this.handleLiturgicalSubHeadingLibraryChange.bind(_this);
    _this.handleNoteLibraryChange = _this.handleNoteLibraryChange.bind(_this);
    _this.handleNoteTypeChange = _this.handleNoteTypeChange.bind(_this);
    _this.handleOntologyRefChange = _this.handleOntologyRefChange.bind(_this);
    _this.handlePredecessorChange = _this.handlePredecessorChange.bind(_this);
    _this.handleTitleChange = _this.handleTitleChange.bind(_this);
    _this.handleWorkflowCallback = _this.handleWorkflowCallback.bind(_this);
    _this.mapTagsToObjectList = _this.mapTagsToObjectList.bind(_this);
    _this.noteFormatter = _this.noteFormatter.bind(_this);
    _this.onSubmit = _this.onSubmit.bind(_this);
    _this.settingsValid = _this.settingsValid.bind(_this);
    _this.submitPost = _this.submitPost.bind(_this);
    _this.submitPut = _this.submitPut.bind(_this);
    _this.validateForm = _this.validateForm.bind(_this);

    return _this;
  }

  TextNoteEditor.prototype.createMarkup = function createMarkup() {
    return { __html: this.state.form.valueFormatted };
  };

  TextNoteEditor.prototype.render = function render() {
    return React.createElement(
      'div',
      { className: 'App App-Text-Note-Editor' },
      this.state.showModalAddBiblio && this.getModalNewBiblioForm(),
      this.getLiturgicalView(),
      this.getBiblicalView(),
      React.createElement(
        'form',
        null,
        React.createElement(
          FormGroup,
          null,
          React.createElement(
            Well,
            null,
            React.createElement(
              Grid,
              null,
              React.createElement(
                Row,
                { className: 'App show-grid' },
                React.createElement(
                  Col,
                  { xs: 12, md: 12 },
                  React.createElement(
                    ControlLabel,
                    null,
                    this.state.labels.thisClass.note,
                    ': ',
                    this.state.selectedTypeLabel,
                    '.'
                  )
                )
              ),
              React.createElement(
                Row,
                { className: 'App show-grid  App-Text-Note-Editor-Row' },
                React.createElement(
                  Col,
                  { xs: 12, md: 12 },
                  this.getEditor()
                )
              ),
              this.getButtonRow(),
              React.createElement(
                HelpBlock,
                null,
                React.createElement(
                  'div',
                  null,
                  React.createElement(
                    'span',
                    { className: 'App App-message' },
                    React.createElement(FontAwesome, {
                      name: this.state.messageIcon }),
                    ' ',
                    this.state.message
                  )
                )
              )
            )
          )
        )
      ),
      this.getTabs()
    );
  };

  return TextNoteEditor;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {
    _this2.fetchSuggestions();
  };

  this.componentDidMount = function () {};

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;
    var thisClassLabels = labels[labelTopics.TextNoteEditor];
    var messages = labels[labelTopics.messages];
    var textIdParts = IdManager.getParts(nextProps.textId);
    var formIsValid = false;
    var created = false;
    if (_this2.state.created) {
      created = true;
    } else {
      if (nextProps.form && nextProps.form.noteType) {
        created = true;
      }
    }
    var form = {};
    var tags = [];
    var selectedTag = "";
    var selectedType = get(_this2.state, "selectedType", "");
    var selectedTypeLabel = get(_this2.state, "selectedTypeLabel", "");

    if (nextProps.form && nextProps.form.noteType) {
      form = nextProps.form;
      selectedType = form.noteType;
      selectedTypeLabel = _this2.getLabel(form.noteType);
    } else if (nextProps.session && nextProps.session.uiSchemas && nextProps.session.uiSchemas.getForm) {
      var uiSchemas = {};
      uiSchemas = new UiSchemas(nextProps.session.uiSchemas.formsDropdown, nextProps.session.uiSchemas.formsSchemas, nextProps.session.uiSchemas.forms);
      form = JSON.parse(JSON.stringify(uiSchemas.getForm("TextualNote:1.1")));
      form.liturgicalScope = textIdParts.key;
      form.library = nextProps.session.userInfo.domain;
      var key = _this2.getTimestamp();
      form.key = key;
      form.topic = "gr_gr_cog" + "~" + textIdParts.topic + "~" + textIdParts.key;
      form.id = form.library + "~" + form.topic + "~" + key;
      form.liturgicalGreekId = nextProps.textId;
      form.liturgicalTranslationId = form.topic;
      form.noteTitle = " ";
      formIsValid = true;
      selectedTag = form.tags[0];
      selectedType = form.noteType;
      selectedTypeLabel = _this2.getLabel(form.noteType);
      var j = form.tags.length;
      for (var i = 0; i < j; i++) {
        tags.push({ value: form.tags[i], label: form.tags[i] });
      }
    }
    var notesList = [];
    if (nextProps.notesList && nextProps.form) {
      notesList = nextProps.notesList;
    }
    notesList = notesList.filter(function (el) {
      return !el.id === nextProps.form.id;
    });

    var bibliographyDropdown = [];
    if (nextProps.session && nextProps.session.dropdowns) {
      bibliographyDropdown = nextProps.session.dropdowns.schemaEditorDropdown.filter(function (row) {
        return row.value.startsWith("BibEntry");
      });
    }

    _this2.setState(function (prevState, props) {
      return {
        labels: {
          thisClass: thisClassLabels,
          buttons: labels[labelTopics.button],
          messages: messages,
          resultsTableLabels: labels[labelTopics.resultsTable],
          search: labels[labelTopics.search]
        },
        message: get("message", _this2.state.message, messages.initial),
        note: form.valueFormatted,
        bibliographyDropdown: bibliographyDropdown,
        notesList: notesList,
        form: form,
        formIsValid: formIsValid,
        selectedTypeLabel: selectedTypeLabel,
        tags: tags,
        selectedTag: selectedTag,
        selectedType: selectedType,
        predecessorNote: get(_this2.state, "predecessorNote", ""),
        created: created
      };
    });
  };

  this.settingsValid = function () {
    var valid = false;
    if (_this2.state.form.noteType) {
      if (_this2.state.form.noteType === "REF_TO_BIBLE" || _this2.state.form.noteType === "CHECK_YOUR_BIBLE") {
        valid = _this2.state.form.liturgicalScope.length > 0 && _this2.state.form.liturgicalLemma.length > 0
        // && this.state.form.noteTitle.length > 0
        && _this2.state.form.biblicalScope.length > 0 && _this2.state.form.biblicalLemma.length > 0 && _this2.state.form.biblicalGreekId.length > 0;
      } else if (_this2.state.form.noteType.startsWith("REF_TO")) {
        valid = _this2.state.form.liturgicalScope.length > 0 && _this2.state.form.liturgicalLemma.length > 0 && _this2.state.form.ontologicalEntityId.length > 0;
      } else if (_this2.state.form.noteType === "UNIT") {
        valid = _this2.state.form.liturgicalScope.length > 0
        // && this.state.form.noteTitle.length > 0
        ;
      } else {
        valid = _this2.state.form.liturgicalScope.length > 0 && _this2.state.form.liturgicalLemma.length > 0
        // && this.state.form.noteTitle.length > 0
        ;
      }
    }
    return valid;
  };

  this.validateForm = function () {
    var message = _this2.state.labels.thisClass.requiredMsg;
    var messageIcon = MessageIcons.getMessageIcons().warning;
    var formIsValid = false;
    var noteValid = _this2.state.form.valueFormatted.length > 0;
    if (_this2.settingsValid() && noteValid) {
      formIsValid = true;
      message = _this2.state.labels.messages.ok;
      messageIcon = MessageIcons.getMessageIcons().info;
    }
    _this2.setState({
      formIsValid: formIsValid,
      message: message,
      messageIcon: messageIcon
    });
  };

  this.handleAddButtonClick = function () {
    _this2.setState({ showModalAddBiblio: true });
  };

  this.getModalNewBiblioForm = function () {
    return React.createElement(GenericModalNewEntryForm, {
      session: _this2.props.session,
      restPath: Server.getDbServerDocsApi(),
      onClose: _this2.handleCloseModalAddBiblio,
      schemaTypes: _this2.state.bibliographyDropdown,
      title: _this2.state.labels.thisClass.createTitle
    });
  };

  this.getTimestamp = function () {
    var date = new Date();
    var month = (date.getMonth() + 1).toString().padStart(2, "0");
    var day = date.getDate().toString().padStart(2, "0");
    var hour = date.getHours().toString().padStart(2, "0");
    var minute = date.getMinutes().toString().padStart(2, "0");
    var second = date.getSeconds().toString().padStart(2, "0");
    var timestamp = date.getFullYear() + "." + month + "." + day + ".T" + hour + "." + minute + "." + second;
    return timestamp;
  };

  this.handleEditorChange = function (plain, html) {
    var form = _this2.state.form;
    form.value = plain;
    form.valueFormatted = html;
    _this2.setState({ form: form }, _this2.validateForm);
  };

  this.handleCloseModalAddBiblio = function () {
    _this2.setState({ showModalAddBiblio: false });
  };

  this.onSubmit = function () {
    if (_this2.state.created) {
      _this2.submitPut();
    } else {
      _this2.submitPost();
    }
  };

  this.submitPost = function () {
    var formData = _this2.state.form;
    if (!formData.liturgicalTranslationId) {
      formData.liturgicalTranslationId = _this2.props.noteIdTopic;
    }

    _this2.setState({
      message: _this2.state.labels.messages.creating,
      messageIcon: _this2.state.messageIcons.info
    });

    var config = {
      auth: {
        username: _this2.props.session.userInfo.username,
        password: _this2.props.session.userInfo.password
      }
    };
    var path = _this2.props.session.restServer + Server.getDbServerNotesApi();
    axios.post(path, formData, config).then(function (response) {
      _this2.setState({
        message: _this2.state.labels.messages.created,
        form: formData,
        created: true
      });
      if (_this2.props.onSubmit) {
        _this2.props.onSubmit(formData);
      }
    }).catch(function (error) {
      var message = error.message;
      var messageIcon = _this2.state.messageIcons.error;
      _this2.setState({
        message: message,
        messageIcon: messageIcon
      });
    });
  };

  this.submitPut = function () {
    var formData = _this2.state.form;
    if (!formData.liturgicalTranslationId) {
      formData.liturgicalTranslationId = _this2.props.noteIdTopic;
    }
    _this2.setState({
      message: _this2.state.labels.messages.updating,
      messageIcon: _this2.state.messageIcons.info
    });

    var config = {
      auth: {
        username: _this2.props.session.userInfo.username,
        password: _this2.props.session.userInfo.password
      }
    };
    var path = _this2.props.session.restServer + Server.getDbServerNotesApi() + "/" + formData.library + "/" + formData.topic + "/" + formData.key;
    axios.put(path, formData, config).then(function (response) {
      var message = _this2.state.labels.messages.updated;
      _this2.setState({
        message: message,
        form: formData
      });
      if (_this2.props.onSubmit) {
        _this2.props.onSubmit(formData);
      }
    }).catch(function (error) {
      var message = Labels.getHttpMessage(_this2.props.session.languageCode, error.response.status, error.response.statusText);
      var messageIcon = _this2.state.messageIcons.error;
      _this2.setState({ data: message, message: message, messageIcon: messageIcon });
    });
  };

  this.fetchSuggestions = function () {
    var parms = "t=" + encodeURIComponent(_this2.state.topic) + "&l=" + encodeURIComponent(_this2.state.libraries);

    _this2.setState({
      message: _this2.state.labels.messages.retrieving
    }, Server.restGetSuggestions(_this2.props.session.restServer, _this2.props.session.userInfo.username, _this2.props.session.userInfo.password, _this2.props.session.userInfo.domain, _this2.handleFetchSuggestionsCallback));
  };

  this.fetchBibleText = function () {
    var parms = "t=" + encodeURIComponent(_this2.state.topic) + "&l=" + encodeURIComponent(_this2.state.libraries);

    _this2.setState({
      message: _this2.state.labels.messages.retrieving
    }, Server.getViewForTopic(_this2.props.session.restServer, _this2.props.session.userInfo.username, _this2.props.session.userInfo.password, parms, _this2.handleFetchCallback));
  };

  this.handleWorkflowCallback = function (visibility, status, assignedTo) {
    if (visibility && status) {
      var statusIcon = "check";
      var visibilityIcon = "globe";

      switch (visibility) {
        case "PERSONAL":
          {
            visibilityIcon = "lock"; // user-secret
            break;
          }
        case "PRIVATE":
          {
            visibilityIcon = "share-alt";
            break;
          }
        default:
          {}
      }
      switch (status) {
        case "EDITING":
          {
            statusIcon = "edit";
            break;
          }
        case "REVIEWING":
          {
            statusIcon = "eye-open";
            break;
          }
        default:
          {}
      }
      var form = _this2.state.form;
      form.status = status;
      form.visibility = visibility;
      form.assignedToUser = assignedTo;

      _this2.setState({
        form: form,
        workflow: {
          visibilityIcon: visibilityIcon,
          statusIcon: statusIcon
        }
      });
    }
  };

  this.handleFetchSuggestionsCallback = function (restCallResult) {
    if (restCallResult) {
      var abbreviations = [];
      var bibliography = [];
      if (restCallResult.data.values.length > 1) {
        bibliography = restCallResult.data.values[1]["bibliography"];
      }
      if (restCallResult.data.values.length > 0) {
        abbreviations = restCallResult.data.values[0]["abbreviations"];
      }
      var suggestAbr = abbreviations.map(function (o) {
        return { text: o.key + " - " + o.value, value: o.key, url: o.id };
      });
      var suggestBib = bibliography.map(function (o) {
        var author = "";
        var date = "";
        if (has(o, "author")) {
          author = o.author;
        } else if (has(o, "editor")) {
          author = o.editor;
        }
        if (has(o, "date")) {
          date = o.date;
        } else if (has(o, "year")) {
          date = o.year;
        }
        var result = o.key + " - ";
        if (author.length > 0) {
          result += author;
        }
        if (date.length > 0) {
          result += " (" + date + "). ";
        }
        result += o.title;
        // TODO:  currently in OWL, the hyperlink for citation does not work.
        // Probably you need to do something with url: o.id below, e.g.
        // prepend with /data
        return { text: result, value: o.key, url: o.id };
      });

      _this2.setState({
        abbreviations: abbreviations,
        bibliography: bibliography,
        suggestAbbreviations: suggestAbr,
        suggestBibliography: suggestBib,
        suggestions: suggestBib,
        message: _this2.state.labels.messages.ok
      });
    }
  };

  this.handleFetchBibleTextCallback = function (restCallResult) {
    if (restCallResult) {
      var data = restCallResult.data.values[0];
      var about = data.about;
      var templateKeys = data.templateKeys;
      var libraryKeys = data.libraryKeys;
      var libraryKeyValues = data.libraryKeyValues;
      _this2.setState({
        dataFetched: true,
        about: about,
        libraryKeyValues: libraryKeyValues,
        libraryKeys: libraryKeys,
        templateKeys: templateKeys,
        message: _this2.state.labels.messages.found + " " + templateKeys.length + " " + _this2.state.labels.messages.docs,
        messageIcon: restCallResult.messageIcon,
        resultCount: templateKeys.length
      }, _this2.setTableData);
    }
  };

  this.handleEditableListCallback = function (value, values) {
    var form = _this2.state.form;
    form.tags = values.map(function (item) {
      return item['label'].trim();
    });
    _this2.setState({ form: form, selectedTag: value, tags: values });
  };

  this.handleBiblicalScopeChange = function (e) {
    var form = _this2.state.form;
    form.biblicalScope = e.target.value;
    _this2.setState({ form: form }, _this2.validateForm);
  };

  this.handleLiturgicalScopeChange = function (e) {
    var form = _this2.state.form;
    form.liturgicalScope = e.target.value;
    _this2.setState({ form: form }, _this2.validateForm);
  };

  this.handleNoteTypeChange = function (selection) {
    var form = _this2.state.form;
    form.noteType = selection["value"];
    form.biblicalGreekId = "";
    form.biblicalLemma = "";
    form.biblicalScope = "";
    form.biblicalTranslationId = "";
    form.ontologicalEntityId = "";

    // For all note types, we use gr_gr_cog as the library of the form.topic ID.
    // But, a translator's note is for a specific translation.  So we will use the
    // library from the translation.
    if (selection["value"] === "TRANSLATORS_NOTE") {
      var textIdParts = IdManager.getParts(_this2.props.textId);
      form.topic = textIdParts.library + "~" + textIdParts.topic + "~" + textIdParts.key;
      form.id = form.library + "~" + form.topic + "~" + form.key;
      form.liturgicalGreekId = form.topic;
    }
    _this2.setState({
      form: form,
      selectedTypeLabel: selection["label"],
      selectedBiblicalIdParts: [{ key: "domain", label: "*" }, { key: "topic", label: "" }, { key: "key", label: "" }],
      showBibleView: false,
      ontologyRefType: "",
      ontologyRefName: "",
      showOntologyView: false
    }, _this2.validateForm);
  };

  this.handleBibleRefChange = function (book, chapter, verse, citeBible) {
    var form = _this2.state.form;
    var showBibleView = false;
    if (book.length > 0 && chapter.length > 0 && verse.length > 0) {
      showBibleView = true;
      form.biblicalScope = citeBible;
      var library = "";
      if (_this2.state.selectedBiblicalLibrary) {
        library = _this2.state.selectedBiblicalLibrary;
      }
      form.biblicalGreekId = library + "~" + book + "~" + chapter + ":" + verse;
    }
    _this2.setState({
      selectedBiblicalIdParts: [{ key: "domain", label: "*" }, { key: "topic", label: book }, { key: "key", label: chapter + ":" + verse }],
      showBibleView: showBibleView,
      form: form,
      selectedBiblicalBook: book,
      selectedBiblicalChapter: chapter,
      selectedBiblicalVerse: verse,
      citeBible: citeBible
    }, _this2.validateForm);
  };

  this.handleOntologyRefChange = function (entityId, entityName) {
    var showOntologyView = false;
    if (entityId.length > 0) {
      showOntologyView = true;
    }
    var form = _this2.state.form;
    form.ontologicalEntityId = entityId;
    form.noteTitle = entityName;

    _this2.setState({
      form: form,
      ontologyRefEntityName: entityName,
      showOntologyView: showOntologyView,
      title: entityName
    }, _this2.validateForm);
  };

  this.handleBiblicalLemmaChange = function (e) {
    var form = _this2.state.form;
    form.biblicalLemma = e.target.value;
    _this2.setState({ form: form }, _this2.validateForm);
  };

  this.handleLiturgicalLemmaChange = function (e) {
    var form = _this2.state.form;
    form.liturgicalLemma = e.target.value;
    _this2.setState({ form: form }, _this2.validateForm);
  };

  this.handleTitleChange = function (e) {
    var form = _this2.state.form;
    form.noteTitle = e.target.value;
    _this2.setState({ form: form }, _this2.validateForm);
  };

  this.getBibleRefRow = function () {
    if (_this2.state.form.noteType && (_this2.state.form.noteType === "REF_TO_BIBLE" || _this2.state.form.noteType === "CHECK_YOUR_BIBLE")) {
      return React.createElement(BibleRefSelector, {
        session: _this2.props.session,
        callback: _this2.handleBibleRefChange,
        book: _this2.state.selectedBiblicalBook,
        chapter: _this2.state.selectedBiblicalChapter,
        verse: _this2.state.selectedBiblicalVerse
      });
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.getOntologyRefRow = function () {
    if (_this2.state.form.noteType && _this2.state.form.noteType.startsWith("REF_TO") && _this2.state.form.noteType !== ("REF_TO_BIBLE" && _this2.state.form.noteType !== "CHECK_YOUR_BIBLE")) {
      var type = _this2.getOntologyLabel(_this2.state.form.noteType);
      return React.createElement(
        Row,
        { className: 'App show-grid App-Ontology-Ref-Selector-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.refersTo,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(
            'div',
            { className: "App App-Ontology-Ref-Selector-Entity" },
            React.createElement(OntologyRefSelector, {
              session: _this2.props.session,
              type: type,
              callback: _this2.handleOntologyRefChange,
              initialValue: _this2.state.form.ontologicalEntityId
            })
          )
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.getOntologyLabel = function (type) {
    try {
      var label = type.split("_")[2];
      return label.charAt(0) + label.slice(1).toLowerCase();
    } catch (err) {
      return type;
    }
  };

  this.getLiturgicalView = function () {
    return React.createElement(
      Accordion,
      null,
      React.createElement(
        Panel,
        { header: _this2.state.labels.thisClass.viewLiturgicalText, eventKey: 'TextNoteEditor' },
        React.createElement(CompareDocs, {
          session: _this2.props.session,
          handleRowSelect: _this2.handleLiturgicalIdSelection,
          title: "Liturgical Texts",
          docType: "Liturgical",
          selectedIdParts: _this2.state.selectedLiturgicalIdParts,
          labels: _this2.state.labels.search,
          librariesInfoCallback: _this2.handleLibrariesCallback
        })
      )
    );
  };

  this.handleLiturgicalIdSelection = function (row) {
    // let form = this.state.form;
    // let id = row["id"];
    // if (id.startsWith("gr_")) {
    //   if (form.selected)
    //   form.liturgicalGreekId = id;
    //   this.setState({ form: form, selectedLiturgicalHeadingId: id })
    // } else {
    //   form.liturgicalTranslationId = id;
    //   this.setState({ form: form, selectedLiturgicalSubHeadingId: id })
    // }
  };

  this.handleBiblicalIdSelection = function (row) {
    // let id = row["id"];
    // let form = this.state.form;
    // let biblicalIdParts = IdManager.getParts(id);
    //
    // if (id.startsWith("gr_")) {
    //   form.biblicalGreekId = id;
    //   this.setState({
    //     form: form
    //     , selectedBiblicalGreekId: id
    //     , selectedBiblicalLibrary: biblicalIdParts.library
    //   })
    // } else {
    //   form.biblicalTranslationId = id;
    //   this.setState({ form: form, selectedBiblicalTranslationId: id })
    // }
  };

  this.handleLibrariesCallback = function (type, id, libraries) {
    if (libraries) {
      var form = _this2.state.form;

      var librariesDropdown = libraries.map(function (row) {
        return { label: row.library, value: row.id };
      });

      var greekDropdown = libraries.filter(function (row) {
        return row.library.startsWith("gr_");
      }).map(function (row) {
        return { label: row.library, value: row.id };
      });

      var translationDropdown = libraries.filter(function (row) {
        return !row.library.startsWith("gr_");
      }).map(function (row) {
        return { label: row.library, value: row.id };
      });

      if (type === "Biblical") {
        var biblicalIdParts = IdManager.getParts(id);
        var selectedBiblicalLibrary = biblicalIdParts.library;
        form.biblicalGreekId = id;
        _this2.setState({
          form: form,
          biblicalLibraries: {
            greekBibleId: id,
            libraries: libraries,
            greekDropdown: greekDropdown,
            translationDropdown: translationDropdown
          },
          selectedBiblicalGreekId: id,
          selectedBiblicalLibrary: selectedBiblicalLibrary
        });
      } else {
        //        form.liturgicalGreekId = id;
        _this2.setState({
          form: form,
          liturgicalLibraries: {
            greekBibleId: id,
            libraries: libraries,
            greekDropdown: greekDropdown,
            translationDropdown: translationDropdown,
            librariesDropdown: librariesDropdown
          },
          selectedLiturgicalSubHeadingId: id
        });
      }
    }
  };

  this.getBiblicalView = function () {
    if (_this2.state.showBibleView) {
      return React.createElement(
        Accordion,
        null,
        React.createElement(
          Panel,
          { header: _this2.state.labels.thisClass.viewBiblicalText + ": " + _this2.state.citeBible, eventKey: 'TextNoteEditor' },
          React.createElement(CompareDocs, {
            session: _this2.props.session,
            handleRowSelect: _this2.handleBiblicalIdSelection,
            librariesInfoCallback: _this2.handleLibrariesCallback,
            title: "Biblical Texts",
            docType: "Biblical",
            selectedIdParts: _this2.state.selectedBiblicalIdParts,
            labels: _this2.state.labels.search
          })
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.getLiturgicalScopeRow = function () {
    return React.createElement(
      Row,
      { className: 'App show-grid  App-Text-Note-Editor-Scope-Row' },
      React.createElement(
        Col,
        { xs: 3, md: 3 },
        React.createElement(
          ControlLabel,
          null,
          _this2.state.labels.thisClass.liturgicalScope,
          ':'
        )
      ),
      React.createElement(
        Col,
        { xs: 9, md: 9 },
        React.createElement(FormControl, {
          id: "fxLiturgicalScope",
          className: "App App-Text-Note-Editor-Scope",
          type: 'text',
          value: _this2.state.form.liturgicalScope,
          placeholder: _this2.state.labels.thisClass.liturgicalScope,
          onChange: _this2.handleLiturgicalScopeChange
        })
      )
    );
  };

  this.getLiturgicalLemmaRow = function () {
    if (_this2.state.form.noteType === "UNIT") {
      return React.createElement('span', { className: 'App App-no-display' });
    } else {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Lemma-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.liturgicalLemma,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(FormControl, {
            id: "fcLiturgicalLemma",
            className: "App App-Text-Note-Editor-Lemma",
            type: 'text',
            value: _this2.state.form.liturgicalLemma,
            placeholder: _this2.state.labels.thisClass.liturgicalLemma,
            onChange: _this2.handleLiturgicalLemmaChange
          })
        )
      );
    }
  };

  this.handleNoteLibraryChange = function (selection) {
    var form = _this2.state.form;
    form.library = selection["value"];
    _this2.setState({ form: form }, _this2.validateForm);
  };

  this.handlePredecessorChange = function (selection) {
    var form = _this2.state.form;
    var predecessorId = selection["id"];
    form.followsNoteId = predecessorId;
    var selectRow = _this2.state.selectRow;
    selectRow["selected"] = [predecessorId];
    _this2.setState({
      predecessorNote: predecessorId,
      form: form,
      selectRow: selectRow
    });
  };

  this.getNoteLibraryRow = function () {
    if (_this2.props.session.userInfo.domains.author && _this2.state.form && _this2.state.form.library && _this2.state.form.library.length < 1) {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Library-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.noteLibrary,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(ResourceSelector, {
            title: "",
            initialValue: _this2.props.session.userInfo.domain,
            resources: _this2.props.session.userInfo.domains.author,
            changeHandler: _this2.handleNoteLibraryChange,
            multiSelect: false
          })
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.getNoteIdRow = function () {
    if (_this2.state.form && _this2.state.form.id) {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Library-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.id,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.form.id
          )
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.noteFormatter = function (cell, row, formatExtraData) {
    if (row && row["type"]) {
      return React.createElement(FormattedTextNote, {
        session: formatExtraData,
        note: row["valueFormatted"],
        type: row["type"],
        title: row["title"],
        scopeLiturgical: row["liturgicalScope"],
        lemmaLiturgical: row["liturgicalLemma"],
        scopeBiblical: row["biblicalScope"],
        lemmaBiblical: row["biblicalLemma"]
      });
    }
  };

  this.getNoteOrderingRow = function () {
    if (_this2.props.notesList && _this2.state.labels.resultsTableLabels) {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Order-Row' },
        React.createElement(
          Col,
          { xs: 12, md: 12 },
          React.createElement(
            BootstrapTable,
            {
              ref: 'theOrderTable',
              data: _this2.state.notesList,
              exportCSV: false,
              trClassName: "App-data-tr",
              striped: true,
              hover: true,
              pagination: true,
              options: _this2.state.options,
              selectRow: _this2.state.selectRow
            },
            React.createElement(
              TableHeaderColumn,
              {
                isKey: true,
                dataField: 'id',
                dataSort: true,
                'export': true,
                hidden: true
              },
              'ID'
            ),
            React.createElement(
              TableHeaderColumn,
              {
                dataField: 'type',
                dataSort: true,
                tdClassname: 'tdType',
                filter: _this2.state.filter
              },
              _this2.state.labels.resultsTableLabels.headerType
            ),
            React.createElement(
              TableHeaderColumn,
              {
                dataField: 'liturgicalLemma',
                dataSort: true,
                tdClassname: 'tdType',
                hidden: true
              },
              _this2.state.labels.resultsTableLabels.headerLemma
            ),
            React.createElement(
              TableHeaderColumn,
              {
                dataField: 'liturgicalScope',
                dataSort: true,
                tdClassname: 'tdType',
                hidden: true
              },
              _this2.state.labels.resultsTableLabels.headerScope
            ),
            React.createElement(
              TableHeaderColumn,
              {
                dataField: 'valueFormatted',
                dataSort: true,
                width: "85%",
                filter: _this2.state.filter,
                dataFormat: _this2.noteFormatter,
                formatExtraData: _this2.props.session
              },
              _this2.state.labels.resultsTableLabels.headerNote
            )
          )
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.handleBiblicalTranslationLibraryChange = function (selection) {
    var form = _this2.state.form;
    form.biblicalTranslationId = selection["value"];
    _this2.setState({ form: form }, _this2.validateForm);
  };

  this.getBiblicalTranslationLibraryRow = function () {
    if (_this2.state.form.noteType && (_this2.state.form.noteType === "REF_TO_BIBLE" || _this2.state.form.noteType === "CHECK_YOUR_BIBLE") && _this2.state.biblicalLibraries) {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Library-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.biblicalTranslationLibrary,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(ResourceSelector, {
            title: "",
            initialValue: _this2.state.form.biblicalTranslationId,
            resources: _this2.state.biblicalLibraries.translationDropdown,
            changeHandler: _this2.handleBiblicalTranslationLibraryChange,
            multiSelect: false
          })
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.handleLiturgicalHeadingLibraryChange = function (selection) {
    var form = _this2.state.form;
    form.liturgicalGreekId = selection["value"];
    var textIdParts = IdManager.getParts(selection["value"]);
    _this2.setState({
      form: form,
      textIdParts: textIdParts,
      selectedLiturgicalHeadingId: selection["value"]
    }, _this2.validateForm);
  };

  this.getLiturgicalHeadingLibraryRow = function () {
    if (_this2.state.liturgicalLibraries) {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Library-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.liturgicalHeadingLibrary,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(ResourceSelector, {
            title: "",
            initialValue: _this2.state.form.liturgicalGreekId,
            resources: _this2.state.liturgicalLibraries.librariesDropdown,
            changeHandler: _this2.handleLiturgicalHeadingLibraryChange,
            multiSelect: false
          })
        )
      );
    } else {
      return React.createElement(
        'div',
        null,
        React.createElement(Spinner, { message: _this2.state.labels.messages.retrieving })
      );
    }
  };

  this.handleBiblicalGreekLibraryChange = function (selection) {
    var form = _this2.state.form;
    form.biblicalGreekId = selection["value"];
    _this2.setState({
      form: form,
      selectedBiblicalGreekId: selection["value"]
    }, _this2.validateForm);
  };

  this.getBiblicalGreekLibraryRow = function () {
    if (_this2.state.form.noteType && (_this2.state.form.noteType === "REF_TO_BIBLE" || _this2.state.form.noteType === "CHECK_YOUR_BIBLE")) {
      if (_this2.state.biblicalLibraries) {
        return React.createElement(
          Row,
          { className: 'App show-grid  App-Text-Note-Editor-Library-Row' },
          React.createElement(
            Col,
            { xs: 3, md: 3 },
            React.createElement(
              ControlLabel,
              null,
              _this2.state.labels.thisClass.biblicalGreekLibrary,
              ':'
            )
          ),
          React.createElement(
            Col,
            { xs: 9, md: 9 },
            React.createElement(ResourceSelector, {
              title: "",
              initialValue: _this2.state.selectedBiblicalGreekId,
              resources: _this2.state.biblicalLibraries.greekDropdown,
              changeHandler: _this2.handleBiblicalGreekLibraryChange,
              multiSelect: false
            })
          )
        );
      } else {
        return React.createElement(
          'div',
          null,
          React.createElement(Spinner, { message: _this2.state.labels.messages.retrieving })
        );
      }
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.handleLiturgicalSubHeadingLibraryChange = function (selection) {
    var form = _this2.state.form;
    form.liturgicalTranslationId = selection["value"];
    _this2.setState({ form: form, selectedLiturgicalSubHeadingId: selection["value"] }, _this2.validateForm);
  };

  this.getLiturgicalSubHeadingLibraryRow = function () {
    if (_this2.state.liturgicalLibraries && _this2.state.liturgicalLibraries.librariesDropdown) {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Library-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.liturgicalSubHeadingLibrary,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(ResourceSelector, {
            title: "",
            initialValue: _this2.state.form.liturgicalTranslationId,
            resources: _this2.state.liturgicalLibraries.librariesDropdown,
            changeHandler: _this2.handleLiturgicalSubHeadingLibraryChange,
            multiSelect: false
          })
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.getTitleRow = function () {
    if (_this2.state.form.noteType && _this2.state.form.noteType.startsWith("REF_TO") && _this2.state.form.noteType !== "REF_TO_BIBLE" && _this2.state.form.noteType !== "CHECK_YOUR_BIBLE") {
      return React.createElement('span', { className: 'App App-no-display' });
    } else {
      return React.createElement(
        Row,
        { className: 'App show-grid App-Text-Note-Editor-Title-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.title,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(FormControl, {
            id: "fxEditorTitle",
            className: "App App-Text-Note-Editor-Title",
            type: 'text',
            value: _this2.state.form.noteTitle,
            placeholder: _this2.state.labels.thisClass.title,
            onChange: _this2.handleTitleChange
          })
        )
      );
    }
  };

  this.getBiblicalScopeRow = function () {
    if (_this2.state.form.noteType && (_this2.state.form.noteType === "REF_TO_BIBLE" || _this2.state.form.noteType === "CHECK_YOUR_BIBLE")) {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Scope-Biblical-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.biblicalScope,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(FormControl, {
            id: "fxEditorBiblicalScope",
            className: "App App-Text-Note-Editor-Scope",
            type: 'text',
            value: _this2.state.form.biblicalScope,
            placeholder: _this2.state.labels.thisClass.biblicalScope,
            onChange: _this2.handleBiblicalScopeChange
          })
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.getBiblicalLemmaRow = function () {
    if (_this2.state.form.noteType && (_this2.state.form.noteType === "REF_TO_BIBLE" || _this2.state.form.noteType === "CHECK_YOUR_BIBLE")) {
      return React.createElement(
        Row,
        { className: 'App show-grid  App-Text-Note-Editor-Lemma-Row' },
        React.createElement(
          Col,
          { xs: 3, md: 3 },
          React.createElement(
            ControlLabel,
            null,
            _this2.state.labels.thisClass.biblicalLemma,
            ':'
          )
        ),
        React.createElement(
          Col,
          { xs: 9, md: 9 },
          React.createElement(FormControl, {
            id: "fcBibLemma",
            className: "App App-Text-Note-Editor-Lemma",
            type: 'text',
            value: _this2.state.form.biblicalLemma,
            placeholder: _this2.state.labels.thisClass.biblicalLemma,
            onChange: _this2.handleBiblicalLemmaChange
          })
        )
      );
    } else {
      return React.createElement('span', { className: 'App App-no-display' });
    }
  };

  this.getNoteTypeRow = function () {

    var dropdowns = _this2.props.session.dropdowns.noteTypesDropdown;

    if (_this2.props.session.userInfo.domain === "en_us_epentiuc") {
      dropdowns = _this2.props.session.dropdowns.noteTypesBilDropdown;
    }
    return React.createElement(
      Row,
      { className: 'App show-grid App-Text-Note-Editor-Type-Row' },
      React.createElement(
        Col,
        { xs: 3, md: 3 },
        React.createElement(
          ControlLabel,
          null,
          _this2.state.labels.thisClass.type,
          ':'
        )
      ),
      React.createElement(
        Col,
        { xs: 9, md: 9 },
        React.createElement(
          'div',
          { className: "App App-Text-Note-Type-Selector" },
          React.createElement(ResourceSelector, {
            title: "",
            initialValue: _this2.state.form.noteType,
            resources: dropdowns,
            changeHandler: _this2.handleNoteTypeChange,
            multiSelect: false
          })
        )
      )
    );
  };

  this.handleDeleteCallback = function (result) {
    _this2.props.deleteCallback();
  };

  this.getButtonRow = function () {
    var submitButtonDisabled = true;

    if (_this2.state.formIsValid) {
      submitButtonDisabled = false;
    }
    return React.createElement(
      Row,
      { className: 'App show-grid App-Text-Note-Editor-Button-Row' },
      React.createElement(
        Col,
        { xs: 10, md: 10 },
        React.createElement(
          Button,
          {
            className: 'App App-Button',
            bsStyle: 'primary',
            disabled: submitButtonDisabled,
            onClick: _this2.onSubmit
          },
          _this2.state.labels.buttons.save
        ),
        React.createElement(
          'span',
          { className: 'App App-Text-Editor-Workflow-Glyph' },
          React.createElement(Glyphicon, { glyph: _this2.state.workflow.statusIcon }),
          React.createElement(FontAwesome, { name: _this2.state.workflow.visibilityIcon })
        ),
        _this2.props.session && _this2.props.form && _this2.props.form.noteType && React.createElement(DeleteButton, {
          session: _this2.props.session,
          idLibrary: _this2.state.form.library,
          idTopic: _this2.state.form.topic,
          idKey: _this2.state.form.key,
          onDelete: _this2.handleDeleteCallback
        })
      ),
      React.createElement(
        Col,
        { xs: 2, md: 2 },
        React.createElement(
          Button,
          {
            className: 'App-Add-Biblio-Button',
            bsStyle: 'primary',
            onClick: _this2.handleAddButtonClick },
          React.createElement(Glyphicon, { glyph: "book" })
        )
      )
    );
  };

  this.mapTagsToObjectList = function (tags) {
    var list = [];
    var j = tags.length;
    for (var i = 0; i < j; i++) {
      var v = tags[i];
      list.push({ value: v, label: v });
    }
    return list;
  };

  this.getTagsRow = function () {
    return React.createElement(
      Well,
      { className: 'App App-Text-Note-Editor-Button-Row' },
      React.createElement(EditableSelector, {
        session: _this2.props.session,
        initialValue: _this2.state.selectedTag,
        options: _this2.state.tags,
        changeHandler: _this2.handleEditableListCallback,
        title: "",
        multiSelect: false })
    );
  };

  this.getRevisionsPanel = function () {
    return React.createElement(
      Well,
      null,
      'revisions will appear here'
    );
  };

  this.getWorkflowPanel = function () {
    return React.createElement(WorkflowForm, {
      session: _this2.props.session,
      callback: _this2.handleWorkflowCallback,
      library: _this2.state.form.library,
      status: _this2.state.form.status,
      visibility: _this2.state.form.visibility
    });
  };

  this.getLabel = function (type) {
    var label = "";
    var targetValue = type;
    if (_this2.props.session && _this2.props.session.dropdowns) {
      if (!type) {
        targetValue = _this2.props.form.noteType;
      }
      var j = _this2.props.session.dropdowns.noteTypesDropdown.length;
      for (var i = 0; i < j; i++) {
        var o = _this2.props.session.dropdowns.noteTypesDropdown[i];
        if (o.value === targetValue) {
          label = o.label;
          break;
        }
      }
    }
    return label;
  };

  this.getFormattedHeaderRow = function () {
    return React.createElement(
      Well,
      null,
      React.createElement(
        'div',
        { className: 'App App-Text-Note-formatted' },
        React.createElement(
          'div',
          { className: 'App App-Text-Note-Type' },
          React.createElement(Glyphicon, { className: 'App App-Text-Note-Type-Glyph', glyph: "screenshot" }),
          React.createElement(
            'span',
            { className: 'App App-Text-Note-Type-As-Heading' },
            _this2.state.selectedTypeLabel
          ),
          React.createElement(Glyphicon, { className: 'App App-Text-Note-Type-Glyph', glyph: "screenshot" })
        ),
        _this2.getFormattedView()
      )
    );
  };

  this.getFormattedView = function () {
    return React.createElement(FormattedTextNote, {
      session: _this2.props.session,
      note: _this2.state.form.valueFormatted,
      type: _this2.state.form.noteType,
      title: _this2.state.form.noteTitle,
      scopeLiturgical: _this2.state.form.liturgicalScope,
      lemmaLiturgical: _this2.state.form.liturgicalLemma,
      lemmaBiblical: _this2.state.form.biblicalLemma,
      scopeBiblical: _this2.state.form.biblicalScope,
      ontologyRefEntityName: _this2.state.ontologyRefEntityName
    });
  };

  this.getIdsWell = function () {
    return React.createElement(
      Well,
      null,
      React.createElement(
        ControlLabel,
        null,
        _this2.state.labels.thisClass.dbIds
      ),
      React.createElement(
        Grid,
        null,
        _this2.getNoteLibraryRow(),
        _this2.getLiturgicalHeadingLibraryRow(),
        _this2.getLiturgicalSubHeadingLibraryRow(),
        _this2.getBiblicalGreekLibraryRow(),
        _this2.getBiblicalTranslationLibraryRow(),
        _this2.getNoteIdRow()
      )
    );
  };

  this.getOrderWell = function () {
    return React.createElement(
      Well,
      null,
      React.createElement(
        ControlLabel,
        null,
        _this2.state.labels.thisClass.selectPredecessor,
        ':'
      ),
      React.createElement(
        Grid,
        null,
        _this2.getNoteOrderingRow()
      )
    );
  };

  this.getSettingsWell = function () {
    return React.createElement(
      Well,
      null,
      React.createElement(
        Grid,
        null,
        _this2.getNoteTypeRow(),
        _this2.getLiturgicalScopeRow(),
        _this2.getLiturgicalLemmaRow(),
        _this2.getBibleRefRow(),
        _this2.getBiblicalScopeRow(),
        _this2.getBiblicalLemmaRow(),
        _this2.getOntologyRefRow()
      )
    );
  };

  this.getTabs = function () {
    if (_this2.state.form) {
      return React.createElement(
        Well,
        null,
        React.createElement(
          Tabs,
          { id: 'App-Text-Node-Editor-Tabs', defaultActiveKey: "heading", animation: false },
          React.createElement(
            Tab,
            { eventKey: "heading", title: _this2.state.labels.thisClass.settings },
            _this2.getSettingsWell()
          ),
          React.createElement(
            Tab,
            { eventKey: "formattedheading", title: _this2.state.labels.thisClass.viewFormattedNote },
            _this2.getFormattedHeaderRow()
          ),
          React.createElement(
            Tab,
            { eventKey: "idsheading", title: _this2.state.labels.thisClass.ids },
            _this2.getIdsWell()
          ),
          React.createElement(
            Tab,
            { eventKey: "revisions", title: _this2.state.labels.thisClass.revisions },
            _this2.getRevisionsPanel()
          ),
          React.createElement(
            Tab,
            { eventKey: "tags", title: _this2.state.labels.thisClass.tags },
            _this2.getTagsRow()
          ),
          React.createElement(
            Tab,
            { eventKey: "workflow", title: _this2.state.labels.thisClass.workflow },
            _this2.getWorkflowPanel()
          )
        )
      );
    } else {
      return React.createElement(
        'div',
        null,
        React.createElement(Spinner, { message: _this2.state.labels.messages.retrieving })
      );
    }
  };

  this.getEditor = function () {
    if (_this2.state.form) {
      return React.createElement(RichEditor, {
        session: _this2.props.session,
        handleEditorChange: _this2.handleEditorChange,
        content: _this2.state.form.valueFormatted,
        suggestions: _this2.state.suggestions
      });
    } else {
      return React.createElement(
        'div',
        null,
        React.createElement(Spinner, { message: _this2.state.labels.messages.retrieving })
      );
    }
  };
}, _temp);


process.env.NODE_ENV !== "production" ? TextNoteEditor.propTypes = {
  session: PropTypes.object.isRequired,
  onEditorChange: PropTypes.func.isRequired,
  textId: PropTypes.string.isRequired,
  form: PropTypes.object,
  notesList: PropTypes.array,
  deleteCallback: PropTypes.func.isRequired
} : void 0;

// set default values for props here
TextNoteEditor.defaultProps = {};

export default TextNoteEditor;