var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import axios from 'axios';
import { get } from 'lodash';
import ModalTextNoteEditor from './modules/ModalTextNoteEditor';
import FontAwesome from 'react-fontawesome';
import { Button, ButtonGroup, ControlLabel, FormControl, FormGroup, Panel, PanelGroup } from 'react-bootstrap';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import Server from './helpers/Server';
import IdManager from './helpers/IdManager';
import FormattedTextNote from './FormattedTextNote';
import User from "./classes/User";

/**
 *
 * The TextNotesLister searches for notes about the liturgical text and its references
 *
 * Trouble-shooting: if notes are in the database, but not being returned, it is likely
 * that the notes were created while logged in as wsadmin.  The notes only show for
 * the user who logged in.  So, if you log in as your self you will not see notes
 * you created while logged in as wsadmin.  You need to update the createdBy property
 * of the notes to change them from wsadmin to your user id.
 *
 */
export var TextNotesLister = (_temp = _class = function (_React$Component) {
  _inherits(TextNotesLister, _React$Component);

  function TextNotesLister(props) {
    _classCallCheck(this, TextNotesLister);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    _this.state = _this.setTheState(props, "");

    _this.deselectAllRows = _this.deselectAllRows.bind(_this);
    _this.fetchData = _this.fetchData.bind(_this);
    _this.getAddButton = _this.getAddButton.bind(_this);
    _this.getModalEditor = _this.getModalEditor.bind(_this);
    _this.getSelectedDocOptions = _this.getSelectedDocOptions.bind(_this);
    _this.handleAddButtonClick = _this.handleAddButtonClick.bind(_this);
    _this.handleAddClose = _this.handleAddClose.bind(_this);
    _this.handleCancelRequest = _this.handleCancelRequest.bind(_this);
    _this.handleCloseModal = _this.handleCloseModal.bind(_this);
    _this.handleDoneRequest = _this.handleDoneRequest.bind(_this);
    _this.handleGetForIdCallback = _this.handleGetForIdCallback.bind(_this);
    _this.handleRowSelect = _this.handleRowSelect.bind(_this);
    _this.noteFormatter = _this.noteFormatter.bind(_this);
    _this.onSizePerPageList = _this.onSizePerPageList.bind(_this);
    _this.setTheState = _this.setTheState.bind(_this);
    _this.showRowComparison = _this.showRowComparison.bind(_this);
    _this.verifyTextId = _this.verifyTextId.bind(_this);
    _this.createNotesDropdown = _this.createNotesDropdown.bind(_this);
    _this.compareNotes = _this.compareNotes.bind(_this);
    return _this;
  }

  // a method called by both the constructor and componentWillReceiveProps


  TextNotesLister.prototype.handleCancelRequest = function handleCancelRequest() {
    if (this.props.callback) {
      this.props.callback("", "");
    }
  };

  TextNotesLister.prototype.handleDoneRequest = function handleDoneRequest() {
    if (this.props.callback) {
      this.props.callback(this.state.selectedId, this.state.selectedValue);
    }
  };

  TextNotesLister.prototype.getSelectedDocOptions = function getSelectedDocOptions() {
    return React.createElement(
      Panel,
      null,
      React.createElement(
        FormGroup,
        null,
        React.createElement(
          ControlLabel,
          null,
          this.state.labels.search.selectedDoc
        ),
        React.createElement(FormControl, {
          type: 'text',
          value: this.state.selectedId,
          disabled: true
        }),
        React.createElement(
          ControlLabel,
          null,
          this.state.labels.search.selectedDoc
        ),
        React.createElement(FormControl, {
          type: 'text',
          value: this.state.selectedValue,
          disabled: true
        }),
        React.createElement(
          'div',
          null,
          React.createElement(
            ButtonGroup,
            { bsSize: 'xsmall' },
            React.createElement(
              Button,
              { onClick: this.handleCancelRequest },
              'Cancel'
            ),
            React.createElement(
              Button,
              { onClick: this.handleDoneRequest },
              'Done'
            )
          )
        )
      )
    );
  };

  /**
   * font-awesome icons for messages
   * @type {{info: string, warning: string, error: string}}
   */


  TextNotesLister.prototype.setMessage = function setMessage(message) {
    this.setState({
      message: message
    });
  };

  TextNotesLister.prototype.fetchData = function fetchData(event) {
    var _this2 = this;

    this.setState({
      message: this.state.labels.search.msg2,
      messageIcon: this.messageIcons.info
    });
    var config = {
      auth: {
        username: this.state.session.userInfo.username,
        password: this.state.session.userInfo.password
      }
    };

    var idParts = IdManager.getParts(this.props.topicId);

    var parms = "?t=" + encodeURIComponent("*") + "&q=" + encodeURIComponent(idParts.topic + "~" + idParts.key) + "&p=topic" + "&m=ew" + "&l=" + "&o=any";
    var path = this.props.session.restServer + Server.getDbServerNotesApi() + parms;
    axios.get(path, config).then(function (response) {
      var resultCount = 0;
      var notes = [];
      var showSearchResults = false;
      var message = _this2.state.labels.search.foundNone;
      var found = _this2.state.labels.search.foundMany;
      if (response.data.valueCount) {
        notes = response.data.values;
        resultCount = response.data.valueCount;
        showSearchResults = resultCount > 0;
        if (resultCount === 0) {
          message = _this2.state.labels.search.foundNone;
        } else if (resultCount === 1) {
          message = _this2.state.labels.search.foundOne;
        } else {
          message = found + " " + resultCount + ".";
        }
      }

      var enableAdd = resultCount > 0;
      _this2.setState({
        message: message,
        notes: notes,
        resultCount: resultCount,
        messageIcon: _this2.messageIcons.info,
        showSearchResults: showSearchResults,
        enableAdd: enableAdd,
        selectedId: "",
        selectedKey: "",
        selectedLibrary: "",
        selectedTopic: _this2.props.topicId,
        selectedText: ""
      }, _this2.createNotesDropdown);
    }).catch(function (error) {
      var message = error.message;
      var messageIcon = _this2.messageIcons.error;
      if (error && error.response && error.response.status === 404) {
        message = _this2.state.labels.search.foundNone;
        messageIcon = _this2.messageIcons.warning;
        _this2.setState({ data: message, message: message, messageIcon: messageIcon });
      }
    });
  };

  TextNotesLister.prototype.render = function render() {
    return React.createElement(
      'div',
      { className: 'App-page App-Notes-Lister' },
      this.props.title && React.createElement(
        'h3',
        null,
        this.props.title
      ),
      React.createElement(
        'div',
        null,
        this.state.labels.search.resultLabel,
        ': ',
        React.createElement(
          'span',
          { className: 'App App-message' },
          React.createElement(FontAwesome, { name: this.state.messageIcon }),
          this.state.message,
          ' ',
          this.getAddButton()
        )
      ),
      this.state.showSearchResults && React.createElement(
        'div',
        null,
        this.state.labels.search.msg5,
        ' ',
        this.state.labels.search.msg6
      ),
      this.state.showRowSelectMessage && React.createElement(
        'div',
        null,
        React.createElement(FontAwesome, { name: this.state.rowSelectMessageIcon }),
        ' ',
        this.state.rowSelectMessage
      ),
      this.state.showModalEditor && this.getModalEditor(),
      this.state.showSearchResults && React.createElement(
        'div',
        { className: 'App-search-results' },
        React.createElement(
          'div',
          { className: 'row' },
          React.createElement(
            BootstrapTable,
            {
              ref: 'theTable',
              data: this.state.notes,
              exportCSV: false,
              trClassName: "App-data-tr",
              striped: true,
              hover: true,
              pagination: true,
              options: this.state.options,
              selectRow: this.state.selectRow
            },
            React.createElement(
              TableHeaderColumn,
              {
                isKey: true,
                dataField: 'id',
                dataSort: true,
                'export': true,
                hidden: true
              },
              'ID'
            ),
            React.createElement(
              TableHeaderColumn,
              {
                dataField: 'type',
                dataSort: true,
                tdClassname: 'tdType',
                width: "15%",
                filter: this.state.filter
              },
              this.state.labels.resultsTable.headerType
            ),
            React.createElement(
              TableHeaderColumn,
              {
                dataField: 'liturgicalScope',
                dataSort: true,
                tdClassname: 'tdType',
                width: "15%",
                filter: this.state.filter
              },
              this.state.labels.resultsTable.headerScope
            ),
            React.createElement(
              TableHeaderColumn,
              {
                dataField: 'liturgicalLemma',
                dataSort: true,
                tdClassname: 'tdType',
                width: "15%",
                filter: this.state.filter
              },
              this.state.labels.resultsTable.headerLemma
            ),
            React.createElement(
              TableHeaderColumn,
              {
                dataField: 'valueFormatted',
                dataSort: true,
                width: "85%",
                filter: this.state.filter,
                dataFormat: this.noteFormatter,
                formatExtraData: this.props.session
              },
              this.state.labels.resultsTable.headerNote
            )
          )
        )
      )
    );
  };

  return TextNotesLister;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.componentWillMount = function () {
    _this3.fetchData();
  };

  this.componentWillReceiveProps = function (nextProps) {
    _this3.state = _this3.setTheState(nextProps, _this3.state.docType);
    _this3.verifyTextId(_this3.props.topicId, nextProps.topicId);
  };

  this.setTheState = function (props, docType) {

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    var theSearchLabels = labels[labelTopics.searchNotes];

    var selectedId = "";
    if (docType) {
      if (props.initialType === docType) {
        selectedId = _this3.state.selectedId;
      }
    }
    var userInfo = {};
    if (props.session && props.session.userInfo) {
      userInfo = new User(props.session.userInfo.username, props.session.userInfo.password, props.session.userInfo.domain, props.session.userInfo.email, props.session.userInfo.firstname, props.session.userInfo.lastname, props.session.userInfo.title, props.session.userInfo.authenticated, props.session.userInfo.domains);
    }

    return {
      labels: {
        messages: labels[labelTopics.messages],
        search: theSearchLabels,
        resultsTable: labels[labelTopics.resultsTable]
      },
      session: {
        userInfo: userInfo
      },
      docType: props.initialType,
      filterMessage: theSearchLabels.msg5,
      selectMessage: theSearchLabels.msg6,
      messageIcon: get(_this3.state, "messageIcon", ""),
      message: get(_this3.state, "message", ""),
      rowSelectMessage: get(_this3.state, "rowSelectMessage", ""),
      rowSelectMessageIcon: get(_this3.state, "rowSelectMessageIcon", ""),
      showRowSelectMessage: get(_this3.state, "showRowSelectMessage", false),
      matcherTypes: [{ label: theSearchLabels.matchesAnywhere, value: "c" }, { label: theSearchLabels.matchesAtTheStart, value: "sw" }, { label: theSearchLabels.matchesAtTheEnd, value: "ew" }, { label: theSearchLabels.matchesRegEx, value: "rx" }],
      matcher: "c",

      query: "",

      suggestedQuery: "",

      propertyTypes: [{ label: "ID", value: "id" }, { label: "Value (insensitive)", value: "nnp" }, { label: "Value (sensitive)", value: "value" }],

      docPropMessage: "",

      docPropMessageById: "Search By ID searches the ID of the docs, with the parts domain~topic~key, e.g. gr_gr_cog~actors~Priest.",

      docPropMessageByValue: "Search By Value is insensitive to accents, case, and punctuation.",

      docPropMessageByValueSensitive: "Search By Value (sensitive) is sensitive to accents, case, and punctuation.",

      searchFormToggle: _this3.messageIcons.toggleOff,

      showSearchForm: true,

      searchFormType: "simple",

      showSearchResults: get(_this3.state, "showSearchResults", false),

      resultCount: get(_this3.state, "resultCount", 0),

      options: {
        sizePerPage: 30,
        sizePerPageList: [5, 15, 30],
        onSizePerPageList: _this3.onSizePerPageList,
        hideSizePerPage: true,
        paginationShowsTotal: true
      },

      selectRow: {
        mode: 'radio' // or checkbox
        , hideSelectColumn: false,
        clickToSelect: false,
        onSelect: _this3.handleRowSelect,
        className: "App-row-select"
      },
      filter: { type: 'RegexFilter', delay: 100 },
      showSelectionButtons: false,
      selectedId: selectedId,
      selectedLibrary: "",
      selectedTopic: props.topicId,
      selectedKey: "",
      title: "",
      selectedText: "",
      showModalEditor: false,
      idColumnSize: "80px",
      enableAdd: get(_this3.state, "enableAdd", false),
      notes: get(_this3.state, "notes", [{ "id": "", "value:": "" }]),
      notesDropdown: get(_this3.state, "notesDropdown", []),
      canUpdateNote: get(_this3.state, "canUpdateNote", false)
    };
  };

  this.compareNotes = function (a, b) {
    if (a.label < b.label) return -1;
    if (a.label > b.label) return 1;
    return 0;
  };

  this.createNotesDropdown = function () {
    var notesDropdown = _this3.state.notes.map(function (a) {
      var label = a.type;
      label += ": ";
      label += a.liturgicalScope;
      label += " ";
      label += a.liturgicalLemma;
      label += " ";
      label += a.value.substring(0, 20);
      return { label: label, value: a.id };
    });
    notesDropdown.sort(_this3.compareNotes);
    _this3.setState({ notesDropdown: notesDropdown });
  };

  this.deselectAllRows = function () {
    if (_this3.refs && _this3.refs.theTable) {
      _this3.refs.theTable.setState({
        selectedRowKeys: []
      });
    }
  };

  this.handleRowSelect = function (row, isSelected, e) {
    var rowSelectMessage = _this3.state.labels.messages.ok;
    var rowSelectMessageIcon = _this3.messageIcons.info;
    if (_this3.state.session.userInfo.isAuthorFor(row["library"])) {
      _this3.setState({
        selectedId: row["id"],
        selectedLibrary: row["library"],
        selectedTopic: row["topic"],
        selectedKey: row["key"],
        title: row["id"],
        selectedText: row["text"],
        showIdPartSelector: true,
        showModalEditor: true,
        rowSelectMessage: rowSelectMessage,
        rowSelectMessageIcon: rowSelectMessageIcon,
        showRowSelectMessage: false
      });
    } else {
      rowSelectMessage = _this3.state.labels.messages.readOnly + " ( " + row["library"] + ")";
      rowSelectMessageIcon = _this3.messageIcons.error;
      _this3.setState({
        rowSelectMessage: rowSelectMessage,
        rowSelectMessageIcon: rowSelectMessageIcon,
        showRowSelectMessage: true
      });
    }
  };

  this.showRowComparison = function (id) {
    _this3.setState({
      showModalEditor: true,
      selectedId: id
    });
  };

  this.handleCloseModal = function (id, value) {
    if (id && id.length > 0) {
      _this3.setState({
        showModalEditor: false,
        selectedId: id,
        selectedValue: value
      });
    } else {
      _this3.setState({
        showModalEditor: false
      });
    }
    _this3.deselectAllRows();
    _this3.fetchData();
  };

  this.getModalEditor = function () {
    return React.createElement(ModalTextNoteEditor, {
      session: _this3.props.session,
      restPath: Server.getDbServerDocsApi(),
      noteIdLibrary: _this3.state.selectedLibrary,
      noteIdTopic: _this3.state.selectedTopic,
      noteIdKey: _this3.state.selectedKey,
      onClose: _this3.handleCloseModal,
      notesList: _this3.state.notes,
      canUpdate: _this3.state.canUpdateNote
    });
  };

  this.onSizePerPageList = function (sizePerPage) {
    _this3.setState({
      options: { sizePerPage: sizePerPage }
    });
  };

  this.messageIcons = {
    info: "info-circle",
    warning: "lightbulb-o",
    error: "exclamation-triangle"
    // , toggleOn: "eye"
    // , toggleOff: "eye-slash"
    , toggleOn: "toggle-on",
    toggleOff: "toggle-off",
    simpleSearch: "minus",
    advancedSearch: "bars",
    idPatternSearch: "key"
  };

  this.handleAddClose = function () {
    _this3.setState({
      showModalEditor: false
    }, _this3.fetchData);
  };

  this.handleAddButtonClick = function () {
    _this3.setState({
      showModalEditor: true
    });
  };

  this.getAddButton = function () {
    return React.createElement(
      Button,
      {
        className: 'Text-Note-Add-Button',
        bsStyle: 'primary',
        bsSize: "xsmall",
        onClick: _this3.handleAddButtonClick },
      React.createElement(FontAwesome, {
        className: 'App-Add-ico',
        name: 'plus' })
    );
  };

  this.handleGetForIdCallback = function (restCallResult) {
    var enableAdd = false;
    if (restCallResult && restCallResult.data && restCallResult.data.valueCount) {
      enableAdd = restCallResult.data.valueCount > 0;
    }
    _this3.setState({ enableAdd: enableAdd });
  };

  this.verifyTextId = function (currentId, nextId) {
    var needToVerify = true;

    if (_this3.state.enableAdd) {
      if (currentId) {
        if (currentId == nextId) {
          needToVerify = false;
        }
      }
    }
    if (needToVerify) {
      _this3.setState({ enableAdd: false });

      Server.restGetForId(_this3.props.session.restServer, _this3.state.session.userInfo.username, _this3.state.session.userInfo.password, nextId, _this3.handleGetForIdCallback);
    }
  };

  this.noteFormatter = function (cell, row, formatExtraData) {
    return React.createElement(FormattedTextNote, {
      session: formatExtraData,
      note: row["valueFormatted"],
      type: row["type"],
      title: row["title"],
      scopeLiturgical: row["liturgicalScope"],
      lemmaLiturgical: row["liturgicalLemma"],
      scopeBiblical: row["biblicalScope"],
      lemmaBiblical: row["biblicalLemma"]
    });
  };
}, _temp);;

process.env.NODE_ENV !== "production" ? TextNotesLister.propTypes = {
  session: PropTypes.object.isRequired,
  callback: PropTypes.func,
  topicId: PropTypes.string.isRequired,
  topicText: PropTypes.string.isRequired
} : void 0;

export default TextNotesLister;