var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Button, FormControl, FormGroup, InputGroup, Tab, Tabs, Well } from 'react-bootstrap';
import FontAwesome from 'react-fontawesome';
import { get } from 'lodash';

import TreeNode from '../classes/TreeNode';

import LabelSelector from '../helpers/LabelSelector';
import MessageIcons from '../helpers/MessageIcons';
import Server from '../helpers/Server';
import Spinner from '../helpers/Spinner';
import UiSchemas from "../classes/UiSchemas";

/**
 * Provides a means for the user to set the tags for a token.
 * A token can be a word or a punctuation mark.
 * The tags initialize using information from the database via the rest api.
 * The user then has the option of manually setting tag values,
 * or if the user selects an analysis from an external source,
 * e.g. Perseus (displayed via the Grammar component),
 * the selected values are copied and become parms to the TokenTagger.
 * The new values are saved back to the database.
 *
 * Notes: the grammar tags are set by TreeNode.getGrammar()
 *        the values for the dropdowns come from labels
 */
var TokenTagger = (_temp = _class = function (_React$Component) {
  _inherits(TokenTagger, _React$Component);

  function TokenTagger(props) {
    _classCallCheck(this, TokenTagger);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    _this.state = _this.setTheState(props, "");

    _this.getAnswersComponent = _this.getAnswersComponent.bind(_this);
    _this.getAspectComponent = _this.getAspectComponent.bind(_this);
    _this.getCaseComponent = _this.getCaseComponent.bind(_this);
    _this.getDependencyComponent = _this.getDependencyComponent.bind(_this);
    _this.getGenderComponent = _this.getGenderComponent.bind(_this);
    _this.getLabelComponent = _this.getLabelComponent.bind(_this);
    _this.getMoodComponent = _this.getMoodComponent.bind(_this);
    _this.getNumberComponent = _this.getNumberComponent.bind(_this);
    _this.getPartOfSpeechComponent = _this.getPartOfSpeechComponent.bind(_this);
    _this.getPersonComponent = _this.getPersonComponent.bind(_this);
    _this.getReferentComponent = _this.getReferentComponent.bind(_this);
    _this.getSubmitMessage = _this.getSubmitMessage.bind(_this);
    _this.getTabs = _this.getTabs.bind(_this);
    _this.getTenseComponent = _this.getTenseComponent.bind(_this);
    _this.getVerbNumberComponent = _this.getVerbNumberComponent.bind(_this);
    _this.getVoiceComponent = _this.getVoiceComponent.bind(_this);

    _this.handleAnswersChange = _this.handleAnswersChange.bind(_this);
    _this.handleCaseChange = _this.handleCaseChange.bind(_this);
    _this.handleDependencyChange = _this.handleDependencyChange.bind(_this);
    _this.handleGenderChange = _this.handleGenderChange.bind(_this);
    _this.handleGlossChange = _this.handleGlossChange.bind(_this);
    _this.handleLabelChange = _this.handleLabelChange.bind(_this);
    _this.handleLemmaChange = _this.handleLemmaChange.bind(_this);
    _this.handleMoodChange = _this.handleMoodChange.bind(_this);
    _this.handleNumberChange = _this.handleNumberChange.bind(_this);
    _this.handlePartOfSpeechChange = _this.handlePartOfSpeechChange.bind(_this);
    _this.handlePersonChange = _this.handlePersonChange.bind(_this);
    _this.handleReferentChange = _this.handleReferentChange.bind(_this);
    _this.handleSubmit = _this.handleSubmit.bind(_this);
    _this.handleTenseChange = _this.handleTenseChange.bind(_this);
    _this.handleValueUpdateCallback = _this.handleValueUpdateCallback.bind(_this);
    _this.handleVoiceChange = _this.handleVoiceChange.bind(_this);
    _this.normalizeIndex = _this.normalizeIndex.bind(_this);
    _this.submitUpdate = _this.submitUpdate.bind(_this);
    _this.toggleSubmit = _this.toggleSubmit.bind(_this);
    return _this;
  }

  TokenTagger.prototype.normalizeIndex = function normalizeIndex(value) {
    var result = value;
    if (value) {
      if (value === "0") {
        result = "Root";
      } else {
        result = (parseInt(value) - 1).toString();
      }
    }
    return result;
  };

  /**
   * Update the database and return the value to the caller
   */


  TokenTagger.prototype.render = function render() {
    return React.createElement(
      'form',
      { onSubmit: this.handleSubmit },
      React.createElement(
        'div',
        { className: 'container' },
        React.createElement(
          'div',
          null,
          React.createElement(
            'div',
            { className: 'row' },
            React.createElement(
              'div',
              { className: 'col-sm-12 col-md-12 col-lg-12 resourceSelectorPrompt' },
              this.state.labels.thisClass.instructions
            ),
            React.createElement(
              'div',
              { className: 'col-sm-12 col-md-12 col-lg-12 App-Label-Selector-POS' },
              parseInt(this.props.index) + 1,
              ' ',
              this.props.token
            )
          )
        )
      ),
      React.createElement(
        FormGroup,
        null,
        React.createElement(
          'div',
          { className: 'container' },
          React.createElement(
            'div',
            null,
            React.createElement(
              'div',
              { className: 'row' },
              React.createElement(
                'div',
                { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Case' },
                React.createElement(
                  'div',
                  { className: 'resourceSelectorPrompt' },
                  this.state.labels.thisClass.lemma
                ),
                React.createElement(FormControl, {
                  id: 'AppTreeNodeBuilder-Lemma',
                  className: 'App App-TokenTagger-Lemma',
                  type: 'text',
                  value: this.state.lemma,
                  placeholder: 'Enter lemma',
                  onChange: this.handleLemmaChange
                })
              ),
              React.createElement(
                'div',
                { className: 'col-sm-6 col-md-6 col-lg-6 App-Token-Tagger-Gloss' },
                React.createElement(
                  'div',
                  { className: 'resourceSelectorPrompt' },
                  this.state.labels.thisClass.gloss
                ),
                React.createElement(
                  InputGroup,
                  null,
                  React.createElement(FormControl, {
                    id: 'AppTreeNodeBuilder-Gloss',
                    className: 'App App-TokenTagger-Gloss',
                    type: 'text',
                    value: this.state.gloss,
                    placeholder: 'Enter gloss',
                    onChange: this.handleGlossChange
                  }),
                  React.createElement(
                    InputGroup.Addon,
                    { className: 'App-Token-Tagger-OED' },
                    React.createElement(
                      'a',
                      {
                        href: "https://www.oxfordlearnersdictionaries.com/definition/english/" + this.state.gloss.toLowerCase() + "_1?isEntryInOtherDict=false",
                        target: '_blank'
                      },
                      React.createElement('span', { className: 'glyphicon glyphicon-search App-Token-Tagger-OED-glyphicon' })
                    )
                  )
                )
              )
            )
          ),
          this.getTabs(),
          React.createElement(
            'div',
            { className: 'row' },
            React.createElement(
              'div',
              { className: 'col-sm-2 col-md-2 col-lg-2  App-Label-Selector-Button' },
              React.createElement(
                Button,
                {
                  bsStyle: 'primary',
                  type: 'submit',
                  onClick: this.handleSubmit,
                  disabled: this.state.submitDisabled
                },
                this.state.labels.messages.submit
              )
            ),
            React.createElement(
              'div',
              { className: 'col-sm-6 col-md-6 col-lg-6  App-Label-Selector-Retrieving' },
              this.getSubmitMessage()
            ),
            React.createElement('div', { className: 'col-sm-4 col-md-4 col-lg-4  App-Label-Selector-Empty' })
          )
        )
      )
    );
  };

  return TokenTagger;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {};

  this.componentWillReceiveProps = function (nextProps) {
    _this2.state = _this2.setTheState(nextProps, _this2.state);
  };

  this.setTheState = function (props, currentState) {
    var index = props.index;
    var tokenAnalysis = props.tokenAnalysis;

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;
    var labelAnswerTags = labels[labelTopics.Answertags];
    var labelGrammarTermsTitles = labels[labelTopics.grammarTermsTitles];
    var labelCase = labels[labelTopics.grammarTermsCaseValues];
    var labelCategories = labels[labelTopics.UDtagsDepRel]; // labels[labelTopics.grammarTermsCategoryValues];
    var labelGender = labels[labelTopics.grammarTermsGenderValues];
    var labelNumber = labels[labelTopics.grammarTermsNumberValues];
    var labelPerson = labels[labelTopics.grammarTermsPersonValues];
    var labelPos = labels[labelTopics.grammarTermsPosValues];
    var labelMood = labels[labelTopics.grammarTermsMoodValues];
    var labelTense = labels[labelTopics.grammarTermsTenseValues];
    var labelVoice = labels[labelTopics.grammarTermsVoiceValues];
    var grammar = {
      answersQuestion: { title: labelGrammarTermsTitles.answers, values: labelAnswerTags },
      case: { title: labelGrammarTermsTitles.case, values: labelCase },
      categories: { title: labelGrammarTermsTitles.categories, values: labelCategories },
      gender: { title: labelGrammarTermsTitles.gender, values: labelGender },
      mood: { title: labelGrammarTermsTitles.mood, values: labelMood },
      number: { title: labelGrammarTermsTitles.number, values: labelNumber },
      person: { title: labelGrammarTermsTitles.person, values: labelPerson },
      pos: { title: labelGrammarTermsTitles.pos, values: labelPos },
      tense: { title: labelGrammarTermsTitles.tense, values: labelTense },
      voice: { title: labelGrammarTermsTitles.voice, values: labelVoice }
    };

    // if the index did not change, preserve the previous state
    if (currentState.index && currentState.index === index) {
      tokenAnalysis = currentState.tokenAnalysis;
      var propLemma = props.copiedLemma;
      var propGloss = props.copiedGloss;
      var propPos = props.copiedPos;
      var propGrammar = props.copiedGrammar;
      var lemma = currentState.lemma;
      var gloss = currentState.gloss;

      var dependsOn = get(currentState, "dependsOn", props.tokenAnalysis.dependsOn);
      var refersTo = get(currentState, "refersTo", props.tokenAnalysis.refersTo);
      var answersQuestion = get(currentState, "answersQuestion", props.tokenAnalysis.answersQuestion);
      var selectedCase = currentState.selectedCase;
      var selectedGender = currentState.selectedGender;
      var selectedMood = currentState.selectedMood;
      var selectedNumber = currentState.selectedNumber;
      var selectedPerson = currentState.selectedPerson;
      var selectedPos = currentState.selectedPos;
      var selectedTense = currentState.selectedTense;
      var selectedVoice = currentState.selectedVoice;
      var theTaggedNode = new TreeNode();

      if (currentState.theTaggedNode) {
        theTaggedNode = currentState.theTaggedNode;
      }

      if (selectedPos) {
        if (props.copiedPos) {
          if (props.copiedPos === currentState.propPos) {
            // ignore
          } else {
            selectedPos = props.copiedPos;
          }
        }
      } else {
        selectedPos = props.copiedPos;
      }
      if (lemma) {
        if (props.copiedLemma) {
          if (props.copiedLemma === currentState.lemma) {
            // ignore
          } else {
            lemma = props.copiedLemma;
          }
        }
      } else {
        lemma = props.copiedLemma;
      }
      if (gloss) {
        if (props.copiedGloss) {
          if (props.copiedGloss === currentState.propGloss) {
            // ignore
          } else {
            gloss = props.copiedGloss;
          }
        }
      } else {
        gloss = props.copiedGloss;
      }
      if (props.copiedGrammar) {
        var tags = props.copiedGrammar.split(".");
        for (var i = 1; i < tags.length; i++) {
          var tag = tags[i];
          if (tag === "PRES") {
            tag = "PRS";
          } else if (tag === "PART") {
            tag = "PTCP";
          } else if (tag === "PERF") {
            tag = "PRF";
          } else if (tag === "INF") {
            // treat infinitive as a part of speech
            selectedPos = tag;
            propPos = tag;
          }
          if (grammar.case && grammar.case.values && grammar.case.values[tag]) {
            selectedCase = tag;
          } else if (grammar.gender && grammar.gender.values && grammar.gender.values[tag]) {
            selectedGender = tag;
          } else if (grammar.number && grammar.number.values && grammar.number.values[tag]) {
            selectedNumber = tag;
          } else if (grammar.mood && grammar.mood.values && grammar.mood.values[tag]) {
            selectedMood = tag;
          } else if (grammar.person && grammar.person.values && grammar.person.values[tag]) {
            selectedPerson = tag;
          } else if (grammar.tense && grammar.tense.values && grammar.tense.values[tag]) {
            selectedTense = tag;
          } else if (grammar.voice && grammar.voice.values && grammar.voice.values[tag]) {
            selectedVoice = tag;
          }
        }
      }
      var submitDisabled = true;
      if (currentState.theTaggedNode) {
        submitDisabled = currentState.theTaggedNode.notComplete();
      }

      var uiSchemas = {};
      if (props.session && props.session.uiSchemas) {
        uiSchemas = new UiSchemas(props.session.uiSchemas.formsDropdown, props.session.uiSchemas.formsSchemas, props.session.uiSchemas.forms);
      }

      return {
        labels: {
          thisClass: labels[labelTopics.TokenTagger],
          messages: labels[labelTopics.messages],
          grammar: grammar
        },
        session: {
          uiSchemas: uiSchemas
        },
        messageIcons: MessageIcons.getMessageIcons(),
        messageIcon: MessageIcons.getMessageIcons().info,
        message: labels[labelTopics.messages].initial,
        index: index,
        selectedCase: selectedCase,
        selectedGender: selectedGender,
        selectedMood: selectedMood,
        selectedNumber: selectedNumber,
        selectedPerson: selectedPerson,
        selectedPos: selectedPos,
        selectedTense: selectedTense,
        selectedVoice: selectedVoice,
        selectedLabel: get(currentState, "selectedLabel", ""),
        dependsOn: dependsOn,
        refersTo: refersTo,
        answersQuestion: answersQuestion,
        lemma: lemma,
        gloss: gloss,
        propLemma: propLemma,
        propGloss: propGloss,
        propPos: propPos,
        propGrammar: propGrammar,
        tokenAnalysis: tokenAnalysis,
        theTaggedNode: theTaggedNode,
        submitDisabled: submitDisabled,
        updatingData: currentState.updatingData,
        dataUpdated: currentState.dataUpdated
      };
    } else if (index && tokenAnalysis) {
      return {
        labels: {
          thisClass: labels[labelTopics.TokenTagger],
          messages: labels[labelTopics.messages],
          grammar: grammar
        },
        session: currentState.session,
        messageIcons: MessageIcons.getMessageIcons(),
        messageIcon: MessageIcons.getMessageIcons().info,
        message: labels[labelTopics.messages].initial,
        updatingData: false,
        dataUpdated: false,
        index: index,
        selectedCase: tokenAnalysis.gCase ? tokenAnalysis.gCase : "",
        selectedGender: tokenAnalysis.gender ? tokenAnalysis.gender : "",
        selectedMood: tokenAnalysis.mood ? tokenAnalysis.mood : "",
        selectedNumber: tokenAnalysis.number ? tokenAnalysis.number : "",
        selectedPerson: tokenAnalysis.person ? tokenAnalysis.person : "",
        selectedPos: tokenAnalysis.pos ? tokenAnalysis.pos : "",
        selectedTense: tokenAnalysis.tense ? tokenAnalysis.tense : "",
        selectedVoice: tokenAnalysis.voice ? tokenAnalysis.voice : "",
        selectedLabel: tokenAnalysis.label ? tokenAnalysis.label : "_",
        lemma: tokenAnalysis.lemma ? tokenAnalysis.lemma : "",
        gloss: tokenAnalysis.gloss ? tokenAnalysis.gloss : "",
        dependsOn: tokenAnalysis.dependsOn ? tokenAnalysis.dependsOn : "",
        refersTo: tokenAnalysis.refersTo ? tokenAnalysis.refersTo : "",
        answersQuestion: tokenAnalysis.answersQuestion ? tokenAnalysis.answersQuestion : "_",
        grammar: tokenAnalysis.grammar ? tokenAnalysis.grammar : "",
        tokenAnalysis: tokenAnalysis
      };
    } else {
      return {
        labels: {
          thisClass: labels[labelTopics.TokenTagger],
          messages: labels[labelTopics.messages],
          grammar: grammar
        },
        session: currentState.session,
        messageIcons: MessageIcons.getMessageIcons(),
        messageIcon: MessageIcons.getMessageIcons().info,
        message: labels[labelTopics.messages].initial,
        updatingData: false,
        dataUpdated: false
      };
    }
  };

  this.getTabs = function () {
    return React.createElement(
      'div',
      { className: 'row App-Tagger-Tabs' },
      React.createElement(
        Tabs,
        { id: 'App-Text-Node-Editor-Tabs', animation: false },
        React.createElement(
          Tab,
          { eventKey: "morphology", title: _this2.state.labels.thisClass.morphology },
          React.createElement(
            Well,
            null,
            React.createElement(
              FormGroup,
              null,
              React.createElement(
                'div',
                { className: 'container' },
                React.createElement(
                  'div',
                  null,
                  React.createElement(
                    'div',
                    { className: 'row' },
                    _this2.getPartOfSpeechComponent(),
                    _this2.getPersonComponent(),
                    _this2.getVerbNumberComponent(),
                    _this2.getTenseComponent(),
                    _this2.getVoiceComponent(),
                    _this2.getMoodComponent(),
                    _this2.getGenderComponent(),
                    _this2.getNumberComponent(),
                    _this2.getCaseComponent()
                  )
                )
              )
            ),
            React.createElement(
              'div',
              { className: 'row' },
              React.createElement(
                'div',
                { className: 'col-sm-3 col-md-3 col-lg-3  App-Label-Selector-Help' },
                React.createElement(
                  'a',
                  {
                    href: "http://universaldependencies.org/guidelines.html",
                    target: '_blank'
                  },
                  _this2.state.labels.thisClass.udGuidelines
                )
              ),
              React.createElement(
                'div',
                { className: 'col-sm-2 col-md-2 col-lg-2  App-Label-Selector-Help' },
                React.createElement(
                  'a',
                  {
                    href: 'https://github.com/PerseusDL/treebank_data/blob/master/AGDT2/guidelines/Greek_guidelines.md',
                    target: '_blank'
                  },
                  _this2.state.labels.thisClass.help
                )
              ),
              React.createElement(
                'div',
                { className: 'col-sm-2 col-md-2 col-lg-2  App-Label-Selector-Help' },
                React.createElement(
                  'a',
                  {
                    href: "https://www.eva.mpg.de/lingua/resources/glossing-rules.php",
                    target: '_blank'
                  },
                  _this2.state.labels.thisClass.leipzig
                )
              )
            )
          )
        ),
        React.createElement(
          Tab,
          { eventKey: "syntax", title: _this2.state.labels.thisClass.syntax },
          React.createElement(
            Well,
            null,
            React.createElement(
              FormGroup,
              null,
              React.createElement(
                'div',
                { className: 'container' },
                React.createElement(
                  'div',
                  null,
                  React.createElement(
                    'div',
                    { className: 'row' },
                    _this2.getDependencyComponent(),
                    _this2.getLabelComponent()
                  )
                )
              )
            ),
            React.createElement(
              'div',
              { className: 'row' },
              React.createElement(
                'div',
                { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Help' },
                React.createElement(
                  'a',
                  {
                    href: "http://universaldependencies.org/guidelines.html",
                    target: '_blank'
                  },
                  _this2.state.labels.thisClass.udGuidelines
                )
              )
            )
          )
        ),
        React.createElement(
          Tab,
          { eventKey: "semantics", title: _this2.state.labels.thisClass.semantics },
          React.createElement(
            Well,
            null,
            React.createElement(
              FormGroup,
              null,
              React.createElement(
                'div',
                { className: 'container' },
                React.createElement(
                  'div',
                  null,
                  React.createElement(
                    'div',
                    { className: 'row' },
                    _this2.getReferentComponent(),
                    _this2.getAnswersComponent()
                  )
                )
              )
            )
          )
        )
      )
    );
  };

  this.handleGlossChange = function (event) {
    _this2.setState({
      gloss: event.target.value
    }, _this2.toggleSubmit);
  };

  this.handleLemmaChange = function (event) {
    _this2.setState({
      lemma: event.target.value
    }, _this2.toggleSubmit);
  };

  this.handleDependencyChange = function (selection) {
    _this2.setState({
      dependsOn: _this2.normalizeIndex(selection["value"])
    }, _this2.toggleSubmit);
  };

  this.handleReferentChange = function (selection) {
    _this2.setState({
      refersTo: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handleLabelChange = function (selection) {
    _this2.setState({
      selectedLabel: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handlePartOfSpeechChange = function (selection) {
    _this2.setState({
      selectedPos: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handlePersonChange = function (selection) {
    _this2.setState({
      selectedPerson: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handleNumberChange = function (selection) {
    _this2.setState({
      selectedNumber: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handleAnswersChange = function (selection) {
    _this2.setState({
      answersQuestion: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handleCaseChange = function (selection) {
    _this2.setState({
      selectedCase: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handleGenderChange = function (selection) {
    _this2.setState({
      selectedGender: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handleTenseChange = function (selection) {
    _this2.setState({
      selectedTense: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handleMoodChange = function (selection) {
    _this2.setState({
      selectedMood: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.handleVoiceChange = function (selection) {
    _this2.setState({
      selectedVoice: selection["value"]
    }, _this2.toggleSubmit);
  };

  this.getDependencyComponent = function () {
    var theIndex = parseInt(_this2.props.index) + 1;
    var result = {};
    var values = {
      "0": "Root"
    };
    for (var i = 1; i <= _this2.props.tokens.length; i++) {
      if (i !== theIndex) {
        values[i] = i + ": " + _this2.props.tokens[i - 1];
      }
    }
    result.title = "Depends On";
    result.values = values;
    // make adjustments for displaying dependency dropdown
    var initialValue = _this2.state.dependsOn;
    if (initialValue === "Root") {
      initialValue = "0";
    } else {
      initialValue = (parseInt(initialValue) + 1).toString();
    }
    return React.createElement(
      'div',
      { className: 'col-sm-12 col-md-12 col-lg-12 App-Label-Selector-Dependency' },
      React.createElement(LabelSelector, {
        languageCode: _this2.props.session.languageCode,
        labels: result,
        initialValue: initialValue,
        changeHandler: _this2.handleDependencyChange,
        sort: false
      })
    );
  };

  this.getReferentComponent = function () {
    if (TreeNode.requiresReferent(_this2.state.selectedPos)) {
      var theIndex = parseInt(_this2.props.index);
      var result = {};
      var values = {};
      for (var i = 0; i < _this2.props.tokens.length; i++) {
        if (i !== theIndex) {
          values[i] = i + 1 + ": " + _this2.props.tokens[i];
        }
      }
      result.title = "Refers to";
      result.values = values;
      // make adjustments for displaying dropdown index shift
      var initialValue = _this2.state.refersTo;
      // if (initialValue === "Root") {
      //   initialValue = "0";
      // } else {
      //   initialValue = (parseInt(initialValue)+1).toString();
      // }
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12 App-Label-Selector-Referent' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: result,
          initialValue: initialValue,
          changeHandler: _this2.handleReferentChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getLabelComponent = function () {
    return React.createElement(
      'div',
      { className: 'col-sm-12 col-md-12 col-lg-12 App-Label-Selector-POS' },
      React.createElement(LabelSelector, {
        languageCode: _this2.props.session.languageCode,
        labels: _this2.state.labels.grammar.categories,
        initialValue: _this2.state.selectedLabel,
        changeHandler: _this2.handleLabelChange
      })
    );
  };

  this.getPartOfSpeechComponent = function () {
    return React.createElement(
      'div',
      { className: 'col-sm-12 col-md-12 col-lg-12 App-Label-Selector-POS' },
      React.createElement(LabelSelector, {
        languageCode: _this2.props.session.languageCode,
        labels: _this2.state.labels.grammar.pos,
        initialValue: _this2.state.selectedPos,
        changeHandler: _this2.handlePartOfSpeechChange
      })
    );
  };

  this.getPersonComponent = function () {
    if (_this2.state.selectedPos.startsWith("VERB") || _this2.state.selectedPos.startsWith("PRON")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Person' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.person,
          initialValue: _this2.state.selectedPerson,
          changeHandler: _this2.handlePersonChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getNumberComponent = function () {
    if (_this2.state.selectedPos.startsWith("ADJ") || _this2.state.selectedPos.startsWith("ART") || _this2.state.selectedPos.startsWith("PRON") || _this2.state.selectedPos.startsWith("NOUN")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Number' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.number,
          initialValue: _this2.state.selectedNumber,
          changeHandler: _this2.handleNumberChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getVerbNumberComponent = function () {
    if (_this2.state.selectedPos.startsWith("VERB") || _this2.state.selectedPos.startsWith("PTCP")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Number' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.number,
          initialValue: _this2.state.selectedNumber,
          changeHandler: _this2.handleNumberChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getCaseComponent = function () {
    if (_this2.state.selectedPos.startsWith("ADJ") || _this2.state.selectedPos.startsWith("ART") || _this2.state.selectedPos.startsWith("PRON") || _this2.state.selectedPos.startsWith("NOUN") || _this2.state.selectedPos.startsWith("PTCP")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Case' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.case,
          initialValue: _this2.state.selectedCase,
          changeHandler: _this2.handleCaseChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getGenderComponent = function () {
    if (_this2.state.selectedPos.startsWith("ADJ") || _this2.state.selectedPos.startsWith("ART") || _this2.state.selectedPos.startsWith("PRON") || _this2.state.selectedPos.startsWith("NOUN") || _this2.state.selectedPos.startsWith("PTCP")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Gender' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.gender,
          initialValue: _this2.state.selectedGender,
          changeHandler: _this2.handleGenderChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getTenseComponent = function () {
    if (_this2.state.selectedPos.startsWith("VERB") || _this2.state.selectedPos.startsWith("INF") || _this2.state.selectedPos.startsWith("PTCP")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Tense' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.tense,
          initialValue: _this2.state.selectedTense,
          changeHandler: _this2.handleTenseChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getAnswersComponent = function () {
    return React.createElement(
      'div',
      { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Tense' },
      React.createElement(LabelSelector, {
        languageCode: _this2.props.session.languageCode,
        labels: _this2.state.labels.grammar.answersQuestion,
        initialValue: _this2.state.answersQuestion,
        changeHandler: _this2.handleAnswersChange
      })
    );
  };

  this.getAspectComponent = function () {
    if (_this2.state.selectedPos.startsWith("VERB") || _this2.state.selectedPos.startsWith("INF") || _this2.state.selectedPos.startsWith("PTCP")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Tense' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.tense,
          initialValue: _this2.state.selectedTense,
          changeHandler: _this2.handleTenseChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getVoiceComponent = function () {
    if (_this2.state.selectedPos.startsWith("VERB") || _this2.state.selectedPos.startsWith("INF") || _this2.state.selectedPos.startsWith("PTCP")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Voice' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.voice,
          initialValue: _this2.state.selectedVoice,
          changeHandler: _this2.handleVoiceChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.getMoodComponent = function () {
    if (_this2.state.selectedPos.startsWith("VERB")) {
      return React.createElement(
        'div',
        { className: 'col-sm-12 col-md-12 col-lg-12  App-Label-Selector-Mood' },
        React.createElement(LabelSelector, {
          languageCode: _this2.props.session.languageCode,
          labels: _this2.state.labels.grammar.mood,
          initialValue: _this2.state.selectedMood,
          changeHandler: _this2.handleMoodChange
        })
      );
    } else {
      return React.createElement('span', null);
    }
  };

  this.submitUpdate = function () {
    var path = _this2.state.session.uiSchemas.getHttpPutPathForSchema(_this2.state.tokenAnalysis._valueSchemaId);
    // submit update to the database via the rest api
    Server.restPutSchemaBasedForm(_this2.props.session.restServer, _this2.props.session.userInfo.username, _this2.props.session.userInfo.password, path, _this2.state.tokenAnalysis, undefined, _this2.handleValueUpdateCallback);
    // submit update to the caller
    _this2.props.callBack(_this2.state.theTaggedNode);
  };

  this.handleSubmit = function (event) {
    event.preventDefault();
    var tokenAnalysis = _this2.state.tokenAnalysis;
    var theTaggedNode = _this2.state.theTaggedNode;
    tokenAnalysis.dependsOn = theTaggedNode.dependsOn;
    tokenAnalysis.answersQuestion = theTaggedNode.answersQuestion;
    tokenAnalysis.refersTo = theTaggedNode.refersTo;
    tokenAnalysis.lemma = theTaggedNode.lemma;
    tokenAnalysis.gloss = theTaggedNode.gloss;
    tokenAnalysis.label = theTaggedNode.label;
    tokenAnalysis.gCase = theTaggedNode.case;
    tokenAnalysis.gender = theTaggedNode.gender;
    tokenAnalysis.mood = theTaggedNode.mood;
    tokenAnalysis.number = theTaggedNode.number;
    tokenAnalysis.person = theTaggedNode.person;
    tokenAnalysis.pos = theTaggedNode.pos;
    tokenAnalysis.tense = theTaggedNode.tense;
    tokenAnalysis.voice = theTaggedNode.voice;
    tokenAnalysis.grammar = theTaggedNode.grammar;
    tokenAnalysis.annotationSchema = "HYBRID";
    _this2.setState({
      updatingData: true,
      tokenAnalysis: tokenAnalysis
    }, _this2.submitUpdate);
  };

  this.handleValueUpdateCallback = function (restCallResult) {
    if (restCallResult) {
      _this2.setState({
        message: restCallResult.message,
        messageIcon: restCallResult.messageIcon,
        messageStatus: restCallResult.status,
        updatingData: false,
        dataUpdated: true
      });
    }
  };

  this.toggleSubmit = function () {
    var theNode = new TreeNode(_this2.props.index, _this2.props.token, _this2.state.lemma, _this2.state.gloss, _this2.state.dependsOn, _this2.state.refersTo, _this2.state.selectedLabel, _this2.state.selectedCase, _this2.state.selectedGender, _this2.state.selectedMood, _this2.state.selectedNumber, _this2.state.selectedPerson, _this2.state.selectedPos, _this2.state.selectedTense, _this2.state.selectedVoice, _this2.state.answersQuestion);
    _this2.setState({
      submitDisabled: false,
      theTaggedNode: theNode
    });
    // TODO: isComplete is return erroneous result;
    // if (theNode.isComplete()) {
    //   this.setState({
    //     theTaggedNode: theNode
    //     , submitDisabled: false
    //   });
    // } else {
    //   this.setState({submitDisabled: true})
    // }
  };

  this.getSubmitMessage = function () {
    if (_this2.state.updatingData) {
      return React.createElement(Spinner, { message: _this2.state.labels.messages.updating });
    } else if (_this2.state.dataUpdated) {
      var message = _this2.state.labels.messages.updated;
      if (_this2.state.messageStatus !== "200") {
        message = _this2.state.message;
      }
      return React.createElement(
        'span',
        null,
        React.createElement(FontAwesome, {
          name: _this2.state.messageIcon
        }),
        message
      );
    } else {
      return React.createElement('span', null);
    }
  };
}, _temp);


process.env.NODE_ENV !== "production" ? TokenTagger.propTypes = {
  session: PropTypes.object.isRequired,
  index: PropTypes.string.isRequired,
  tokens: PropTypes.array.isRequired,
  token: PropTypes.string.isRequired,
  tokenAnalysis: PropTypes.object.isRequired,
  callBack: PropTypes.func.isRequired,
  copiedLemma: PropTypes.string,
  copiedGloss: PropTypes.string,
  copiedPos: PropTypes.string,
  copiedGrammar: PropTypes.string
} : void 0;

TokenTagger.defaultProps = {
  copiedLemma: "",
  copiedGloss: "",
  copiedPos: "",
  copiedGrammar: ""
};

export default TokenTagger;