function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

import { get, has } from 'lodash';

var TreeViewUtils = function TreeViewUtils(nodes) {
  var _this = this;

  _classCallCheck(this, TreeViewUtils);

  this.toDependencyMap = function () {
    var map = {};
    for (var i = 0; i < _this.nodes.length; i++) {
      var node = _this.nodes[i];
      var dependsOn = node.dependsOn;
      var dependencies = [];
      if (has(map, dependsOn)) {
        dependencies = get(map, dependsOn);
      }
      dependencies.push(node.key);
      map[dependsOn] = dependencies;
    }
    return map;
  };

  this.toTreeViewData = function (parent, selection) {
    var result = [];
    var nodeData = {};
    nodeData.key = "Root";
    nodeData.token = "";
    nodeData.label = "";
    nodeData.gloss = "";
    nodeData.grammar = "";
    nodeData.lemma = "";
    nodeData.refersTo = "";
    nodeData.state = {
      expanded: true,
      selected: false
    };
    var children = _this.toChildrenNodes(parent, selection);
    if (children) {
      nodeData.nodes = children;
    }
    result.push(nodeData);
    return result;
  };

  this.toChildrenNodes = function (parent, selection) {
    var result = [];
    if (has(_this.nodeDependencies, parent)) {
      var keys = get(_this.nodeDependencies, parent);
      for (var i = 0; i < keys.length; i++) {
        var key = keys[i];
        var keyNumber = parseInt(key);
        var selectionNumber = parseInt(selection);
        var selected = keyNumber === selectionNumber;
        var node = _this.nodes[key];
        if (node) {
          var nodeData = {};
          nodeData.key = key;
          nodeData.token = node.token;
          nodeData.label = node.label;
          nodeData.gloss = node.gloss;
          nodeData.grammar = node.grammar;
          nodeData.lemma = node.lemma;
          nodeData.refersTo = node.refersTo;
          nodeData.state = {
            expanded: selected,
            selected: selected
          };
          var children = _this.toChildrenNodes(key, selection);
          if (children) {
            nodeData.nodes = children;
          }
          result.push(nodeData);
        }
      }
    }
    return result;
  };

  this.nodes = nodes;
  this.nodeDependencies = this.toDependencyMap();
}

/**
 * Creates a map such that
 * key = parent node id
 * value = an array of dependent nodes
 * @param nodes
 * @returns {{}}
 */


/**
 * Converts the flat array of token nodes from the web service
 * into a hierarchical representation, with a root node
 * and children.  This function makes a recursive call.
 * @param nodes
 * @param nodeDependencies
 * @param parent
 * @returns {Array}
 */
;

export default TreeViewUtils;