var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { get } from 'lodash';
import CitationButton from '../helpers/CitationButton';
import MessageIcons from '../helpers/MessageIcons';
import { EditorState, ContentState, convertToRaw } from 'draft-js';
import { Editor } from 'react-draft-wysiwyg';
import draftToHtml from 'draftjs-to-html';
import htmlToDraft from 'html-to-draftjs';

var RichEditor = (_temp = _class = function (_React$Component) {
  _inherits(RichEditor, _React$Component);

  function RichEditor(props) {
    _classCallCheck(this, RichEditor);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var blocksFromHtml = htmlToDraft(props.content);
    var contentBlocks = blocksFromHtml.contentBlocks,
        entityMap = blocksFromHtml.entityMap;

    var contentState = ContentState.createFromBlockArray(contentBlocks, entityMap);
    var editorState = EditorState.createWithContent(contentState);

    var mention = {};
    if (props.suggestions) {
      mention = {
        separator: ' ',
        trigger: '@',
        suggestions: _this.props.suggestions
      };
    }
    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      editorState: editorState,
      content: "",
      mention: mention
    };

    _this.handleStateChange = _this.handleStateChange.bind(_this);
    _this.onEditorStateChange = _this.onEditorStateChange.bind(_this);
    return _this;
  }

  // if we need to do something after setState, do it here...


  RichEditor.prototype.render = function render() {
    var editorState = this.state.editorState;

    return React.createElement(Editor, {
      editorState: editorState,
      wrapperClassName: 'RichEditor-root',
      editorClassName: 'RichEditor-editor',
      onEditorStateChange: this.onEditorStateChange,
      toolbarCustomButtons: [React.createElement(CitationButton, null)],
      spellCheck: true,
      toolbar: {
        options: ['inline'
        // , 'blockType'
        // , 'fontSize'
        // , 'list'
        , 'link', 'history'],
        inline: {
          options: ['bold', 'italic', 'underline']
        }
      },
      mention: this.state.mention
    });
  };

  return RichEditor;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {};

  this.componentDidMount = function () {
    // make any initial function calls here...
  };

  this.componentWillReceiveProps = function (nextProps) {
    var languageCode = nextProps.session.languageCode;
    var mention = {};
    if (nextProps.suggestions) {
      mention = {
        separator: ' ',
        trigger: '@',
        suggestions: nextProps.suggestions
      };
    }
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;

    _this2.setState(function (prevState, props) {
      return {
        message: labels[labelTopics.messages].initial,
        somethingWeTrackIfChanged: get(_this2.state, "somethingWeTrackIfChanged", ""),
        mention: mention
      };
    }, function () {
      return this.handleStateChange("place holder");
    });
  };

  this.handleStateChange = function (parm) {
    // call a function if needed
  };

  this.onEditorStateChange = function (editorState) {
    var plain = editorState.getCurrentContent().getPlainText();
    var html = draftToHtml(convertToRaw(editorState.getCurrentContent()));
    _this2.setState({
      editorState: editorState,
      plain: plain,
      html: html
    }, _this2.props.handleEditorChange(plain, html));
  };
}, _temp);
;

process.env.NODE_ENV !== "production" ? RichEditor.propTypes = {
  session: PropTypes.object.isRequired,
  handleEditorChange: PropTypes.func.isRequired,
  content: PropTypes.string,
  suggestions: PropTypes.array
} : void 0;

// set default values for props here
RichEditor.defaultProps = {
  languageCode: "en",
  content: "<p>Enter text here.</p>"
};

export default RichEditor;