'use strict';

exports.__esModule = true;
exports.NotesLister = undefined;

var _class, _temp, _initialiseProps;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _lodash = require('lodash');

var _ModalSchemaBasedEditor = require('./modules/ModalSchemaBasedEditor');

var _ModalSchemaBasedEditor2 = _interopRequireDefault(_ModalSchemaBasedEditor);

var _reactFontawesome = require('react-fontawesome');

var _reactFontawesome2 = _interopRequireDefault(_reactFontawesome);

var _reactBootstrap = require('react-bootstrap');

var _reactBootstrapTable = require('react-bootstrap-table');

var _UiSchemas = require('./classes/UiSchemas');

var _UiSchemas2 = _interopRequireDefault(_UiSchemas);

var _Server = require('./helpers/Server');

var _Server2 = _interopRequireDefault(_Server);

var _SchemaBasedAddButton = require('./modules/SchemaBasedAddButton');

var _SchemaBasedAddButton2 = _interopRequireDefault(_SchemaBasedAddButton);

var _IdManager = require('./helpers/IdManager');

var _IdManager2 = _interopRequireDefault(_IdManager);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Lists notes for a specific text made by the current user.
 * The ID of a UserNote is:
 * library = the user's personal library
* topic = library~topic~key (i.e. ID) of the text for which the note is made
 * key = timestamp of when the note was made.
 *
 * The NotesLister searches for notes matching the library and topic
 * of the UserNote ID.
 *
 */
var NotesLister = exports.NotesLister = (_temp = _class = function (_React$Component) {
  _inherits(NotesLister, _React$Component);

  function NotesLister(props) {
    _classCallCheck(this, NotesLister);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    _this.state = _this.setTheState(props, "");

    _this.deselectAllRows = _this.deselectAllRows.bind(_this);
    _this.fetchData = _this.fetchData.bind(_this);
    _this.getAddButton = _this.getAddButton.bind(_this);
    _this.getModalEditor = _this.getModalEditor.bind(_this);
    _this.getSelectedDocOptions = _this.getSelectedDocOptions.bind(_this);
    _this.handleAddClose = _this.handleAddClose.bind(_this);
    _this.handleCancelRequest = _this.handleCancelRequest.bind(_this);
    _this.handleCloseModal = _this.handleCloseModal.bind(_this);
    _this.handleDoneRequest = _this.handleDoneRequest.bind(_this);
    _this.handleGetForIdCallback = _this.handleGetForIdCallback.bind(_this);
    _this.handleRowSelect = _this.handleRowSelect.bind(_this);
    _this.onSizePerPageList = _this.onSizePerPageList.bind(_this);
    _this.setTheState = _this.setTheState.bind(_this);
    _this.showRowComparison = _this.showRowComparison.bind(_this);
    _this.verifyTextId = _this.verifyTextId.bind(_this);
    return _this;
  }

  // a method called by both the constructor and componentWillReceiveProps


  NotesLister.prototype.handleCancelRequest = function handleCancelRequest() {
    if (this.props.callback) {
      this.props.callback("", "");
    }
  };

  NotesLister.prototype.handleDoneRequest = function handleDoneRequest() {
    if (this.props.callback) {
      this.props.callback(this.state.selectedId, this.state.selectedValue);
    }
  };

  NotesLister.prototype.getSelectedDocOptions = function getSelectedDocOptions() {
    return _react2.default.createElement(
      _reactBootstrap.Panel,
      null,
      _react2.default.createElement(
        _reactBootstrap.FormGroup,
        null,
        _react2.default.createElement(
          _reactBootstrap.ControlLabel,
          null,
          this.state.searchLabels.selectedDoc
        ),
        _react2.default.createElement(_reactBootstrap.FormControl, {
          type: 'text',
          value: this.state.selectedId,
          disabled: true
        }),
        _react2.default.createElement(
          _reactBootstrap.ControlLabel,
          null,
          this.state.searchLabels.selectedDoc
        ),
        _react2.default.createElement(_reactBootstrap.FormControl, {
          type: 'text',
          value: this.state.selectedValue,
          disabled: true
        }),
        _react2.default.createElement(
          'div',
          null,
          _react2.default.createElement(
            _reactBootstrap.ButtonGroup,
            { bsSize: 'xsmall' },
            _react2.default.createElement(
              _reactBootstrap.Button,
              { onClick: this.handleCancelRequest },
              'Cancel'
            ),
            _react2.default.createElement(
              _reactBootstrap.Button,
              { onClick: this.handleDoneRequest },
              'Done'
            )
          )
        )
      )
    );
  };

  /**
   * font-awesome icons for messages
   * @type {{info: string, warning: string, error: string}}
   */


  NotesLister.prototype.setMessage = function setMessage(message) {
    this.setState({
      message: message
    });
  };

  NotesLister.prototype.fetchData = function fetchData(event) {
    var _this2 = this;

    this.setState({
      message: this.state.searchLabels.msg2,
      messageIcon: this.messageIcons.info
    });
    var config = {
      auth: {
        username: this.props.session.userInfo.username,
        password: this.props.session.userInfo.password
      }
    };

    var parms = "?t=" + encodeURIComponent(this.props.type) + "&q=" + encodeURIComponent(this.props.session.userInfo.domain + "~" + this.state.topicId) + "&p=id" + "&m=sw" + "&l=" + "&o=any";
    var path = this.props.session.restServer + _Server2.default.getDbServerNotesApi() + parms;
    _axios2.default.get(path, config).then(function (response) {
      // response.data will contain: "id, library, topic, key, value, tags, text"
      var resultCount = 0;
      var message = _this2.state.searchLabels.foundNone;
      var found = _this2.state.searchLabels.foundMany;
      var data = [];
      var showSearchResults = false;
      if (response.data.valueCount) {
        data = response.data;
        resultCount = data.valueCount;
        showSearchResults = resultCount > 0;
        if (resultCount === 0) {
          message = _this2.state.searchLabels.foundNone;
        } else if (resultCount === 1) {
          message = _this2.state.searchLabels.foundOne;
        } else {
          message = found + " " + resultCount + ".";
        }
      }

      _this2.setState({
        message: message,
        data: data,
        resultCount: resultCount,
        messageIcon: _this2.messageIcons.info,
        showSearchResults: showSearchResults,
        enableAdd: true
      });
    }).catch(function (error) {
      var message = error.message;
      var messageIcon = _this2.messageIcons.error;
      if (error && error.response && error.response.status === 404) {
        message = _this2.state.searchLabels.foundNone;
        messageIcon = _this2.messageIcons.warning;
        _this2.setState({ data: message, message: message, messageIcon: messageIcon });
      }
    });
  };

  NotesLister.prototype.render = function render() {
    return _react2.default.createElement(
      'div',
      { className: 'App-page App-Notes-Lister' },
      this.props.title && _react2.default.createElement(
        'h3',
        null,
        this.props.title
      ),
      _react2.default.createElement(
        'div',
        null,
        this.state.searchLabels.resultLabel,
        ': ',
        _react2.default.createElement(
          'span',
          { className: 'App App-message' },
          _react2.default.createElement(_reactFontawesome2.default, { name: this.state.messageIcon }),
          this.state.message,
          ' ',
          this.getAddButton()
        )
      ),
      this.state.showSearchResults && _react2.default.createElement(
        'div',
        null,
        this.state.searchLabels.msg5,
        ' ',
        this.state.searchLabels.msg6
      ),
      this.state.showModalEditor && this.getModalEditor(),
      this.state.showSearchResults && _react2.default.createElement(
        'div',
        { className: 'App-search-results' },
        _react2.default.createElement(
          'div',
          { className: 'row' },
          _react2.default.createElement(
            _reactBootstrapTable.BootstrapTable,
            {
              ref: 'theTable',
              data: this.state.data.values,
              exportCSV: false,
              trClassName: "App-data-tr",
              search: true,
              searchPlaceholder: this.state.resultsTableLabels.filterPrompt,
              striped: true,
              hover: true,
              pagination: true,
              options: this.state.options,
              selectRow: this.state.selectRow
            },
            _react2.default.createElement(
              _reactBootstrapTable.TableHeaderColumn,
              {
                isKey: true,
                dataField: 'id',
                dataSort: true,
                'export': true,
                hidden: true
              },
              'ID'
            ),
            _react2.default.createElement(
              _reactBootstrapTable.TableHeaderColumn,
              {
                dataField: 'topic',
                dataSort: true,
                'export': false,
                tdClassname: 'tdTopic',
                width: "10%"
              },
              this.state.resultsTableLabels.headerText
            ),
            _react2.default.createElement(
              _reactBootstrapTable.TableHeaderColumn,
              {
                dataField: 'key',
                dataSort: true,
                tdClassname: 'tdKey',
                width: "10%"
              },
              this.state.resultsTableLabels.headerDate
            ),
            _react2.default.createElement(
              _reactBootstrapTable.TableHeaderColumn,
              {
                dataField: 'tags',
                'export': false,
                dataSort: true,
                width: "10%"
              },
              this.state.resultsTableLabels.headerTags
            ),
            _react2.default.createElement(
              _reactBootstrapTable.TableHeaderColumn,
              {
                dataField: 'value',
                dataSort: true
              },
              this.state.resultsTableLabels.headerNote
            )
          )
        )
      )
    );
  };

  return NotesLister;
}(_react2.default.Component), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.componentWillMount = function () {
    _this3.fetchData();
  };

  this.componentWillReceiveProps = function (nextProps) {
    _this3.state = _this3.setTheState(nextProps, _this3.state.docType);
    _this3.verifyTextId(_this3.props.topicId, nextProps.topicId);
  };

  this.setTheState = function (props, docType) {

    var theSearchLabels = props.session.labels[props.session.labelTopics.searchNotes];

    var selectedId = "";
    if (docType) {
      if (props.initialType === docType) {
        selectedId = _this3.state.selectedId;
      }
    }

    var textIdParts = _IdManager2.default.getParts(_this3.props.topicId);
    var topicId = "gr_gr_cog" + "~" + textIdParts.topic + "~" + textIdParts.key;

    var uiSchemas = {};
    if (props.session && props.session.uiSchemas) {
      uiSchemas = new _UiSchemas2.default(props.session.uiSchemas.formsDropdown, props.session.uiSchemas.formsSchemas, props.session.uiSchemas.forms);
    }

    return {
      searchLabels: theSearchLabels,
      session: {
        uiSchemas: uiSchemas
      },
      docType: props.initialType,
      resultsTableLabels: props.session.labels[props.session.labelTopics.resultsTable],
      filterMessage: theSearchLabels.msg5,
      selectMessage: theSearchLabels.msg6,
      messageIcon: (0, _lodash.get)(_this3.state, "messageIcon", ""),
      message: (0, _lodash.get)(_this3.state, "message", ""),
      matcherTypes: [{ label: theSearchLabels.matchesAnywhere, value: "c" }, { label: theSearchLabels.matchesAtTheStart, value: "sw" }, { label: theSearchLabels.matchesAtTheEnd, value: "ew" }, { label: theSearchLabels.matchesRegEx, value: "rx" }],
      matcher: "c",

      query: "",

      suggestedQuery: "",

      propertyTypes: [{ label: "ID", value: "id" }, { label: "Value (insensitive)", value: "nnp" }, { label: "Value (sensitive)", value: "value" }],

      docPropMessage: "",

      docPropMessageById: "Search By ID searches the ID of the docs, with the parts domain~topic~key, e.g. gr_gr_cog~actors~Priest.",

      docPropMessageByValue: "Search By Value is insensitive to accents, case, and punctuation.",

      docPropMessageByValueSensitive: "Search By Value (sensitive) is sensitive to accents, case, and punctuation.",

      searchFormToggle: _this3.messageIcons.toggleOff,

      showSearchForm: true,

      searchFormType: "simple",

      showSearchResults: (0, _lodash.get)(_this3.state, "showSearchResults", false),

      resultCount: (0, _lodash.get)(_this3.state, "resultCount", 0),

      options: {
        sizePerPage: 30,
        sizePerPageList: [5, 15, 30],
        onSizePerPageList: _this3.onSizePerPageList,
        hideSizePerPage: true,
        paginationShowsTotal: true
      },

      selectRow: {
        mode: 'radio' // or checkbox
        , hideSelectColumn: false,
        clickToSelect: false,
        onSelect: _this3.handleRowSelect,
        className: "App-row-select"
      },

      showSelectionButtons: false,
      selectedId: selectedId,
      selectedLibrary: "",
      selectedTopic: "",
      selectedKey: "",
      title: "",
      selectedText: "",
      showModalEditor: false,
      idColumnSize: "80px",
      enableAdd: (0, _lodash.get)(_this3.state, "enableAdd", false),
      data: (0, _lodash.get)(_this3.state, "data", { values: [{ "id": "", "value:": "" }] }),
      topicId: topicId
    };
  };

  this.deselectAllRows = function () {
    _this3.refs.theTable.setState({
      selectedRowKeys: []
    });
  };

  this.handleRowSelect = function (row, isSelected, e) {
    _this3.setState({
      selectedId: row["id"],
      selectedLibrary: row["library"],
      selectedTopic: row["topic"],
      selectedKey: row["key"],
      title: row["id"],
      selectedText: row["text"],
      showIdPartSelector: true,
      showModalEditor: true
    });
  };

  this.showRowComparison = function (id) {
    _this3.setState({
      showModalEditor: true,
      selectedId: id
    });
  };

  this.handleCloseModal = function (id, value) {
    if (id && id.length > 0) {
      _this3.setState({
        showModalEditor: false,
        selectedId: id,
        selectedValue: value
      });
    } else {
      _this3.setState({
        showModalEditor: false
      });
    }
    _this3.deselectAllRows();
    _this3.fetchData();
  };

  this.getModalEditor = function () {
    return _react2.default.createElement(_ModalSchemaBasedEditor2.default, {
      session: _this3.props.session,
      restPath: _Server2.default.getDbServerDocsApi(),
      showModal: _this3.state.showModalEditor,
      title: _this3.state.title,
      fromId: _this3.state.selectedTopic,
      fromText: _this3.state.selectedText,
      idLibrary: _this3.state.selectedLibrary,
      idTopic: _this3.state.selectedTopic,
      idKey: _this3.state.selectedKey,
      onClose: _this3.handleCloseModal
    });
  };

  this.onSizePerPageList = function (sizePerPage) {
    _this3.setState({
      options: { sizePerPage: sizePerPage }
    });
  };

  this.messageIcons = {
    info: "info-circle",
    warning: "lightbulb-o",
    error: "exclamation-triangle"
    // , toggleOn: "eye"
    // , toggleOff: "eye-slash"
    , toggleOn: "toggle-on",
    toggleOff: "toggle-off",
    simpleSearch: "minus",
    advancedSearch: "bars",
    idPatternSearch: "key"
  };

  this.handleAddClose = function () {
    _this3.fetchData();
  };

  this.getAddButton = function () {
    if (_this3.state.enableAdd && _this3.state.session && _this3.state.session.uiSchemas) {
      var id = "UserNoteCreateForm:1.1";
      var textIdParts = _IdManager2.default.getParts(_this3.props.topicId);
      var topicId = "gr_gr_cog" + "~" + textIdParts.topic + "~" + textIdParts.key;
      var library = _this3.props.session.userInfo.domain;
      var date = new Date();
      var month = (date.getMonth() + 1).toString().padStart(2, "0");
      var day = date.getDate().toString().padStart(2, "0");
      var hour = date.getHours().toString().padStart(2, "0");
      var minute = date.getMinutes().toString().padStart(2, "0");
      var second = date.getSeconds().toString().padStart(2, "0");
      var key = date.getFullYear() + "." + month + "." + day + ".T" + hour + "." + minute + "." + second;
      return _react2.default.createElement(_SchemaBasedAddButton2.default, {
        session: _this3.props.session,
        restPath: _this3.state.session.uiSchemas.getHttpPostPathForSchema(id),
        uiSchema: _this3.state.session.uiSchemas.getUiSchema(id),
        schema: _this3.state.session.uiSchemas.getSchema(id),
        formData: _this3.state.session.uiSchemas.getForm(id),
        idLibrary: library,
        idTopic: topicId,
        idKey: key,
        seq: _IdManager2.default.toId(library, _this3.props.topicId, key),
        onClose: _this3.handleAddClose,
        fromId: _this3.props.topicId,
        fromText: _this3.props.topicText
      });
    } else {
      return _react2.default.createElement('span', null);
    }
  };

  this.handleGetForIdCallback = function (restCallResult) {
    var enableAdd = false;
    if (restCallResult && restCallResult.data && restCallResult.data.valueCount) {
      enableAdd = restCallResult.data.valueCount > 0;
    }
    _this3.setState({ enableAdd: enableAdd });
  };

  this.verifyTextId = function (currentId, nextId) {
    var needToVerify = true;

    if (_this3.state.enableAdd) {
      if (currentId) {
        if (currentId == nextId) {
          needToVerify = false;
        }
      }
    }
    if (needToVerify) {
      _this3.setState({ enableAdd: false });

      _Server2.default.restGetForId(_this3.props.session.restServer, _this3.props.session.userInfo.username, _this3.props.session.userInfo.password, nextId, _this3.handleGetForIdCallback);
    }
  };
}, _temp);


process.env.NODE_ENV !== "production" ? NotesLister.propTypes = {
  session: _propTypes2.default.object.isRequired,
  callback: _propTypes2.default.func,
  type: _propTypes2.default.string.isRequired,
  topicId: _propTypes2.default.string.isRequired,
  topicText: _propTypes2.default.string.isRequired
} : void 0;

exports.default = NotesLister;