'use strict';

exports.__esModule = true;

var _class, _temp, _initialiseProps;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _lodash = require('lodash');

var _reactBootstrap = require('react-bootstrap');

var _reactFontawesome = require('react-fontawesome');

var _reactFontawesome2 = _interopRequireDefault(_reactFontawesome);

var _reactSortableTree = require('react-sortable-tree');

var _reactSortableTree2 = _interopRequireDefault(_reactSortableTree);

var _Spinner = require('./helpers/Spinner');

var _Spinner2 = _interopRequireDefault(_Spinner);

var _MessageIcons = require('./helpers/MessageIcons');

var _MessageIcons2 = _interopRequireDefault(_MessageIcons);

var _ModalTemplateNodeEditor = require('./modules/ModalTemplateNodeEditor');

var _ModalTemplateNodeEditor2 = _interopRequireDefault(_ModalTemplateNodeEditor);

var _Server = require('./helpers/Server');

var _Server2 = _interopRequireDefault(_Server);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * This class provides a visual, drag-and-drop interface for
 * users to create templates to generate liturgical books or services.
 * It is a web browser replacement for the Java application ALWB.
 *
 * Note: if you try to drag and drop a node and you see a thick blue
 * line appear and it won't let you drop where you would like to,
 * the issue is the value for maxDepth.  It needs to be increased.
 */
var TemplateEditor = (_temp = _class = function (_React$Component) {
  _inherits(TemplateEditor, _React$Component);

  function TemplateEditor(props) {
    _classCallCheck(this, TemplateEditor);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var renderDepthTitle = function renderDepthTitle(_ref) {
      var path = _ref.path;
      return 'Depth: ' + path.length;
    };
    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        thisClass: labels[labelTopics.TemplateEditor],
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages]
      },
      messageIcons: _MessageIcons2.default.getMessageIcons(),
      messageIcon: _MessageIcons2.default.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      searchString: '',
      searchFocusIndex: 0,
      searchFoundCount: null,
      treeData: props.treeData,
      idKey: "head",
      showModalEditor: false,
      showModalReactSelector: false,
      selectorResource: [],
      selectorInitialValue: "",
      modalTitle: "",
      editingNode: undefined,
      editingPath: undefined,
      editingTreeIndex: undefined,
      selectedId: "" // from SearchText
      , selectedItem: "" // from ReactSelector
      , updating: false
    };

    _this.handleStateChange = _this.handleStateChange.bind(_this);

    _this.updateTreeData = _this.updateTreeData.bind(_this);

    _this.expandAll = _this.expandAll.bind(_this);
    _this.collapseAll = _this.collapseAll.bind(_this);

    _this.getNodeEditor = _this.getNodeEditor.bind(_this);
    _this.handleNodeEditorCallback = _this.handleNodeEditorCallback.bind(_this);

    _this.getMessages = _this.getMessages.bind(_this);
    _this.onSubmit = _this.onSubmit.bind(_this);
    _this.handleSubmitCallback = _this.handleSubmitCallback.bind(_this);

    return _this;
  }

  // if we need to do something after setState, do it here...


  TemplateEditor.prototype.updateTreeData = function updateTreeData(treeData) {
    this.setState({ treeData: treeData });
  };

  TemplateEditor.prototype.expand = function expand(expanded) {
    this.setState({
      treeData: (0, _reactSortableTree.toggleExpandedForAll)({
        treeData: this.state.treeData,
        expanded: expanded
      })
    });
  };

  TemplateEditor.prototype.expandAll = function expandAll() {
    this.expand(true);
  };

  TemplateEditor.prototype.collapseAll = function collapseAll() {
    this.expand(false);
  };

  TemplateEditor.prototype.render = function render() {
    var _this2 = this;

    var maxDepth = this.props.maxDepth;
    var _state = this.state,
        searchString = _state.searchString,
        searchFocusIndex = _state.searchFocusIndex,
        searchFoundCount = _state.searchFoundCount;


    var handleEditRequest = function handleEditRequest(node, path, treeIndex) {
      console.log("handleEditRequest");
      _this2.setState({
        editingNode: node,
        editingPath: path,
        editingTreeIndex: treeIndex,
        showModalEditor: true
      });

      var objectString = Object.keys(node).map(function (k) {
        return k === 'children' ? 'children: Array' : k + ': \'' + node[k] + '\'';
      }).join(',\n   ');

      console.log('Info passed to the button generator:\n\n' + ('node: {\n   ' + objectString + '\n},\n') + ('path: [' + path.join(', ') + '],\n') + ('treeIndex: ' + treeIndex));
    };

    var selectPrevMatch = function selectPrevMatch() {
      return _this2.setState({
        searchFocusIndex: searchFocusIndex !== null ? (searchFoundCount + searchFocusIndex - 1) % searchFoundCount : searchFoundCount - 1
      });
    };

    var selectNextMatch = function selectNextMatch() {
      return _this2.setState({
        searchFocusIndex: searchFocusIndex !== null ? (searchFocusIndex + 1) % searchFoundCount : 0
      });
    };

    var isVirtualized = false;
    var treeContainerStyle = isVirtualized ? { height: 450 } : {};
    var getNodeKey = function getNodeKey(_ref2) {
      var treeIndex = _ref2.treeIndex;
      return treeIndex;
    };

    return _react2.default.createElement(
      'div',
      { className: 'App App-Template-Editor' },
      this.state.showModalEditor && this.getNodeEditor(),
      _react2.default.createElement(
        _reactBootstrap.Well,
        null,
        _react2.default.createElement(
          'h3',
          null,
          this.state.labels.thisClass.panelTitle
        ),
        _react2.default.createElement(
          _reactBootstrap.Button,
          { className: 'App-Template-Editor-Button', bsStyle: 'primary', bsSize: 'small', onClick: this.expandAll },
          this.state.labels.thisClass.expandAll
        ),
        _react2.default.createElement(
          _reactBootstrap.Button,
          { className: 'App-Template-Editor-Button', bsStyle: 'primary', bsSize: 'small', onClick: this.collapseAll },
          this.state.labels.thisClass.collapseAll
        ),
        '\xA0\xA0\xA0\xA0\xA0\xA0\xA0\xA0',
        _react2.default.createElement(
          'form',
          {
            style: { display: 'inline-block' },
            onSubmit: function onSubmit(event) {
              event.preventDefault();
            }
          },
          _react2.default.createElement(
            'label',
            { htmlFor: 'find-box' },
            'Search:\xA0',
            _react2.default.createElement('input', {
              id: 'find-box',
              type: 'text',
              value: searchString,
              onChange: function onChange(event) {
                return _this2.setState({ searchString: event.target.value });
              }
            })
          ),
          _react2.default.createElement(
            _reactBootstrap.Button,
            {
              className: 'App-Template-Editor-Button',
              bsStyle: 'primary',
              bsSize: 'xsmall',
              type: 'button',
              disabled: !searchFoundCount,
              onClick: selectPrevMatch
            },
            '<'
          ),
          _react2.default.createElement(
            _reactBootstrap.Button,
            {
              className: 'App-Template-Editor-Button-Search',
              bsStyle: 'primary',
              bsSize: 'xsmall',
              type: 'submit',
              disabled: !searchFoundCount,
              onClick: selectNextMatch
            },
            '>'
          ),
          _react2.default.createElement(
            'span',
            null,
            '\xA0',
            searchFoundCount > 0 ? searchFocusIndex + 1 : 0,
            '\xA0/\xA0',
            searchFoundCount || 0
          )
        ),
        _react2.default.createElement(
          'div',
          { style: treeContainerStyle },
          _react2.default.createElement(_reactSortableTree2.default, {
            treeData: this.state.treeData,
            onChange: this.updateTreeData,
            onMoveNode: function onMoveNode(_ref3) {
              var node = _ref3.node,
                  treeIndex = _ref3.treeIndex,
                  path = _ref3.path;
              return console.debug('node:', node, 'treeIndex:', treeIndex, 'path:', path);
            },
            maxDepth: maxDepth,
            searchQuery: searchString,
            searchFocusOffset: searchFocusIndex,
            canDrag: function canDrag(_ref4) {
              var node = _ref4.node;
              return !node.noDragging;
            },
            canDrop: function canDrop(_ref5) {
              var nextParent = _ref5.nextParent;
              return !nextParent || !nextParent.noChildren;
            },
            searchFinishCallback: function searchFinishCallback(matches) {
              return _this2.setState({
                searchFoundCount: matches.length,
                searchFocusIndex: matches.length > 0 ? searchFocusIndex % matches.length : 0
              });
            },
            isVirtualized: isVirtualized,
            generateNodeProps: function generateNodeProps(_ref6) {
              var node = _ref6.node,
                  path = _ref6.path,
                  treeIndex = _ref6.treeIndex;
              return {
                buttons: [_react2.default.createElement(
                  _reactBootstrap.Button,
                  {
                    className: 'App-Template-Editor-Node-Button',
                    bsStyle: 'default',
                    bsSize: 'xsmall',
                    onClick: function onClick() {
                      return handleEditRequest(node, path, treeIndex);
                    }
                  },
                  _react2.default.createElement(_reactFontawesome2.default, { name: _this2.state.messageIcons.pencil })
                ), _react2.default.createElement(
                  _reactBootstrap.Button,
                  {
                    className: 'App-Template-Editor-Node-Button',
                    bsStyle: 'default',
                    bsSize: 'xsmall',
                    onClick: function onClick() {
                      return _this2.setState(function (state) {
                        return {
                          treeData: (0, _reactSortableTree.addNodeUnderParent)({
                            treeData: state.treeData,
                            parentKey: path[path.length - 1],
                            expandParent: true,
                            getNodeKey: getNodeKey,
                            newNode: {
                              title: "tbd", subtitle: "", config: "" }
                          }).treeData
                        };
                      });
                    }
                  },
                  _react2.default.createElement(_reactFontawesome2.default, { name: _this2.state.messageIcons.plus })
                ), _react2.default.createElement(
                  _reactBootstrap.Button,
                  {
                    className: 'App-Template-Editor-Node-Button',
                    bsStyle: 'default',
                    bsSize: 'xsmall',
                    onClick: function onClick() {
                      return _this2.setState(function (state) {
                        return {
                          treeData: (0, _reactSortableTree.removeNodeAtPath)({
                            treeData: state.treeData,
                            path: path,
                            getNodeKey: getNodeKey
                          })
                        };
                      });
                    }
                  },
                  _react2.default.createElement(_reactFontawesome2.default, { name: _this2.state.messageIcons.trash })
                )]
              };
            }
          }),
          this.getSubmitButton()
        )
      )
    );
  };

  return TemplateEditor;
}(_react2.default.Component), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.componentWillMount = function () {};

  this.componentDidMount = function () {
    // make any initial function calls here...
  };

  this.componentWillReceiveProps = function (nextProps) {
    _this3.setState(function (prevState, props) {
      var labels = nextProps.session.labels;
      var labelTopics = nextProps.session.labelTopics;

      return {
        labels: {
          thisClass: labels[labelTopics.TemplateEditor],
          buttons: labels[labelTopics.button],
          messages: labels[labelTopics.messages]
        },
        message: labels[labelTopics.messages].initial,
        treeData: nextProps.treeData,
        updating: false,
        showModalEditor: false,
        showModalReactSelector: false,
        selectorResource: [],
        selectorInitialValue: "",
        modalTitle: "",
        editingNode: undefined,
        editingPath: undefined,
        editingTreeIndex: undefined,
        selectedId: "" // from SearchText
        , selectedItem: "" // from ReactSelector
      };
    }, function () {
      return this.handleStateChange("place holder");
    });
  };

  this.handleStateChange = function (parm) {
    // call a function if needed
  };

  this.getNodeEditor = function () {
    if (_this3.state.showModalEditor) {
      return _react2.default.createElement(_ModalTemplateNodeEditor2.default, {
        session: _this3.props.session,
        showModal: _this3.state.showModalEditor,
        node: _this3.state.editingNode,
        path: _this3.state.editingPath,
        treeIndex: _this3.state.editingTreeIndex,
        callBack: _this3.handleNodeEditorCallback,
        templateLibrary: _this3.props.idLibrary,
        templateTopic: _this3.props.idTopic
      });
    }
  };

  this.handleNodeEditorCallback = function (node) {
    _this3.setState({
      showModalEditor: false
    }, console.log('handleNodeEditorCallback, this.state.showModalEditor=' + _this3.state.showModalEditor));
  };

  this.onSubmit = function () {
    _this3.setState({
      updating: true
    });
    var formData = _this3.props.formData;
    formData.node = JSON.stringify(_this3.state.treeData[0]);
    var config = {
      auth: {
        username: _this3.props.session.userInfo.username,
        password: _this3.props.session.userInfo.password
      }
    };
    var path = _Server2.default.getDbServerTemplatesApi() + "/" + _this3.props.idLibrary + "/" + _this3.props.idTopic + "/" + _this3.props.idKey;
    _Server2.default.restPutSchemaBasedForm(_this3.props.session.restServer, _this3.props.session.userInfo.username, _this3.props.session.userInfo.password, path, formData, undefined, _this3.handleSubmitCallback);
  };

  this.handleSubmitCallback = function (restCallResult) {
    if (restCallResult) {
      _this3.setState({
        message: restCallResult.message,
        messageIcon: restCallResult.messageIcon,
        updating: false
      });
    }
  };

  this.getSubmitButton = function () {
    if (_this3.props.formData) {
      return _react2.default.createElement(
        _reactBootstrap.Grid,
        null,
        _react2.default.createElement(
          _reactBootstrap.Row,
          { className: 'show-grid App-Template-Editor-Submit-Row' },
          _react2.default.createElement(
            _reactBootstrap.Col,
            { sm: 12, md: 12 },
            _react2.default.createElement(
              _reactBootstrap.Button,
              {
                className: "App-Template-Editor-Submit-Button",
                bsStyle: 'primary',
                onClick: _this3.onSubmit
              },
              _this3.state.labels.buttons.submit
            ),
            _this3.getMessages()
          )
        )
      );
    }
  };

  this.getMessages = function () {
    if (_this3.state.updating) {
      return _react2.default.createElement(
        'span',
        null,
        _react2.default.createElement(_Spinner2.default, { message: _this3.state.labels.messages.updating })
      );
    } else {
      return _react2.default.createElement(
        'span',
        null,
        _react2.default.createElement(_reactFontawesome2.default, { name: _this3.state.messageIcon }),
        _this3.state.message
      );
    }
  };
}, _temp);


process.env.NODE_ENV !== "production" ? TemplateEditor.propTypes = {
  session: _propTypes2.default.object.isRequired,
  idLibrary: _propTypes2.default.string.isRequired,
  idTopic: _propTypes2.default.string.isRequired,
  treeData: _propTypes2.default.array,
  maxDepth: _propTypes2.default.number,
  formData: _propTypes2.default.object,
  uiSchema: _propTypes2.default.object,
  schema: _propTypes2.default.object
} : void 0;

TemplateEditor.defaultProps = {
  languageCode: "en",
  treeData: [{
    title: 'Template',
    subtitle: 'tbd',
    expanded: true,
    children: [{
      title: "Section",
      subtitle: 'tbd',
      children: []
    }]
  }],
  maxDepth: 20
};

process.env.NODE_ENV !== "production" ? TemplateEditor.propTypes = {
  session: _propTypes2.default.object.isRequired,
  treeData: _propTypes2.default.array.isRequired,
  idLibrary: _propTypes2.default.string.isRequired,
  idTopic: _propTypes2.default.string.isRequired
} : void 0;

exports.default = TemplateEditor;
module.exports = exports['default'];