"use strict";

exports.__esModule = true;

var _labels = require("./labels.json");

var _labels2 = _interopRequireDefault(_labels);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var Labels = function Labels(value) {
  var _this = this;

  _classCallCheck(this, Labels);

  this.getAllLabels = function (code) {
    if (_this.labels[code]) {
      return _this.labels[code];
    } else {
      return _this.labels["en"];
    }
  };

  this.getLabels = function (code, topic) {
    if (_this.labels[code]) {
      return _this.labels[code][topic];
    } else {
      return _this.labels["en"][topic];
    }
  };

  this.getAgesEditorLabels = function (code) {
    return _this.getLabels(code, "AgesEditor");
  };

  this.getAgesViewerLabels = function (code) {
    return _this.getLabels(code, "AgesViewer");
  };

  this.getBibleRefSelectorLabels = function (code) {
    return _this.getLabels(code, "BibleRefSelector");
  };

  this.getButtonLabels = function (code) {
    return _this.getLabels(code, "button");
  };

  this.getChangePasswordPageLabels = function (code) {
    return _this.getLabels(code, "ChangePasswordPage");
  };

  this.getComponentNewEntryLabels = function (code) {
    return _this.getLabels(code, "NewEntry");
  };

  this.getComponentParaTextEditorLabels = function (code) {
    return _this.getLabels(code, "ParaTextEditor");
  };

  this.getDeleteButtonLabels = function (code) {
    return _this.getLabels(code, "deleteButton");
  };

  this.getDependencyDiagramLabels = function (code) {
    return _this.getLabels(code, "DependencyDiagram");
  };

  this.getFormattedTextNoteLabels = function (code) {
    return _this.getLabels(code, "FormattedTextNote");
  };

  this.getGenericNewEntryFormLabels = function (code) {
    return _this.getLabels(code, "GenericNewEntryForm");
  };

  this.getGlossBuilderLabels = function (code) {
    return _this.getLabels(code, "GlossBuilder");
  };

  this.getGrammarLabels = function (code) {
    return _this.getLabels(code, "Grammar");
  };

  this.getGrammarTerms = function (code, category) {
    var theCode = code;
    if (!_this.labels[code]) {
      theCode = "en";
    }
    if (category) {
      return _this.labels[theCode].grammarTerms[category];
    } else {
      return _this.labels[theCode].grammarTerms;
    }
  };

  this.getGrammarTermsCase = function (code) {
    return _this.getLabels(code, "grammarTerms.case");
  };

  this.getGrammarTermsCategories = function (code) {
    return _this.getLabels(code, "grammarTerms.categories");
  };

  this.getGrammarTermsGender = function (code) {
    return _this.getLabels(code, "grammarTerms.gender");
  };

  this.getGrammarTermsMood = function (code) {
    return _this.getLabels(code, "grammarTerms.mood");
  };

  this.getGrammarTermsNumber = function (code) {
    return _this.getLabels(code, "grammarTerms.number");
  };

  this.getGrammarTermsPartsOfSpeech = function (code) {
    return _this.getLabels(code, "grammarTerms.pos");
  };

  this.getGrammarTermsPerson = function (code) {
    return _this.getLabels(code, "grammarTerms.person");
  };

  this.getGrammarTermsTense = function (code) {
    return _this.getLabels(code, "grammarTerms.tense");
  };

  this.getGrammarTermsVoice = function (code) {
    return _this.getLabels(code, "grammarTerms.voice");
  };

  this.getHeaderLabels = function (code) {
    return _this.getLabels(code, "header");
  };

  this.getHelpLabels = function (code) {
    return _this.getLabels(code, "help");
  };

  this.getHttpCodeLabels = function (code) {
    return _this.getLabels(code, "httpCodes");
  };

  this.getHttpMessage = function (languageCode, errorCode, errorMessage) {
    var message = "";
    if (_this.labels[languageCode].httpCodes[errorCode]) {
      message = labels[languageCode].httpCodes[errorCode];
    } else {
      message = errorMessage;
    }
    return message;
  };

  this.getHyperTokenTextLabels = function (code) {
    return _this.getLabels(code, "HyperTokenText");
  };

  this.getJson = function () {
    return JSON.stringify(_this.labels);
  };

  this.getLdpLabels = function (code) {
    return _this.getLabels(code, "ldp");
  };

  this.getLinkSearchResultsTableLabels = function (code) {
    return _this.getLabels(code, "linkSearchResultsTable");
  };

  this.getLiturgicalAcronymsLabels = function (code) {
    return _this.getLabels(code, "liturgicalAcronyms");
  };

  this.getMessageLabels = function (code) {
    return _this.getLabels(code, "messages");
  };

  this.getModalAgesServiceSelectorLabels = function (code) {
    return _this.getLabels(code, "ModalAgesServiceSelector");
  };

  this.getModalParaRowEditorLabels = function (code) {
    return _this.getLabels(code, "ModalParaRowEditor");
  };

  this.getModalReactSelectorLabels = function (code) {
    return _this.getLabels(code, "ModalReactSelector");
  };

  this.getModalTemplateNodeEditorLabels = function (code) {
    return _this.getLabels(code, "ModalTemplateNodeEditor");
  };

  this.getNewEntryFormLabels = function (code) {
    return _this.getLabels(code, "NewEntryForm");
  };

  this.getOntologyRefSelectorLabels = function (code) {
    return _this.getLabels(code, "OntologyRefSelector");
  };

  this.getPageAboutLabels = function (code) {
    return _this.getLabels(code, "pageAbout");
  };

  this.getPageLoginLabels = function (code) {
    return _this.getLabels(code, "pageLogin");
  };

  this.getParaColTextEditorLabels = function (code) {
    return _this.getLabels(code, "ParaColTextEditor");
  };

  this.getResultsTableLabels = function (code) {
    return _this.getLabels(code, "resultsTable");
  };

  this.getRichEditorLabels = function (code) {
    return _this.getLabels(code, "RichEditor");
  };

  this.getSchemaBasedAddButtonLabels = function (code) {
    return _this.getLabels(code, "schemaBasedAddButton");
  };

  this.getSearchGenericLabels = function (code) {
    return _this.getLabels(code, "SearchGeneric");
  };

  this.getSearchLabels = function (code) {
    return _this.getLabels(code, "search");
  };

  this.getSearchLinksLabels = function (code) {
    return _this.getLabels(code, "searchLinks");
  };

  this.getSearchNotesLabels = function (code) {
    return _this.getLabels(code, "searchNotes");
  };

  this.getSearchOntologyLabels = function (code) {
    return _this.getLabels(code, "searchOntology");
  };

  this.getSearchTemplatesLabels = function (code) {
    return _this.getLabels(code, "searchTemplates");
  };

  this.getSearchTreebanksLabels = function (code) {
    return _this.getLabels(code, "searchTreebanks");
  };

  this.getTemplateEditorLabels = function (code) {
    return _this.getLabels(code, "TemplateEditor");
  };

  this.getTemplateForTableLabels = function (code) {
    return _this.getLabels(code, "templateForTable");
  };

  this.getTemplateLabels = function (code) {
    return _this.getLabels(code, "template");
  };

  this.getTextNoteEditorLabels = function (code) {
    return _this.getLabels(code, "TextNoteEditor");
  };

  this.getTokenTaggerLabels = function (code) {
    return _this.getLabels(code, "TokenTagger");
  };

  this.getTopicsSelectorLabels = function (code) {
    return _this.getLabels(code, "TopicsSelector");
  };

  this.getTreebankSearchResultsTableLabels = function (code) {
    return _this.getLabels(code, "treebanksResultsTable");
  };

  this.getUiLabelEditorLabels = function (code) {
    return _this.getLabels(code, "UiLabelEditor");
  };

  this.getViewReferencesLabels = function (code) {
    return _this.getLabels(code, "ViewReferences");
  };

  this.getViewRelationshipsLabels = function (code) {
    return _this.getLabels(code, "ViewRelationships");
  };

  this.getWorkflowAssignmentLabels = function (code) {
    return _this.getLabels(code, "WorkflowAssignment");
  };

  this.getWorkflowFormLabels = function (code) {
    return _this.getLabels(code, "WorkflowForm");
  };

  console.log("CONSTRUCTOR");
  console.log(value);
  this.labels = {};
  if (value) {
    this.labels = value;
  } else {
    this.labels = _labels2.default;
  }
  console.log(this.labels);
  console.log(this.labels.en);
  console.log(this.labels.en.AgesEditor.agesEnglish);
  console.log(this.labels.en.help["search.headerDomain"]);
  this.labels["el"]["UiLabelEditor"] = {
    panelTitle: "View and Edit Parallel Texts in Columns",
    msg1: "Select a topic, then select one or more libraries.  Then click the button.",
    msg2: "Double-Click to edit a cell. You can sort the columns using the up and down triangles. You can filter a column by typing in the box below the column name. Clear the filters using the button to the right.",
    key: "Key",
    view: "Select a topic...",
    including: "Including",
    select: "you may select up to ",
    libraries: "libraries.",
    sourceRequired: "You must include the source library ",
    maxLibraries: "The maximum of number of libraries you may select is"
  };
  this.labels["en"]["UiLabelEditor"] = {
    panelTitle: "View and Edit Parallel Texts in Columns",
    msg1: "Select a topic, then select one or more libraries.  Then click the button.",
    msg2: "Double-Click to edit a cell. You can sort the columns using the up and down triangles. You can filter a column by typing in the box below the column name. Clear the filters using the button to the right.",
    key: "Key",
    view: "Select a topic...",
    including: "Including",
    select: "you may select up to ",
    libraries: "libraries.",
    sourceRequired: "You must include the source library ",
    maxLibraries: "The maximum of number of libraries you may select is"
  };
  return this;
};

exports.default = Labels;
module.exports = exports["default"];