"use strict";

exports.__esModule = true;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * UiSchemas
 * Provides a container for globally available
 * schema information for the rendering
 * and editing of forms.
 *
 * A form has a schema for its data.
 * It also has a uiSchema, that describes
 * the components to present the form as
 * a user interface.
 */
var UiSchemas = function UiSchemas(formsDropdown, formsSchemas, forms, adminForms) {
  var _this = this;

  _classCallCheck(this, UiSchemas);

  this.getFormsDropdown = function () {
    return _this.formsDropdown;
  };

  this.getSchema = function (id) {
    return _this.formsSchemas[id].schema;
  };

  this.getUiSchema = function (id) {
    return _this.formsSchemas[id].uiSchema;
  };

  this.getSchema = function (id) {
    return _this.formsSchemas[id].schema;
  };

  this.getForm = function (id) {
    return _this.forms[id];
  };

  this.getHttpGetPathForSchema = function (id) {
    return _this.formsSchemas[id].paths.get;
  };

  this.getHttpPostPathForSchema = function (id) {
    return _this.formsSchemas[id].paths.post;
  };

  this.getHttpPutPathForSchema = function (id) {
    var schemaId = id;
    if (_this.formsSchemas[id]) {
      // ignore
    } else {
      schemaId = _this.getCreateSchemaIdForSchemaId(id);
    }
    if (_this.formsSchemas[schemaId]) {
      return _this.formsSchemas[schemaId].paths.put;
    } else {
      console.log("UiSchemas.getHttpPutPathForSchema.schemaId " + schemaId + " not found");
      console.table(_this.formsSchemas);
    }
  };

  this.getPropsForSchema = function (id, exclusions) {
    var keys = [];
    for (var key in _this.formsSchemas[id].schema.properties) {
      if (exclusions.includes(key)) {
        // skip
      } else {
        keys.push(key);
      }
    }
    return keys;
  };

  this.getCreateSchemaIdForSchemaId = function (id) {
    var name = id;
    var parts = id.split(":");
    if (parts.length === 2) {
      if (!name.endsWith("CreateForm")) {
        name = parts[0] + "CreateForm";
      }
      name = name + ":1.1";
    }
    return name;
  };

  this.getLinkCreateSchemaIdForSchemaId = function (id) {
    var name = id;
    var parts = id.split(":");
    if (parts.length === 2) {
      if (parts[0] === "TextBiblical") {
        name = "LinkRefersToBiblicalTextCreateForm";
      } else {
        name = "LinkRefersTo" + parts[0];
        if (!name.endsWith("CreateForm")) {
          name = name + "CreateForm";
        }
      }
      name = name + ":1.1";
    }
    return name;
  };

  this.formsDropdown = formsDropdown;
  this.formsSchemas = formsSchemas;
  this.forms = forms;
  this.adminForms = adminForms;
}

/**
 * Get the schema whose id matches the parameter
 * @param id
 * @returns {*}
 */


/**
 * Get the uiSchema whose id matches the parameter
 * @param id
 * @returns {*}
 */


/**
 * Get the formsSchema whose id matches the parameter
 * @param id
 * @returns {*}
 */


/**
 * Get the form whose id matches the parameter
 * @param id
 * @returns {*}
 */


/**
 * Get the HTTP GET path for the form whose id matches the parameter
 * @param id
 * @returns {*}
 */

/**
 * Get the HTTP POST path for the form whose id matches the parameter
 * @param id
 * @returns {*}
 */

/**
 * Get the HTTP PUT path for the form whose id matches the parameter
 * @param id
 * @returns {*}
 */


/**
 * Uses the supplied ID to convert it to its
 * corresponding CreateForm
 * @param id
 * @returns {*}
 */


/**
 * Uses the supplied ID to convert it to its
 * corresponding LinkRefersTo...CreateForm
 * @param id
 * @returns {*}
 */
;

exports.default = UiSchemas;
module.exports = exports["default"];