'use strict';

exports.__esModule = true;

var _MessageIcons = require('./MessageIcons');

var _MessageIcons2 = _interopRequireDefault(_MessageIcons);

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _fileSaver = require('file-saver');

var _fileSaver2 = _interopRequireDefault(_fileSaver);

var _IdManager = require('./IdManager');

var _IdManager2 = _interopRequireDefault(_IdManager);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Created by mac002 on 1/2/17.
 *
 * Note: June 1, 2017 -- I am in the process of creating functions
 * in this class that result in this being the only place that
 * calls Axios.  Only a few have been taken care of so far.
 */
var adminApi = "/admin/api/v1/";
var dbApi = "/db/api/v1/";
var lookupApi = dbApi + "id/";
var uilabels = "docs/uilabels";
var ldpApi = "/ldp/api/v1/";
var resources = "docs/new";
var version = "info";
var changePassword = "users/passwordchange";
var login = "login/form";
var loginUser = "login/user";
var links = "links";
var docs = "docs";
var generic = docs + "/generic";
var genericExists = docs + "/genericexists";
var notes = docs + "/notes";
var userdocs = docs + "/userdocs";
var treebanks = docs + "/treebanks";
var agesPdf = docs + "/agespdf";
var clone = docs + "/clone";
var agesIndex = docs + "/agesindex";
var agesReactTemplate = docs + "/agesreacttemplate";
var agesReadOnlyTemplate = docs + "/agesreadonlytemplate";
var nlp = "nlp/";
var ontology = "ontology/ontology";
var tables = docs + "/tables/";
var tableLexiconOald = "en_sys_tables/LexiconTable/OALD";
var templates = docs + "/templates";
var valuePath = docs + "/value";
var viewtemplate = docs + "/viewtemplate";
var viewtopic = docs + "/viewtopic";
var wordAnalysis = "nlp/word/analysis";
var textAnalysis = nlp + "text/analysis";
var textDownloads = docs + "/textdownloads";
var adminDomains = "misc/domains";
var dbDropdownsSearchAbbreviations = "dropdowns/abbreviations";
var dbDropdownsSearchBibliography = "dropdowns/bibliography";
var dbDropdownsSearchText = "dropdowns/texts";
var dbDropdownsSearchTemplates = "dropdowns/templates";
var dbDropdownsSearchNotes = "dropdowns/notes";
var dbDropdownsUserRolesForDomain = "domains/userdropdown";
var dbDomainsCollective = "domains/collective";
var dbDropdownsOntologyEntites = "dropdowns/ontologyentities";
var dbDropdownsSearchOntology = "dropdowns/ontology";
var dbDropdownDomains = "dropdowns/domains";
var dbDropdownsSearchRelationships = "dropdowns/relationships";
var dbDropdownsSearchTreebanks = "dropdowns/treebanks";
var dbDropdownsGrLibTopics = "dropdowns/grlibtopics";
var ldp = "ldp";
var messageIcons = _MessageIcons2.default.getMessageIcons();
var requests = new Map();

var getTimestamp = function getTimestamp() {
  var date = new Date();
  var month = (date.getMonth() + 1).toString().padStart(2, "0");
  var day = date.getDate().toString().padStart(2, "0");
  var hour = date.getHours().toString().padStart(2, "0");
  var minute = date.getMinutes().toString().padStart(2, "0");
  var second = date.getSeconds().toString().padStart(2, "0");
  var idKey = date.getFullYear() + "." + month + "." + day + ".T" + hour + "." + minute + "." + second;
  return idKey;
};

/**
 * The request tokens are used to cancel
 * promises when a component unmounts before
 * the promise has been fulfilled.  The
 * component needs to do this in the componentWillUnmount
 * method.  See Grammar as an example.
 * @returns {string}
 */
var _getRequestToken = function _getRequestToken() {
  var token = getTimestamp();
  requests.set(token, "live");
  return token;
};

var _cancelRequest = function _cancelRequest(token) {
  if (requests.has(token)) {
    requests.delete(token);
  }
};

var _restGetPromise = function _restGetPromise(restServer, serverPath, username, password, parms) {
  return new Promise(function (resolve, reject) {
    var responseType = "application/json";
    if (serverPath.includes('pdf')) {
      responseType = "blob";
    }
    var config = {
      auth: {
        username: username,
        password: password
      },
      responseType: responseType
    };

    var path = restServer + serverPath;

    if (parms && parms.length > 0) {
      path = path + "?" + parms;
    }

    var result = {
      data: {},
      userMessage: "OK",
      developerMessage: "OK",
      messageIcon: messageIcons.info,
      status: 200
    };

    _axios2.default.get(path, config).then(function (response) {
      result.userMessage = response.data.status.userMessage;
      result.developerMessage = response.data.status.developerMessage;
      result.code = response.data.status.code;
      result.data = response.data;
      resolve(result);
    }).catch(function (error) {
      result.message = error.message;
      result.messageIcon = messageIcons.error;
      result.status = error.status;
      reject(result);
    });
  });
};

var restGetPublicPromise = function restGetPublicPromise(restServer, serverPath, parms, callback) {
  return new Promise(function (resolve, reject) {
    var responseType = "application/json";
    if (serverPath.includes('pdf')) {
      responseType = "blob";
    }
    var config = {
      responseType: responseType
    };

    var path = restServer + serverPath;

    if (parms && parms.length > 0) {
      path = path + "?" + parms;
    }

    var result = {
      data: {},
      userMessage: "OK",
      developerMessage: "OK",
      messageIcon: messageIcons.info,
      status: 200
    };

    _axios2.default.get(path, config).then(function (response) {
      result.userMessage = response.data.status.userMessage;
      result.developerMessage = response.data.status.developerMessage;
      result.code = response.data.status.code;
      result.data = response.data;
      callback(result);
    }).catch(function (error) {
      result.message = error.message;
      result.messageIcon = messageIcons.error;
      result.status = error.status;
      callback(result);
    });
  });
};

var _restGetPdf = function _restGetPdf(restServer, serverPath, username, password, parms, filename) {
  return new Promise(function (resolve, reject) {
    var responseType = "blob";
    var config = {
      auth: {
        username: username,
        password: password
      },
      responseType: responseType
    };

    var path = restServer + serverPath;

    if (parms && parms.length > 0) {
      path = path + "?" + parms;
    }

    var result = {
      data: {},
      userMessage: "OK",
      developerMessage: "OK",
      messageIcon: messageIcons.info,
      status: 200
    };

    _axios2.default.get(path, config).then(function (response) {
      var blob = new Blob([response.data], { type: 'application/pdf' });
      _fileSaver2.default.saveAs(blob, filename);
      result.userMessage = "ok";
      result.developerMessage = "ok";
      result.code = "200";
      result.data = response.data;
      resolve(result);
    }).catch(function (error) {
      result.message = error.message;
      result.messageIcon = messageIcons.error;
      result.status = error.status;
      reject(result);
    });
  });
};

var _restGetAddress = function _restGetAddress(callback) {
  return new Promise(function (resolve, reject) {
    var path = "https://api.ipify.org/?format=json";
    var result = {
      ip: "",
      status: 0
    };

    _axios2.default.get(path).then(function (response) {
      result.status = response.status;
      result.ip = response.data.ip;
      callback(result);
    }).catch(function (error) {
      result.message = error.message;
      result.messageIcon = messageIcons.error;
      result.status = error.status;
      callback(result);
    });
  });
};

var _restGetLocation = function _restGetLocation(address, callback) {
  return new Promise(function (resolve, reject) {
    var path = "http://ip-api.com/json/" + address;

    var result = {
      location: "",
      userMessage: "OK",
      developerMessage: "OK",
      messageIcon: messageIcons.info,
      status: 200
    };

    _axios2.default.get(path).then(function (response) {
      result.status = response.status;
      result.location = response.data.countryCode + "|" + response.data.country + "|" + response.data.region + "|" + response.data.regionName + "|" + response.data.city;
      callback(result);
    }).catch(function (error) {
      result.status = error.status;
      callback(result);
    });
  });
};

var _restGetUserDocs = function _restGetUserDocs(restServer, serverPath, username, password) {
  return new Promise(function (resolve, reject) {
    var responseType = "blob";
    var config = {
      auth: {
        username: username,
        password: password
      },
      responseType: responseType
    };

    var path = restServer + serverPath;

    var result = {
      data: {},
      userMessage: "OK",
      developerMessage: "OK",
      messageIcon: messageIcons.info,
      status: 200
    };

    _axios2.default.get(path, config).then(function (response) {
      var blob = new Blob([response.data], { type: 'application/json' });
      _fileSaver2.default.saveAs(blob, getTimestamp() + "_" + username + ".json");
      result.userMessage = "ok";
      result.developerMessage = "ok";
      result.code = "200";
      result.data = response.data;
      resolve(result);
    }).catch(function (error) {
      result.message = error.message;
      result.messageIcon = messageIcons.error;
      result.status = error.status;
      reject(result);
    });
  });
};

var _restDelete = function _restDelete(restServer, username, password, library, topic, key, callback) {

  var config = {
    auth: {
      username: username,
      password: password
    }
  };

  var path = restServer + dbApi + library + "/" + topic + "/" + key;

  var result = {
    data: {},
    userMessage: "OK",
    developerMessage: "OK",
    messageIcon: messageIcons.info,
    status: 200
  };

  _axios2.default.delete(path, config).then(function (response) {
    result.userMessage = response.data.status.userMessage;
    result.developerMessage = response.data.status.developerMessage;
    result.code = response.data.status.code;
    result.data = response.data;
    callback(result);
  }).catch(function (error) {
    result.message = error.message;
    result.messageIcon = messageIcons.error;
    result.status = error.status;
    callback(result);
  });
};

var restGet = function restGet(restServer, username, password, serverPath, parms, callback, requestToken) {

  var config = config = {
    auth: {
      username: username,
      password: password
    }
  };

  var path = restServer + serverPath;
  console.log('server path');
  console.log(path);
  if (parms && parms.length > 0) {
    path = path + "?" + parms;
  }

  var result = {
    data: {},
    userMessage: "OK",
    developerMessage: "OK",
    messageIcon: messageIcons.info,
    status: 200
  };

  _axios2.default.get(path, config).then(function (response) {
    if (requestToken) {
      if (requests.has(requestToken)) {
        requests.delete(requestToken);
        result.userMessage = response.data.status.userMessage;
        result.developerMessage = response.data.status.developerMessage;
        result.code = response.data.status.code;
        result.data = response.data;
        callback(result);
      }
    } else {
      result.userMessage = response.data.status.userMessage;
      result.developerMessage = response.data.status.developerMessage;
      result.code = response.data.status.code;
      result.data = response.data;
      callback(result);
    }
  }).catch(function (error) {
    if (requestToken) {
      if (requests.includes(requestToken)) {
        requests.delete(requestToken);
        result.message = error.message;
        result.messageIcon = messageIcons.error;
        result.status = error.status;
        callback(result);
      }
    } else {
      requests.delete(requestToken);
      result.message = error.message;
      result.messageIcon = messageIcons.error;
      result.status = error.status;
      callback(result);
    }
  });
};

var restPost = function restPost(restServer, username, password, serverPath, data, parms) {

  var config = {
    auth: {
      username: username,
      password: password
    }
  };

  var path = restServer + serverPath;

  if (parms && parms.length > 0) {
    path = path + "/?" + parms;
  }

  var result = {
    data: {},
    message: "OK",
    messageIcon: messageIcons.info,
    status: 200
  };

  _axios2.default.post(path, data, config).then(function (response) {}).catch(function (error) {
    result.message = error.message;
    result.messageIcon = messageIcons.error;
    result.status = error.status;
  });
  return result;
};

var restPut = function restPut(restServer, username, password, serverPath, data, parms, callback) {

  var config = {
    auth: {
      username: username,
      password: password
    }
  };

  var path = restServer + serverPath;

  if (parms && parms.length > 0) {
    path = path + "/?" + parms;
  }
  var result = {
    data: {},
    message: "OK",
    messageIcon: messageIcons.info,
    status: 200
  };

  _axios2.default.put(path, data, config).then(function (response) {
    var userMessage = "Updated OK";
    var developerMessage = userMessage;
    var statusCode = 200;
    if (response.data) {
      if (response.data.status) {
        userMessage = response.data.status.userMessage;
        developerMessage = response.data.status.developerMessage;
        statusCode = response.data.status.code;
      } else if (response.data.userMessage) {
        userMessage = response.data.userMessage;
        developerMessage = response.data.developerMessage;
        statusCode = response.data.code;
      }
    }
    result.userMessage = userMessage;
    result.developerMessage = developerMessage;
    result.code = statusCode;
    if (callback) {
      callback(result);
    }
  }).catch(function (error) {
    result.message = error.message;
    result.messageIcon = messageIcons.error;
    result.status = error.status;
    if (error.response && error.response.data) {
      result.status = error.response.data.code;
      result.message = error.response.data.userMessage;
      console.log(error.response.data.developerMessage);
    }
    if (callback) {
      callback(result);
    }
  });
  return result;
};

exports.default = {
  tableLexiconOald: tableLexiconOald,
  getRequestToken: function getRequestToken() {
    return _getRequestToken();
  },
  cancelRequest: function cancelRequest(token) {
    _cancelRequest(token);
  },
  getWsServerAdminApi: function getWsServerAdminApi() {
    return adminApi;
  },
  getWsServerLdpApi: function getWsServerLdpApi() {
    return ldpApi;
  },
  getWsServerLookupApi: function getWsServerLookupApi() {
    return lookupApi;
  },
  getWsServerDbApi: function getWsServerDbApi() {
    return dbApi;
  },
  getWsServerLoginApi: function getWsServerLoginApi() {
    return adminApi + login;
  },
  getWsServerPasswordChangeApi: function getWsServerPasswordChangeApi() {
    return adminApi + changePassword;
  },
  getWsServerLoginUserApi: function getWsServerLoginUserApi() {
    return adminApi + loginUser;
  },
  getWsServerVersionApi: function getWsServerVersionApi() {
    return adminApi + version;
  },
  getWsServerResourcesApi: function getWsServerResourcesApi() {
    return dbApi + resources;
  },
  getWsServerDomainsApi: function getWsServerDomainsApi() {
    return adminApi + adminDomains;
  },
  getDbServerAgesPdfApi: function getDbServerAgesPdfApi() {
    return dbApi + agesPdf;
  },
  getDbServerDropdownsSearchAbbreviationsApi: function getDbServerDropdownsSearchAbbreviationsApi() {
    return dbApi + dbDropdownsSearchAbbreviations;
  },
  getDbServerDropdownsSearchBibliographyApi: function getDbServerDropdownsSearchBibliographyApi() {
    return dbApi + dbDropdownsSearchBibliography;
  },
  getDbServerDropdownsSearchTextApi: function getDbServerDropdownsSearchTextApi() {
    return dbApi + dbDropdownsSearchText;
  },
  getDbServerDropdownsSearchTemplatesApi: function getDbServerDropdownsSearchTemplatesApi() {
    return dbApi + dbDropdownsSearchTemplates;
  },
  getDbServerDropdownsSearchNotesApi: function getDbServerDropdownsSearchNotesApi() {
    return dbApi + dbDropdownsSearchNotes;
  },
  getDbServerDropdownsSearchOntologyApi: function getDbServerDropdownsSearchOntologyApi() {
    return dbApi + dbDropdownsSearchOntology;
  },
  getDbServerDropdownsOntologyEntitiesApi: function getDbServerDropdownsOntologyEntitiesApi() {
    return dbApi + dbDropdownsOntologyEntites;
  },
  getDbServerDropdownsSearchRelationshipsApi: function getDbServerDropdownsSearchRelationshipsApi() {
    return dbApi + dbDropdownsSearchRelationships;
  },
  getDbServerDropdownsSearchTreebanksApi: function getDbServerDropdownsSearchTreebanksApi() {
    return dbApi + dbDropdownsSearchTreebanks;
  },
  getDbServerDocsApi: function getDbServerDocsApi() {
    return dbApi + docs;
  },
  getDbServerNotesApi: function getDbServerNotesApi() {
    return dbApi + notes;
  },
  getDbServerUserDocsApi: function getDbServerUserDocsApi() {
    return dbApi + userdocs;
  },
  getDbServerLinksApi: function getDbServerLinksApi() {
    return dbApi + links;
  },
  getDbServerOntologyApi: function getDbServerOntologyApi() {
    return dbApi + ontology;
  },
  getDbServerTemplatesApi: function getDbServerTemplatesApi() {
    return dbApi + templates;
  },
  getDbServerTreebanksApi: function getDbServerTreebanksApi() {
    return dbApi + treebanks;
  },
  getWsServerLiturgicalDayPropertiesApi: function getWsServerLiturgicalDayPropertiesApi() {
    return ldpApi + ldp;
  },
  getDbServerWordAnalysisApi: function getDbServerWordAnalysisApi() {
    return dbApi + wordAnalysis;
  },
  getLookupResult: function getLookupResult(restServer, library, topic, key, callback) {
    restGet(restServer, "", "", lookupApi + library + "/" + topic + "/" + key, "", function (result) {
      callback(result);
    });
  },
  getGenericExistsResult: function getGenericExistsResult(restServer, username, password, library, topic, key, callback) {
    restGet(restServer, username, password, dbApi + genericExists, "d=" + encodeURIComponent(library) + "&t=" + encodeURIComponent(topic) + "&k=" + encodeURIComponent(key), function (result) {
      callback(result);
    });
  },
  getGenericSearchResult: function getGenericSearchResult(restServer, username, password, parms, callback) {
    restGet(restServer, username, password, dbApi + generic, parms, function (result) {
      callback(result);
    });
  },
  getActivities: function getActivities(restServer, username, password, parms, callback) {
    restGet(restServer, username, password, dbApi + "activity", parms, function (result) {
      callback(result);
    });
  },
  getResources: function getResources(restServer, username, password, parms, callback) {
    restGet(restServer, username, password, dbApi + resources + "/" + username, parms, function (result) {
      callback(result);
    });
  },
  getTextAnalysis: function getTextAnalysis(restServer, username, password, id, callback, cancelToken) {
    restGet(restServer, username, password, dbApi + textAnalysis + "/" + id, undefined, function (result) {
      callback(result);
    }, cancelToken);
  },
  getTextComparison: function getTextComparison(restServer, username, password, parms, callback, cancelToken) {
    restGet(restServer, username, password, dbApi + docs, parms, function (result) {
      callback(result);
    }, cancelToken);
  },
  getTextDownloads: function getTextDownloads(restServer, username, password, id, parms, callback) {
    restGet(restServer, username, password, dbApi + textDownloads + "/" + id, parms, function (result) {
      callback(result);
    });
  },
  getRelationshipsSearchDropdowns: function getRelationshipsSearchDropdowns(restServer, username, password, callback) {
    restGet(restServer, username, password, dbApi + dbDropdownsSearchRelationships, undefined, function (result) {
      callback(result);
    });
  },
  getDropdownUsersForLibrary: function getDropdownUsersForLibrary(restServer, username, password, library, callback) {
    restGet(restServer, username, password, adminApi + dbDropdownsUserRolesForDomain + "/" + library, undefined, function (result) {
      callback(result);
    });
  },
  getCollectiveDomains: function getCollectiveDomains(restServer, username, password, callback) {
    restGet(restServer, username, password, adminApi + dbDomainsCollective, undefined, function (result) {
      callback(result);
    });
  },
  getDropdownLibrariesForUser: function getDropdownLibrariesForUser(restServer, username, password, user, callback) {
    restGet(restServer, username, password, adminApi + dbDropdownDomains + "/" + user, undefined, function (result) {
      callback(result);
    });
  },
  getTable: function getTable(restServer, username, password, id, callback) {
    restGet(restServer, username, password, dbApi + tables + id, undefined, function (result) {
      callback(result);
    });
  },
  getTopics: function getTopics(restServer, username, password, callback) {
    restGet(restServer, username, password, dbApi + dbDropdownsGrLibTopics, undefined, function (result) {
      callback(result);
    });
  },
  getViewForTemplate: function getViewForTemplate(restServer, username, password, parms, callback) {
    restGet(restServer, username, password, dbApi + viewtemplate, parms, function (result) {
      callback(result);
    });
  },
  getViewForTopic: function getViewForTopic(restServer, username, password, parms, callback) {
    restGet(restServer, username, password, dbApi + viewtopic, parms, function (result) {
      callback(result);
    });
  },
  getUiLabels: function getUiLabels(restServer, username, password, parms, callback) {
    restGet(restServer, username, password, dbApi + uilabels, parms, function (result) {
      callback(result);
    });
  },
  getAgesIndex: function getAgesIndex(restServer, username, password, callback) {
    restGet(restServer, username, password, dbApi + agesIndex, undefined, function (result) {
      callback(result);
    });
  },
  getAgesEditorTemplate: function getAgesEditorTemplate(restServer, username, password, parms, callback) {
    restGet(restServer, username, password, dbApi + agesReactTemplate, parms, function (result) {
      callback(result);
    });
  },
  getAgesReadOnlyTemplate: function getAgesReadOnlyTemplate(restServer, username, password, parms, callback) {
    restGet(restServer, username, password, dbApi + agesReadOnlyTemplate, parms, function (result) {
      callback(result);
    });
  },
  postLibraryClone: function postLibraryClone(restServer, username, password, value, parms, callback) {
    restPost(restServer, username, password, dbApi + clone, value, parms, function (result) {
      callback(result);
    });
  },
  restPutSchemaBasedForm: function restPutSchemaBasedForm(restServer, username, password, path, value, parms, callback) {
    restPut(restServer, username, password, path, value, parms, function (result) {
      callback(result);
    });
  },
  putValue: function putValue(restServer, username, password, value, parms, callback) {
    restPut(restServer, username, password, dbApi + valuePath, value, parms, function (result) {
      callback(result);
    });
  },
  putUiLabel: function putUiLabel(restServer, username, password, value, parms, callback) {
    restPut(restServer, username, password, dbApi + uilabels, value, parms, function (result) {
      callback(result);
    });
  },
  restGetPromise: function restGetPromise(restServer, serverPath, username, password, parms) {
    return _restGetPromise(restServer, serverPath, username, password, parms);
  },
  restGetForId: function restGetForId(restServer, username, password, id, callback) {
    var idParts = _IdManager2.default.getParts(id);
    var path = dbApi + docs + "/" + idParts.library + "/" + idParts.topic + "/" + idParts.key;
    return restGet(restServer, username, password, path, undefined, function (result) {
      callback(result);
    });
  },
  restGetForLibraryTopicKey: function restGetForLibraryTopicKey(restServer, username, password, library, topic, key, callback) {
    var path = dbApi + docs + "/" + library + "/" + topic + "/" + key;
    return restGet(restServer, username, password, path, undefined, function (result) {
      callback(result);
    });
  },
  restGetSuggestions: function restGetSuggestions(restServer, username, password, library, callback) {
    var path = dbApi + docs + "/suggestions";
    return restGet(restServer, username, password, path, "d=" + encodeURIComponent(library), function (result) {
      callback(result);
    });
  },
  restGetGenerationStatus: function restGetGenerationStatus(restServer, username, password, fileId, callback) {
    var path = dbApi + docs + "/genstatus";
    return restGet(restServer, username, password, path, "i=" + encodeURIComponent(fileId), function (result) {
      callback(result);
    });
  },
  restGetPdf: function restGetPdf(restServer, serverPath, username, password, parms, filename) {
    return _restGetPdf(restServer, serverPath, username, password, parms, filename);
  },
  restGetUserDocs: function restGetUserDocs(restServer, serverPath, username, password) {
    return _restGetUserDocs(restServer, serverPath, username, password);
  },
  restGetAddress: function restGetAddress(callback) {
    return _restGetAddress(callback);
  },
  restGetLocation: function restGetLocation(address, callback) {
    return _restGetLocation(address, callback);
  },
  restGetPublications: function restGetPublications(restServer, callback) {
    return restGetPublicPromise(restServer, dbApi + "publications", undefined, callback);
  },
  restDelete: function restDelete(restServer, username, password, library, topic, key, callback) {
    return _restDelete(restServer, username, password, library, topic, key, callback);
  }
};
module.exports = exports['default'];