'use strict';

exports.__esModule = true;
exports.TreeNode = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var treeviewSpanStyle = {
  "width": "1rem",
  "height": "1rem"
};

var treeviewSpanIndentStyle = treeviewSpanStyle;
treeviewSpanIndentStyle["marginLeft"] = "1px"; // originally 10px
treeviewSpanIndentStyle["marginRight"] = "1px"; // 10px

var treeviewSpanIconStyle = treeviewSpanStyle;
treeviewSpanIconStyle["marginLeft"] = "1px"; // 10px
treeviewSpanIconStyle["marginRight"] = "1px"; // 5px

/**
 * Modified from https://github.com/eliftech/treeview-react-bootstrap
 * The Dependency Diagram formatting is done using the TreeNode class.
 */

var DependencyDiagram = function (_React$Component) {
  _inherits(DependencyDiagram, _React$Component);

  function DependencyDiagram(props) {
    _classCallCheck(this, DependencyDiagram);

    var _this2 = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _this2.nodesQuantity = 0;

    _this2.state = { data: _this2.setNodeId(_lodash2.default.clone({ nodes: props.data })) };

    _this2.findNodeById = _this2.findNodeById.bind(_this2);
    _this2.setGlobalState = _this2.setGlobalState.bind(_this2);
    _this2.setChildrenState = _this2.setChildrenState.bind(_this2);
    _this2.setParentSelectable = _this2.setParentSelectable.bind(_this2);
    _this2.checkParentEmpty = _this2.checkParentEmpty.bind(_this2);
    _this2.nodeSelected = _this2.nodeSelected.bind(_this2);
    _this2.nodeDoubleClicked = _this2.nodeDoubleClicked.bind(_this2);
    _this2.addNode = _this2.addNode.bind(_this2);
    _this2.removeNode = _this2.removeNode.bind(_this2);
    return _this2;
  }

  DependencyDiagram.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    this.setState({ data: this.setNodeId(_lodash2.default.clone({ nodes: nextProps.data })) });
  };

  DependencyDiagram.prototype.setNodeId = function setNodeId(node) {
    var _this3 = this;

    if (!node.nodes) return;
    return node.nodes.map(function (childNode) {
      return {
        nodeId: _this3.nodesQuantity++,
        nodes: _this3.setNodeId(childNode),
        parentNode: node,
        state: {
          selected: childNode.state ? !!childNode.state.selected : false,
          expanded: childNode.state ? !!childNode.state.expanded : false
        },
        key: childNode.key,
        label: childNode.label,
        token: childNode.token,
        gloss: childNode.gloss,
        grammar: childNode.grammar,
        lemma: childNode.lemma,
        refersTo: childNode.refersTo,
        icon: childNode.icon
      };
    });
  };

  DependencyDiagram.prototype.findNodeById = function findNodeById(nodes, id) {
    var _this = this;
    var result = void 0;
    if (nodes) nodes.forEach(function (node) {
      if (node.nodeId == id) result = node;else {
        if (node.nodes) {
          result = _this.findNodeById(node.nodes, id) || result;
        }
      }
    });
    return result;
  };

  DependencyDiagram.prototype.deleteById = function deleteById(obj, id) {
    var _this4 = this;

    if (!obj || obj.length <= 0) return [];
    var arr = [];
    _lodash2.default.each(obj, function (val) {
      if (val.nodes && val.nodes.length > 0) val.nodes = _this4.deleteById(val.nodes, id);

      if (val.nodeId !== id) {
        arr.push(val);
      }
    });
    return arr;
  };

  DependencyDiagram.prototype.setChildrenState = function setChildrenState(nodes, state) {
    var _this = this;
    if (nodes) nodes.forEach(function (node) {
      node.state.selected = state;
      _this.setChildrenState(node.nodes, state);
    });
  };

  DependencyDiagram.prototype.setGlobalState = function setGlobalState(state) {
    var _this = this;
    if (this.state.data) this.state.data.forEach(function (node) {
      node.state.selected = state;
      _this.setChildrenState(node.nodes, state);
    });
  };

  DependencyDiagram.prototype.setParentSelectable = function setParentSelectable(node) {
    if (!node.parentNode || !node.parentNode.state) return;
    node.parentNode.state.selected = true;
    this.setParentSelectable(node.parentNode);
  };

  DependencyDiagram.prototype.checkParentEmpty = function checkParentEmpty(node) {
    var parent = node.parentNode;
    if (!parent.state || !parent.state.selected) return;
    if (parent.nodes.every(function (childNode) {
      return !childNode.state.selected;
    })) {
      parent.state.selected = false;
      this.checkParentEmpty(parent);
    }
  };

  DependencyDiagram.prototype.nodeSelected = function nodeSelected(nodeId, selected) {
    if (this.props.onClick) {
      var node = this.findNodeById(this.state.data, nodeId);
      this.props.onClick(node);
    }
  };

  DependencyDiagram.prototype.nodeDoubleClicked = function nodeDoubleClicked(nodeId, selected) {
    var node = this.findNodeById(this.state.data, nodeId);
    if (this.props.onDoubleClick) this.props.onDoubleClick(node);
  };

  DependencyDiagram.prototype.convert = function convert(obj) {
    var _this5 = this;

    if (!obj || obj.length <= 0) return [];
    return _lodash2.default.map(obj, function (val) {
      var treeNodeData = {
        key: val.key,
        token: val.token,
        gloss: val.gloss,
        grammar: val.grammar,
        lemma: val.lemma,
        selected: val.state.selected
      };
      var children = _this5.convert(val.nodes);
      if (children.length > 0) treeNodeData.nodes = children;
      return treeNodeData;
    });
  };

  DependencyDiagram.prototype.addNode = function addNode(nodeId, text) {
    var node = this.findNodeById(this.state.data, nodeId);

    var newNode = {
      text: text,
      state: {},
      parentNode: node,
      nodeId: this.nodesQuantity++
    };

    if (node.nodes) {
      node.nodes.push(newNode);
    } else {
      node.nodes = [newNode];
    }

    if (this.props.onNodeAdded) this.props.onNodeAdded(this.state.data);
  };

  DependencyDiagram.prototype.removeNode = function removeNode(nodeId) {
    var newData = this.deleteById(_lodash2.default.clone(this.state.data), nodeId);
    if (newData.length === 0) return false;
    this.setState({ data: newData });
    if (this.props.onNodeRemoved) this.props.onNodeRemoved(newData);
  };

  DependencyDiagram.prototype.render = function render() {
    var data = this.state.data;
    var children = [];
    if (data) {
      var _this = this;
      data.forEach(function (node) {
        children.push(_react2.default.createElement(TreeNode, {
          node: node,
          key: node.nodeId,
          level: 1,
          visible: true,
          onSelectedStatusChanged: _this.nodeSelected,
          onNodeDoubleClicked: _this.nodeDoubleClicked,
          addNode: _this.addNode,
          removeNode: _this.removeNode,
          options: _this.props,
          nodes: _this.state.data,
          allowNew: _this.props.allowNew,
          offSetKey: _this.props.offsetKey
        }));
      });
    }

    return _react2.default.createElement(
      'div',
      { classID: 'treeview', className: 'treeview' },
      _react2.default.createElement(
        'ul',
        { className: 'list-group' },
        children
      )
    );
  };

  return DependencyDiagram;
}(_react2.default.Component);

process.env.NODE_ENV !== "production" ? DependencyDiagram.propTypes = {
  levels: _propTypes2.default.number,
  expandIcon: _propTypes2.default.string,
  selectable: _propTypes2.default.bool,

  emptyIcon: _propTypes2.default.string,
  nodeIcon: _propTypes2.default.string,

  color: _propTypes2.default.string,
  backColor: _propTypes2.default.string,
  borderColor: _propTypes2.default.string,
  onhoverColor: _propTypes2.default.string,
  selectedColor: _propTypes2.default.string,
  selectedBackColor: _propTypes2.default.string,

  enableLinks: _propTypes2.default.bool,
  highlightSelected: _propTypes2.default.bool,
  showBorder: _propTypes2.default.bool,
  showTags: _propTypes2.default.bool,

  nodes: _propTypes2.default.arrayOf(_propTypes2.default.object),

  onClick: _propTypes2.default.func,
  onDoubleClick: _propTypes2.default.func,
  onNodeAdded: _propTypes2.default.func,
  onNodeRemoved: _propTypes2.default.func,

  offsetKey: _propTypes2.default.bool
} : void 0;

DependencyDiagram.defaultProps = {
  levels: 2,
  selectable: true,

  expandIcon: 'glyphicon glyphicon-plus',
  collapseIcon: 'glyphicon glyphicon-minus',
  emptyIcon: 'glyphicon',
  nodeIcon: 'glyphicon glyphicon-stop',
  unselectedIcon: 'glyphicon glyphicon-unchecked',
  selectedIcon: 'glyphicon glyphicon-check',

  color: "#428bca",
  backColor: undefined,
  borderColor: undefined,
  onhoverColor: '#F5F5F5',
  selectedColor: '#000000',
  selectedBackColor: '#bce8f1',

  enableLinks: false,
  highlightSelected: true,
  showBorder: true,
  showTags: false,

  nodes: []
};

var TreeNode = exports.TreeNode = function (_React$Component2) {
  _inherits(TreeNode, _React$Component2);

  function TreeNode(props) {
    _classCallCheck(this, TreeNode);

    var _this6 = _possibleConstructorReturn(this, _React$Component2.call(this, props));

    _this6.state = { node: props.node, expanded: true };
    _this6.selected = props.node.state && props.node.state.hasOwnProperty('selected') ? props.node.state.selected : false;
    _this6.toggleExpanded = _this6.toggleExpanded.bind(_this6);
    _this6.toggleSelected = _this6.toggleSelected.bind(_this6);
    _this6.doubleClicked = _this6.doubleClicked.bind(_this6);
    _this6.newNodeForm = _this6.newNodeForm.bind(_this6);
    _this6.addNode = _this6.addNode.bind(_this6);
    _this6.removeNode = _this6.removeNode.bind(_this6);
    return _this6;
  }

  TreeNode.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    this.setState({ node: nextProps.node, expanded: true });
    this.selected = nextProps.node.state && nextProps.node.state.hasOwnProperty('selected') ? nextProps.node.state.selected : false;
  };

  TreeNode.prototype.toggleExpanded = function toggleExpanded(event) {
    this.setState({ expanded: !this.state.expanded });
    event.stopPropagation();
  };

  TreeNode.prototype.toggleSelected = function toggleSelected(event) {
    var selected = !this.props.node.state.selected;
    this.props.onSelectedStatusChanged(this.state.node.nodeId, selected);
    event.stopPropagation();
  };

  TreeNode.prototype.doubleClicked = function doubleClicked(event) {
    var selected = !this.props.node.state.selected;
    this.props.onNodeDoubleClicked(this.state.node.nodeId, selected);
    event.stopPropagation();
  };

  TreeNode.prototype.newNodeForm = function newNodeForm(event) {
    this.setState({ addNode: !this.state.addNode });
    event.stopPropagation();
  };

  TreeNode.prototype.addNode = function addNode(event) {
    if (!new RegExp('^[a-zA-Z0-9]+$').test(this.refs.newNodeName.value)) {
      this.refs.newNodeName.setCustomValidity("Incorrect format");
      return false;
    }
    this.setState({ addNode: false });
    this.props.addNode(this.state.node.nodeId, this.refs.newNodeName.value);
    this.setState({ expanded: true });
    event.stopPropagation();
  };

  TreeNode.prototype.removeNode = function removeNode(event) {
    this.props.removeNode(this.state.node.nodeId);
    event.stopPropagation();
  };

  TreeNode.prototype.render = function render() {
    var node = _lodash2.default.clone(this.props.node);
    var options = _lodash2.default.clone(this.props.options);

    var style = void 0;

    if (this.props.options.selectable) node.icon = node.state.selected ? options.selectedIcon : options.unselectedIcon;

    if (!this.props.visible) {

      style = {
        display: 'none'
      };
    } else {

      if (options.highlightSelected && node.state.selected) {
        style = {
          color: options.selectedColor,
          backgroundColor: options.selectedBackColor
        };
      } else {
        style = {
          color: node.color || options.color,
          backgroundColor: node.backColor || options.backColor
        };
      }

      if (!options.showBorder) {
        style.border = 'none';
      } else if (options.borderColor) {
        style.border = '1px solid ' + options.borderColor;
      }
    }

    var indents = [];
    for (var i = 0; i < this.props.level - 1; i++) {
      indents.push(_react2.default.createElement(
        'span',
        { className: 'indent', style: treeviewSpanIndentStyle, key: i },
        ' '
      ));
    }

    var expandCollapseIcon = void 0;
    if (node.nodes) {
      if (!this.state.expanded) {
        expandCollapseIcon = _react2.default.createElement(
          'span',
          { className: options.expandIcon, style: treeviewSpanStyle,
            onClick: this.toggleExpanded },
          ' '
        );
      } else {
        expandCollapseIcon = _react2.default.createElement(
          'span',
          { className: options.collapseIcon, style: treeviewSpanStyle,
            onClick: this.toggleExpanded },
          '   '
        );
      }
    } else {
      expandCollapseIcon = _react2.default.createElement(
        'span',
        { className: options.emptyIcon, style: treeviewSpanStyle },
        ' '
      );
    }

    var nodeIcon = node.icon || options.nodeIcon ? _react2.default.createElement(
      'span',
      { className: 'icon', onClick: this.toggleSelected, style: treeviewSpanIconStyle },
      ' ',
      _react2.default.createElement(
        'i',
        {
          className: node.icon || options.nodeIcon },
        ' '
      ),
      ' '
    ) : "";

    var nodeText = void 0;
    if (options.enableLinks) {
      nodeText = _react2.default.createElement(
        'a',
        { href: node.href },
        ' ',
        node.token,
        ' '
      );
    } else {
      var key = undefined;
      if (isNaN(node.key)) {
        key = node.key;
      } else {
        key = parseInt(node.key);
        if (this.props.options.offsetKey) {
          key++;
        }
      }
      var refersTo = node.refersTo;
      if (refersTo) {
        if (!isNaN(refersTo)) {
          refersTo = (parseInt(refersTo) + 1).toString();
        }
      }
      nodeText = _react2.default.createElement(
        'span',
        { onClick: this.toggleSelected, style: treeviewSpanStyle },
        _react2.default.createElement(
          'span',
          { className: "App App-DependencyDiagram-Node-Key" },
          key
        ),
        node.refersTo && _react2.default.createElement(
          'span',
          { className: "App App-DependencyDiagram-Node-RefersTo" },
          '\u2192',
          refersTo
        ),
        _react2.default.createElement(
          'span',
          { title: 'hi', className: "App App-DependencyDiagram-Node-Label" },
          node.label
        ),
        _react2.default.createElement(
          'span',
          { className: "App App-DependencyDiagram-Node-Token" },
          node.token
        ),
        _react2.default.createElement(
          'span',
          { className: "App App-DependencyDiagram-Node-Gloss" },
          node.gloss
        ),
        _react2.default.createElement(
          'span',
          { className: "App App-DependencyDiagram-Node-Grammar" },
          node.grammar
        ),
        _react2.default.createElement(
          'span',
          { className: "App App-DependencyDiagram-Node-Lemma" },
          node.lemma
        )
      );
    }

    var badges = void 0;
    if (options.showTags && node.grammar) {
      badges = node.grammar.map(function (tag) {
        return _react2.default.createElement(
          'span',
          { className: 'badge', style: treeviewSpanStyle },
          ' ',
          tag,
          ' '
        );
      });
    }

    var children = [];
    if (node.nodes) {
      var _this = this;
      node.nodes.forEach(function (node) {
        children.push(_react2.default.createElement(TreeNode, {
          node: node,
          key: node.nodeId,
          level: _this.props.level + 1,
          visible: _this.state.expanded && _this.props.visible,
          onSelectedStatusChanged: _this.props.onSelectedStatusChanged,
          onNodeDoubleClicked: _this.props.onNodeDoubleClicked,
          addNode: _this.props.addNode,
          removeNode: _this.props.removeNode,
          options: options,
          allowNew: _this.props.allowNew
        }));
      });
    }

    var addButton = this.props.allowNew ? _react2.default.createElement('span', { className: 'glyphicon glyphicon-plus addElement', style: { float: "right", cursor: "pointer" },
      onClick: this.newNodeForm }) : "";

    var removeButton = this.props.options.removable ? _react2.default.createElement('span', { className: 'glyphicon glyphicon-remove removeElement', style: { cursor: "pointer" },
      onClick: this.removeNode }) : "";

    var newNode = void 0;

    if (this.state.addNode) {
      newNode = _react2.default.createElement(
        'div',
        { className: 'input-group' },
        _react2.default.createElement('input', { type: 'text', className: 'form-control nodeName', ref: 'newNodeName' }),
        _react2.default.createElement(
          'span',
          { className: 'input-group-btn' },
          _react2.default.createElement(
            'span',
            { className: 'btn btn-primary submitNode', onClick: this.addNode },
            'Add'
          )
        )
      );
    }

    style["cursor"] = "pointer";

    var treeNode = _react2.default.createElement(
      'li',
      { className: 'list-group-item',
        style: style,
        onDoubleClick: this.doubleClicked,
        key: node.nodeId },
      indents,
      expandCollapseIcon,
      nodeIcon,
      removeButton,
      nodeText,
      badges,
      addButton,
      newNode,
      children
    );

    return _react2.default.createElement(
      'ul',
      null,
      treeNode
    );
  };

  return TreeNode;
}(_react2.default.Component);

exports.default = DependencyDiagram;